!function() {
  "use strict";
  function clampEntity(entityName, num, min, max, overflow) {
    const clamped = clampNumber(num, min, max);
    if (overflow && num !== clamped) {
      throw new RangeError(numberOutOfRange(entityName, num, min, max));
    }
    return clamped;
  }
  function clampProp(props, propName, min, max, overflow) {
    return clampEntity(propName, getDefinedProp(props, propName), min, max, overflow);
  }
  function getDefinedProp(props, propName) {
    const propVal = props[propName];
    if (void 0 === propVal) {
      throw new TypeError(missingField(propName));
    }
    return propVal;
  }
  function isObjectLike(arg) {
    return null !== arg && /object|function/.test(typeof arg);
  }
  function createLazyGenerator(generator, MapClass = Map) {
    const map = new MapClass;
    return (key, ...otherArgs) => {
      if (map.has(key)) {
        return map.get(key);
      }
      const val = generator(key, ...otherArgs);
      return map.set(key, val), val;
    };
  }
  function createNameDescriptors(name) {
    return createPropDescriptors({
      name: name
    }, 1);
  }
  function createPropDescriptors(propVals, readonly) {
    return mapProps((value => ({
      value: value,
      configurable: 1,
      writable: !readonly
    })), propVals);
  }
  function createGetterDescriptors(getters) {
    return mapProps((getter => ({
      get: getter,
      configurable: 1
    })), getters);
  }
  function createStringTagDescriptors(value) {
    return {
      [Symbol.toStringTag]: {
        value: value,
        configurable: 1
      }
    };
  }
  function zipProps(propNamesRev, args) {
    const res = {};
    let i = propNamesRev.length;
    for (const arg of args) {
      res[propNamesRev[--i]] = arg;
    }
    return res;
  }
  function mapProps(transformer, props, extraArg) {
    const res = {};
    for (const propName in props) {
      res[propName] = transformer(props[propName], propName, extraArg);
    }
    return res;
  }
  function mapPropNames(generator, propNames, extraArg) {
    const props = {};
    for (let i = 0; i < propNames.length; i++) {
      const propName = propNames[i];
      props[propName] = generator(propName, i, extraArg);
    }
    return props;
  }
  function pluckProps(propNames, props) {
    const res = {};
    for (const propName of propNames) {
      res[propName] = props[propName];
    }
    return res;
  }
  function excludePropsByName(propNames, props) {
    const filteredProps = {};
    for (const propName in props) {
      propNames.has(propName) || (filteredProps[propName] = props[propName]);
    }
    return filteredProps;
  }
  function excludeUndefinedProps(props) {
    props = {
      ...props
    };
    const propNames = Object.keys(props);
    for (const propName of propNames) {
      void 0 === props[propName] && delete props[propName];
    }
    return props;
  }
  function allPropsEqual(propNames, props0, props1) {
    for (const propName of propNames) {
      if (props0[propName] !== props1[propName]) {
        return 0;
      }
    }
    return 1;
  }
  function bindArgs(f, ...boundArgs) {
    return (...dynamicArgs) => f(...boundArgs, ...dynamicArgs);
  }
  function identity(arg) {
    return arg;
  }
  function capitalize(s) {
    return s[0].toUpperCase() + s.substring(1);
  }
  function sortStrings(strs) {
    return strs.slice().sort();
  }
  function padNumber(digits, num) {
    return String(num).padStart(digits, "0");
  }
  function compareNumbers(a, b) {
    return Math.sign(a - b);
  }
  function clampNumber(num, min, max) {
    return Math.min(Math.max(num, min), max);
  }
  function divModFloor(num, divisor) {
    return [ Math.floor(num / divisor), modFloor(num, divisor) ];
  }
  function modFloor(num, divisor) {
    return (num % divisor + divisor) % divisor;
  }
  function divModTrunc(num, divisor) {
    return [ divTrunc(num, divisor), modTrunc(num, divisor) ];
  }
  function divTrunc(num, divisor) {
    return Math.trunc(num / divisor) || 0;
  }
  function modTrunc(num, divisor) {
    return num % divisor || 0;
  }
  function hasHalf(num) {
    return .5 === Math.abs(num % 1);
  }
  function givenFieldsToDayTimeNano(fields, largestUnit, fieldNames) {
    let timeNano = 0, days = 0;
    for (let unit = 0; unit <= largestUnit; unit++) {
      const fieldVal = fields[fieldNames[unit]], unitNano = unitNanoMap[unit], unitInDay = nanoInUtcDay / unitNano, [unitDays, leftoverUnits] = divModTrunc(fieldVal, unitInDay);
      timeNano += leftoverUnits * unitNano, days += unitDays;
    }
    const [timeDays, leftoverNano] = divModTrunc(timeNano, nanoInUtcDay);
    return [ days + timeDays, leftoverNano ];
  }
  function nanoToGivenFields(nano, largestUnit, fieldNames) {
    const fields = {};
    for (let unit = largestUnit; unit >= 0; unit--) {
      const divisor = unitNanoMap[unit];
      fields[fieldNames[unit]] = divTrunc(nano, divisor), nano = modTrunc(nano, divisor);
    }
    return fields;
  }
  function createDayTimeNano(days, timeNano) {
    let [extraDays, newTimeNano] = divModTrunc(timeNano, nanoInUtcDay), newDays = days + extraDays;
    const newDaysSign = Math.sign(newDays);
    return newDaysSign && newDaysSign === -Math.sign(newTimeNano) && (newDays -= newDaysSign, 
    newTimeNano += newDaysSign * nanoInUtcDay), [ newDays, newTimeNano ];
  }
  function addDayTimeNanoAndNumber(a, b) {
    return createDayTimeNano(a[0], a[1] + b);
  }
  function addDayTimeNanos(a, b, sign = 1) {
    return createDayTimeNano(a[0] + b[0] * sign, a[1] + b[1] * sign);
  }
  function diffDayTimeNanos(a, b) {
    return createDayTimeNano(b[0] - a[0], b[1] - a[1]);
  }
  function compareDayTimeNanos(a, b) {
    return compareNumbers(a[0], b[0]) || compareNumbers(a[1], b[1]);
  }
  function bigIntToDayTimeNano(num, multiplierNano = 1) {
    const wholeInDay = BigInt(nanoInUtcDay / multiplierNano);
    return [ Number(num / wholeInDay), Number(num % wholeInDay) * multiplierNano ];
  }
  function numberToDayTimeNano(num, multiplierNano = 1) {
    const wholeInDay = nanoInUtcDay / multiplierNano, [days, remainder] = divModTrunc(num, wholeInDay);
    return [ days, remainder * multiplierNano ];
  }
  function dayTimeNanoToBigInt(dayTimeNano, divisorNano = 1) {
    const [days, timeNano] = dayTimeNano, timeUnits = Math.floor(timeNano / divisorNano), timeUnitsInDay = nanoInUtcDay / divisorNano;
    return BigInt(days) * BigInt(timeUnitsInDay) + BigInt(timeUnits);
  }
  function dayTimeNanoToNumber(dayTimeNano, divisorNano = 1, exact) {
    const [whole, remainder] = dayTimeNanoToNumberRemainder(dayTimeNano, divisorNano);
    return whole + (exact ? remainder / divisorNano : 0);
  }
  function dayTimeNanoToNumberRemainder(dayTimeNano, divisorNano) {
    const [days, timeNano] = dayTimeNano, [whole, remainderNano] = divModFloor(timeNano, divisorNano);
    return [ days * (nanoInUtcDay / divisorNano) + whole, remainderNano ];
  }
  function hashIntlFormatParts(intlFormat, epochMilliseconds) {
    const parts = intlFormat.formatToParts(epochMilliseconds), hash = {};
    for (const part of parts) {
      hash[part.type] = part.value;
    }
    return hash;
  }
  function checkIsoYearMonthInBounds(isoFields) {
    return clampProp(isoFields, "isoYear", isoYearMin, isoYearMax, 1), isoFields.isoYear === isoYearMin ? clampProp(isoFields, "isoMonth", 4, 12, 1) : isoFields.isoYear === isoYearMax && clampProp(isoFields, "isoMonth", 1, 9, 1), 
    isoFields;
  }
  function checkIsoDateInBounds(isoFields) {
    return checkIsoDateTimeInBounds({
      ...isoFields,
      ...isoTimeFieldDefaults,
      isoHour: 12
    }), isoFields;
  }
  function checkIsoDateTimeInBounds(isoFields) {
    const isoYear = clampProp(isoFields, "isoYear", isoYearMin, isoYearMax, 1), nudge = isoYear === isoYearMin ? 1 : isoYear === isoYearMax ? -1 : 0;
    return nudge && checkEpochNanoInBounds(isoToEpochNano({
      ...isoFields,
      isoDay: isoFields.isoDay + nudge,
      isoNanosecond: isoFields.isoNanosecond - nudge
    })), isoFields;
  }
  function checkEpochNanoInBounds(epochNano) {
    if (!epochNano || -1 === compareDayTimeNanos(epochNano, epochNanoMin) || 1 === compareDayTimeNanos(epochNano, epochNanoMax)) {
      throw new RangeError(outOfBoundsDate);
    }
    return epochNano;
  }
  function isoTimeFieldsToNano(isoTimeFields) {
    return givenFieldsToDayTimeNano(isoTimeFields, 5, isoTimeFieldNamesAsc)[1];
  }
  function nanoToIsoTimeAndDay(nano) {
    const [dayDelta, timeNano] = divModFloor(nano, nanoInUtcDay);
    return [ nanoToGivenFields(timeNano, 5, isoTimeFieldNamesAsc), dayDelta ];
  }
  function epochNanoToSec(epochNano) {
    return dayTimeNanoToNumber(epochNano, nanoInSec);
  }
  function epochNanoToMilli(epochNano) {
    return dayTimeNanoToNumber(epochNano, nanoInMilli);
  }
  function isoToEpochMilli(isoDateTimeFields) {
    return isoArgsToEpochMilli(isoDateTimeFields.isoYear, isoDateTimeFields.isoMonth, isoDateTimeFields.isoDay, isoDateTimeFields.isoHour, isoDateTimeFields.isoMinute, isoDateTimeFields.isoSecond, isoDateTimeFields.isoMillisecond);
  }
  function isoToEpochNano(isoFields) {
    const epochMilli = isoToEpochMilli(isoFields);
    if (void 0 !== epochMilli) {
      const [days, milliRemainder] = divModTrunc(epochMilli, milliInDay);
      return [ days, milliRemainder * nanoInMilli + (isoFields.isoMicrosecond || 0) * nanoInMicro + (isoFields.isoNanosecond || 0) ];
    }
  }
  function isoToEpochNanoWithOffset(isoFields, offsetNano) {
    const [newIsoTimeFields, dayDelta] = nanoToIsoTimeAndDay(isoTimeFieldsToNano(isoFields) - offsetNano);
    return checkEpochNanoInBounds(isoToEpochNano({
      ...isoFields,
      isoDay: isoFields.isoDay + dayDelta,
      ...newIsoTimeFields
    }));
  }
  function isoArgsToEpochSec(...args) {
    return isoArgsToEpochMilli(...args) / milliInSec;
  }
  function isoArgsToEpochMilli(...args) {
    const [legacyDate, nudge] = isoToLegacyDate(...args), epochMilli = legacyDate.getTime();
    if (!isNaN(epochMilli)) {
      return epochMilli - nudge * milliInDay;
    }
  }
  function isoToLegacyDate(isoYear, isoMonth = 1, isoDay = 1, isoHour = 0, isoMinute = 0, isoSec = 0, isoMilli = 0) {
    const nudge = isoYear === isoYearMin ? 1 : isoYear === isoYearMax ? -1 : 0, legacyDate = new Date;
    return legacyDate.setUTCHours(isoHour, isoMinute, isoSec, isoMilli), legacyDate.setUTCFullYear(isoYear, isoMonth - 1, isoDay + nudge), 
    [ legacyDate, nudge ];
  }
  function epochNanoToIso(epochNano, offsetNano) {
    let [days, timeNano] = addDayTimeNanoAndNumber(epochNano, offsetNano);
    timeNano < 0 && (timeNano += nanoInUtcDay, days -= 1);
    const [timeMilli, nanoRemainder] = divModFloor(timeNano, nanoInMilli), [isoMicrosecond, isoNanosecond] = divModFloor(nanoRemainder, nanoInMicro);
    return {
      ...epochMilliToIso(days * milliInDay + timeMilli),
      isoMicrosecond: isoMicrosecond,
      isoNanosecond: isoNanosecond
    };
  }
  function epochMilliToIso(epochMilli) {
    const nudge = epochMilli < -milliInDay * maxDays ? 1 : epochMilli > milliInDay * maxDays ? -1 : 0, legacyDate = new Date(epochMilli + nudge * milliInDay);
    return zipProps(isoDateTimeFieldNamesAsc, [ legacyDate.getUTCFullYear(), legacyDate.getUTCMonth() + 1, legacyDate.getUTCDate() - nudge, legacyDate.getUTCHours(), legacyDate.getUTCMinutes(), legacyDate.getUTCSeconds(), legacyDate.getUTCMilliseconds() ]);
  }
  function computeIsoMonthsInYear() {
    return isoMonthsInYear;
  }
  function computeIsoDaysInMonth(isoYear, isoMonth) {
    switch (isoMonth) {
     case 2:
      return computeIsoInLeapYear(isoYear) ? 29 : 28;

     case 4:
     case 6:
     case 9:
     case 11:
      return 30;
    }
    return 31;
  }
  function computeIsoDaysInYear(isoYear) {
    return computeIsoInLeapYear(isoYear) ? 366 : 365;
  }
  function computeIsoInLeapYear(isoYear) {
    return isoYear % 4 == 0 && (isoYear % 100 != 0 || isoYear % 400 == 0);
  }
  function computeIsoDayOfYear(isoDateFields) {
    return diffEpochMilliByDay(isoToEpochMilli(isoDateYearStart(isoDateFields)), isoToEpochMilli({
      ...isoDateFields,
      ...isoTimeFieldDefaults
    })) + 1;
  }
  function computeIsoDayOfWeek(isoDateFields) {
    const [legacyDate, nudge] = isoToLegacyDate(isoDateFields.isoYear, isoDateFields.isoMonth, isoDateFields.isoDay);
    return modFloor(legacyDate.getUTCDay() - nudge, 7) || 7;
  }
  function computeIsoWeekParts(isoDateFields) {
    const doy = computeIsoDayOfYear(isoDateFields), dow = computeIsoDayOfWeek(isoDateFields), doj = computeIsoDayOfWeek(isoDateYearStart(isoDateFields)), isoWeek = Math.floor((doy - dow + 10) / isoDaysInWeek), {isoYear: isoYear} = isoDateFields;
    return isoWeek < 1 ? [ isoYear - 1, 5 === doj || 6 === doj && computeIsoInLeapYear(isoYear - 1) ? 53 : 52 ] : 53 === isoWeek && computeIsoDaysInYear(isoYear) - doy < 4 - dow ? [ isoYear + 1, 1 ] : [ isoYear, isoWeek ];
  }
  function isoDateYearStart(isoDateFields) {
    return {
      ...isoDateFields,
      isoMonth: 1,
      isoDay: 1,
      ...isoTimeFieldDefaults
    };
  }
  function computeGregoryEraParts({isoYear: isoYear}) {
    return isoYear < 1 ? [ "bce", 1 - isoYear ] : [ "ce", isoYear ];
  }
  function checkIsoDateTimeFields(isoDateTimeFields) {
    return checkIsoDateFields(isoDateTimeFields), constrainIsoTimeFields(isoDateTimeFields, 1), 
    isoDateTimeFields;
  }
  function checkIsoDateFields(isoInternals) {
    return constrainIsoDateFields(isoInternals, 1), isoInternals;
  }
  function isIsoDateFieldsValid(isoFields) {
    return allPropsEqual(isoDateFieldNamesAsc, isoFields, constrainIsoDateFields(isoFields));
  }
  function constrainIsoDateFields(isoFields, overflow) {
    const {isoYear: isoYear} = isoFields, isoMonth = clampProp(isoFields, "isoMonth", 1, computeIsoMonthsInYear(), overflow);
    return {
      isoYear: isoYear,
      isoMonth: isoMonth,
      isoDay: clampProp(isoFields, "isoDay", 1, computeIsoDaysInMonth(isoYear, isoMonth), overflow)
    };
  }
  function constrainIsoTimeFields(isoTimeFields, overflow) {
    return zipProps(isoTimeFieldNamesAsc, [ clampProp(isoTimeFields, "isoHour", 0, 23, overflow), clampProp(isoTimeFields, "isoMinute", 0, 59, overflow), clampProp(isoTimeFields, "isoSecond", 0, 59, overflow), clampProp(isoTimeFields, "isoMillisecond", 0, 999, overflow), clampProp(isoTimeFields, "isoMicrosecond", 0, 999, overflow), clampProp(isoTimeFields, "isoNanosecond", 0, 999, overflow) ]);
  }
  function requireObjectLike(arg) {
    if (!isObjectLike(arg)) {
      throw new TypeError(invalidObject);
    }
    return arg;
  }
  function requireType(typeName, arg, entityName = typeName) {
    if (typeof arg !== typeName) {
      throw new TypeError(invalidEntity(entityName, arg));
    }
    return arg;
  }
  function requireInteger(arg) {
    return requireNumberIsInteger(requireNumber(arg));
  }
  function requirePositiveInteger(arg) {
    return requireNumberIsPositive(requireInteger(arg));
  }
  function requireNumberIsInteger(num, entityName = "number") {
    if (!Number.isInteger(num)) {
      throw new RangeError(expectedInteger(entityName, num));
    }
    return num || 0;
  }
  function requireNumberIsPositive(num, entityName = "number") {
    if (num <= 0) {
      throw new RangeError(expectedPositive(entityName, num));
    }
    return num;
  }
  function requireNonNullish(o) {
    if (null == o) {
      throw new TypeError("Cannot be null or undefined");
    }
    return o;
  }
  function requirePropDefined(optionName, optionVal) {
    if (null == optionVal) {
      throw new RangeError(missingField(optionName));
    }
    return optionVal;
  }
  function toString(arg) {
    if ("symbol" == typeof arg) {
      throw new TypeError(forbiddenSymbolToString);
    }
    return String(arg);
  }
  function toStringViaPrimitive(arg, entityName) {
    return isObjectLike(arg) ? String(arg) : requireString(arg, entityName);
  }
  function toBigInt(bi) {
    if ("string" == typeof bi) {
      return BigInt(bi);
    }
    if ("bigint" != typeof bi) {
      throw new TypeError(invalidBigInt(bi));
    }
    return bi;
  }
  function toNumber(arg, entityName = "number") {
    if ("bigint" == typeof arg) {
      throw new TypeError(forbiddenBigIntToNumber(entityName));
    }
    if (arg = Number(arg), !Number.isFinite(arg)) {
      throw new RangeError(expectedFinite(entityName, arg));
    }
    return arg;
  }
  function toInteger(arg, entityName) {
    return Math.trunc(toNumber(arg, entityName)) || 0;
  }
  function toStrictInteger(arg, entityName) {
    return requireNumberIsInteger(toNumber(arg, entityName), entityName);
  }
  function toPositiveInteger(arg, entityName) {
    return requireNumberIsPositive(toInteger(arg, entityName), entityName);
  }
  function refineOverflowOptions(options) {
    return void 0 === options ? 0 : refineOverflow(requireObjectLike(options));
  }
  function refineZonedFieldOptions(options, defaultOffsetDisambig = 0) {
    options = normalizeOptions(options);
    const epochDisambig = refineEpochDisambig(options), offsetDisambig = refineOffsetDisambig(options, defaultOffsetDisambig);
    return [ refineOverflow(options), offsetDisambig, epochDisambig ];
  }
  function refineEpochDisambigOptions(options) {
    return refineEpochDisambig(normalizeOptions(options));
  }
  function refineDiffOptions(roundingModeInvert, options, defaultLargestUnit, maxUnit = 9, minUnit = 0, defaultRoundingMode = 4) {
    options = normalizeOptions(options);
    let largestUnit = refineLargestUnit(options, maxUnit, minUnit), roundingInc = parseRoundingIncInteger(options), roundingMode = refineRoundingMode(options, defaultRoundingMode);
    const smallestUnit = refineSmallestUnit(options, maxUnit, minUnit, 1);
    return null == largestUnit ? largestUnit = Math.max(defaultLargestUnit, smallestUnit) : checkLargestSmallestUnit(largestUnit, smallestUnit), 
    roundingInc = refineRoundingInc(roundingInc, smallestUnit, 1), roundingModeInvert && (roundingMode = (roundingMode => roundingMode < 4 ? (roundingMode + 2) % 4 : roundingMode)(roundingMode)), 
    [ largestUnit, smallestUnit, roundingInc, roundingMode ];
  }
  function refineRoundOptions(options, maxUnit = 6, solarMode) {
    let roundingInc = parseRoundingIncInteger(options = normalizeUnitNameOptions(options, smallestUnitStr));
    const roundingMode = refineRoundingMode(options, 7);
    let smallestUnit = refineSmallestUnit(options, maxUnit);
    return smallestUnit = requirePropDefined(smallestUnitStr, smallestUnit), roundingInc = refineRoundingInc(roundingInc, smallestUnit, void 0, solarMode), 
    [ smallestUnit, roundingInc, roundingMode ];
  }
  function refineDateDisplayOptions(options) {
    return refineCalendarDisplay(normalizeOptions(options));
  }
  function refineTimeDisplayOptions(options, maxSmallestUnit) {
    return refineTimeDisplayTuple(normalizeOptions(options), maxSmallestUnit);
  }
  function refineTimeDisplayTuple(options, maxSmallestUnit = 4) {
    const subsecDigits = refineSubsecDigits(options);
    return [ refineRoundingMode(options, 4), ...refineSmallestUnitAndSubsecDigits(refineSmallestUnit(options, maxSmallestUnit), subsecDigits) ];
  }
  function refineSmallestUnitAndSubsecDigits(smallestUnit, subsecDigits) {
    return null != smallestUnit ? [ unitNanoMap[smallestUnit], smallestUnit < 4 ? 9 - 3 * smallestUnit : -1 ] : [ void 0 === subsecDigits ? 1 : 10 ** (9 - subsecDigits), subsecDigits ];
  }
  function parseRoundingIncInteger(options) {
    const roundingInc = options[roundingIncName];
    return void 0 === roundingInc ? 1 : toInteger(roundingInc, roundingIncName);
  }
  function refineRoundingInc(roundingInc, smallestUnit, allowManyLargeUnits, solarMode) {
    const upUnitNano = solarMode ? nanoInUtcDay : unitNanoMap[smallestUnit + 1];
    if (upUnitNano) {
      const unitNano = unitNanoMap[smallestUnit];
      if (upUnitNano % ((roundingInc = clampEntity(roundingIncName, roundingInc, 1, upUnitNano / unitNano - (solarMode ? 0 : 1), 1)) * unitNano)) {
        throw new RangeError(invalidEntity(roundingIncName, roundingInc));
      }
    } else {
      roundingInc = clampEntity(roundingIncName, roundingInc, 1, allowManyLargeUnits ? 10 ** 9 : 1, 1);
    }
    return roundingInc;
  }
  function refineSubsecDigits(options) {
    let subsecDigits = options[subsecDigitsName];
    if (void 0 !== subsecDigits) {
      if ("number" != typeof subsecDigits) {
        if ("auto" === toString(subsecDigits)) {
          return;
        }
        throw new RangeError(invalidEntity(subsecDigitsName, subsecDigits));
      }
      subsecDigits = clampEntity(subsecDigitsName, Math.floor(subsecDigits), 0, 9, 1);
    }
    return subsecDigits;
  }
  function normalizeOptions(options) {
    return void 0 === options ? {} : requireObjectLike(options);
  }
  function normalizeUnitNameOptions(options, optionName) {
    return "string" == typeof options ? {
      [optionName]: options
    } : requireObjectLike(options);
  }
  function copyOptions(options) {
    if (void 0 !== options) {
      if (isObjectLike(options)) {
        return Object.assign(Object.create(null), options);
      }
      throw new TypeError(invalidObject);
    }
  }
  function overrideOverflowOptions(options, overflow) {
    return options && Object.assign(Object.create(null), options, {
      overflow: overflowMapNames[overflow]
    });
  }
  function refineUnitOption(optionName, options, maxUnit = 9, minUnit = 0, ensureDefined) {
    let unitStr = options[optionName];
    if (void 0 === unitStr) {
      return ensureDefined ? minUnit : void 0;
    }
    if (unitStr = toString(unitStr), "auto" === unitStr) {
      return ensureDefined ? minUnit : null;
    }
    let unit = unitNameMap[unitStr];
    if (void 0 === unit && (unit = durationFieldIndexes[unitStr]), void 0 === unit) {
      throw new RangeError(invalidEntity(optionName, unitStr));
    }
    return clampEntity(optionName, unit, minUnit, maxUnit, 1), unit;
  }
  function refineChoiceOption(optionName, enumNameMap, options, defaultChoice = 0) {
    const enumArg = options[optionName];
    if (void 0 === enumArg) {
      return defaultChoice;
    }
    const enumStr = toString(enumArg), enumNum = enumNameMap[enumStr];
    if (void 0 === enumNum) {
      throw new RangeError(invalidEntity(optionName, enumStr));
    }
    return enumNum;
  }
  function checkLargestSmallestUnit(largestUnit, smallestUnit) {
    if (smallestUnit > largestUnit) {
      throw new RangeError(flippedSmallestLargestUnit);
    }
  }
  function createInstantSlots(epochNano) {
    return {
      branding: InstantBranding,
      epochNanoseconds: epochNano
    };
  }
  function createZonedDateTimeSlots(epochNano, timeZone, calendar) {
    return {
      branding: ZonedDateTimeBranding,
      calendar: calendar,
      timeZone: timeZone,
      epochNanoseconds: epochNano
    };
  }
  function createPlainDateTimeSlots(isoFields, calendar = isoFields.calendar) {
    return {
      branding: PlainDateTimeBranding,
      calendar: calendar,
      ...pluckProps(isoDateTimeFieldNamesAlpha, isoFields)
    };
  }
  function createPlainDateSlots(isoFields, calendar = isoFields.calendar) {
    return {
      branding: PlainDateBranding,
      calendar: calendar,
      ...pluckProps(isoDateFieldNamesAlpha, isoFields)
    };
  }
  function createPlainYearMonthSlots(isoFields, calendar = isoFields.calendar) {
    return {
      branding: PlainYearMonthBranding,
      calendar: calendar,
      ...pluckProps(isoDateFieldNamesAlpha, isoFields)
    };
  }
  function createPlainMonthDaySlots(isoFields, calendar = isoFields.calendar) {
    return {
      branding: PlainMonthDayBranding,
      calendar: calendar,
      ...pluckProps(isoDateFieldNamesAlpha, isoFields)
    };
  }
  function createPlainTimeSlots(isoFields) {
    return {
      branding: PlainTimeBranding,
      ...pluckProps(isoTimeFieldNamesAlpha, isoFields)
    };
  }
  function createDurationSlots(durationFields) {
    return {
      branding: DurationBranding,
      ...pluckProps(durationFieldNamesAlpha, durationFields)
    };
  }
  function getId(idLike) {
    return "string" == typeof idLike ? idLike : requireString(idLike.id);
  }
  function isIdLikeEqual(idLike0, idLike1) {
    return idLike0 === idLike1 || getId(idLike0) === getId(idLike1);
  }
  function totalDayTimeNano(dayTimeNano, totalUnit) {
    return dayTimeNanoToNumber(dayTimeNano, unitNanoMap[totalUnit], 1);
  }
  function clampRelativeDuration(durationFields, clampUnit, clampDistance, marker, markerToEpochNano, moveMarker) {
    const clampDurationFields = {
      ...durationFieldDefaults,
      [durationFieldNamesAsc[clampUnit]]: clampDistance
    }, marker0 = moveMarker(marker, durationFields), marker1 = moveMarker(marker0, clampDurationFields);
    return [ markerToEpochNano(marker0), markerToEpochNano(marker1) ];
  }
  function computeEpochNanoFrac(epochNano0, epochNano1, epochNanoProgress) {
    const denom = dayTimeNanoToNumber(diffDayTimeNanos(epochNano0, epochNano1));
    if (!denom) {
      throw new RangeError(invalidProtocolResults);
    }
    return dayTimeNanoToNumber(diffDayTimeNanos(epochNano0, epochNanoProgress)) / denom;
  }
  function roundDateTime(isoFields, smallestUnit, roundingInc, roundingMode, timeZoneOps) {
    return 6 === smallestUnit ? ((isoFields, timeZoneOps, roundingMode) => {
      if (timeZoneOps) {
        const nanoInDay = computeNanosecondsInDay(timeZoneOps, isoFields);
        return checkIsoDateTimeInBounds({
          ...moveByIsoDays(isoFields, roundByInc(isoTimeFieldsToNano(isoFields), nanoInDay, roundingMode) / nanoInDay),
          ...isoTimeFieldDefaults
        });
      }
      return roundDateTimeToNano(isoFields, nanoInUtcDay, roundingMode);
    })(isoFields, timeZoneOps, roundingMode) : roundDateTimeToNano(isoFields, computeNanoInc(smallestUnit, roundingInc), roundingMode);
  }
  function roundDateTimeToNano(isoFields, nanoInc, roundingMode) {
    const [roundedIsoFields, dayDelta] = roundTimeToNano(isoFields, nanoInc, roundingMode);
    return checkIsoDateTimeInBounds({
      ...moveByIsoDays(isoFields, dayDelta),
      ...roundedIsoFields
    });
  }
  function roundTimeToNano(isoFields, nanoInc, roundingMode) {
    return nanoToIsoTimeAndDay(roundByInc(isoTimeFieldsToNano(isoFields), nanoInc, roundingMode));
  }
  function balanceDayTimeDuration(durationFields, largestUnit, smallestUnit, roundingInc, roundingMode) {
    return nanoToDurationDayTimeFields(roundDayTimeNano(durationFieldsToDayTimeNano(durationFields, 6), smallestUnit, roundingInc, roundingMode), largestUnit);
  }
  function balanceDayTimeDurationByInc(durationFields, largestUnit, nanoInc, roundingMode) {
    return nanoToDurationDayTimeFields(roundDayTimeNanoByInc(durationFieldsToDayTimeNano(durationFields, largestUnit), nanoInc, roundingMode), largestUnit);
  }
  function roundRelativeDuration(durationFields, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode, marker, markerToEpochNano, moveMarker) {
    const nudgeFunc = markerToEpochNano === identity ? smallestUnit > 6 ? nudgeRelativeDuration : 6 === smallestUnit ? nudgeDurationDayTime : nudgeRelativeDurationTime : smallestUnit > 6 ? nudgeRelativeDuration : nudgeDurationDayTime;
    let [roundedDurationFields, roundedEpochNano, grewBigUnit] = nudgeFunc(durationFields, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode, marker, markerToEpochNano, moveMarker);
    return grewBigUnit && (roundedDurationFields = ((durationFields, endEpochNano, largestUnit, smallestUnit, marker, markerToEpochNano, moveMarker) => {
      const sign = queryDurationSign(durationFields);
      for (let currentUnit = smallestUnit + 1; currentUnit <= largestUnit; currentUnit++) {
        if (7 === currentUnit && 7 !== largestUnit) {
          continue;
        }
        const baseDurationFields = clearDurationFields(durationFields, currentUnit - 1);
        baseDurationFields[durationFieldNamesAsc[currentUnit]] += sign;
        const beyondThreshold = dayTimeNanoToNumber(diffDayTimeNanos(markerToEpochNano(moveMarker(marker, baseDurationFields)), endEpochNano));
        if (beyondThreshold && Math.sign(beyondThreshold) !== sign) {
          break;
        }
        durationFields = baseDurationFields;
      }
      return durationFields;
    })(roundedDurationFields, roundedEpochNano, largestUnit, Math.max(6, smallestUnit), marker, markerToEpochNano, moveMarker)), 
    roundedDurationFields;
  }
  function computeNanoInc(smallestUnit, roundingInc) {
    return unitNanoMap[smallestUnit] * roundingInc;
  }
  function roundByInc(num, inc, roundingMode) {
    return ((num, roundingMode) => roundingModeFuncs[roundingMode](num))(num / inc, roundingMode) * inc;
  }
  function roundToMinute(offsetNano) {
    return roundByInc(offsetNano, nanoInMinute, 7);
  }
  function roundDayTimeNano(dayTimeNano, smallestUnit, roundingInc, roundingMode, useDayOrigin) {
    return 6 === smallestUnit ? [ roundByInc(totalDayTimeNano(dayTimeNano, 6), roundingInc, roundingMode), 0 ] : roundDayTimeNanoByInc(dayTimeNano, computeNanoInc(smallestUnit, roundingInc), roundingMode, useDayOrigin);
  }
  function roundDayTimeNanoByInc(dayTimeNano, nanoInc, roundingMode, useDayOrigin) {
    let [days, timeNano] = dayTimeNano;
    useDayOrigin && timeNano < 0 && (timeNano += nanoInUtcDay, days -= 1);
    const [dayDelta, roundedTimeNano] = divModFloor(roundByInc(timeNano, nanoInc, roundingMode), nanoInUtcDay);
    return createDayTimeNano(days + dayDelta, roundedTimeNano);
  }
  function nudgeDurationDayTime(durationFields, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode) {
    const sign = queryDurationSign(durationFields), dayTimeNano = durationFieldsToDayTimeNano(durationFields, 6), roundedDayTimeNano = roundDayTimeNano(dayTimeNano, smallestUnit, roundingInc, roundingMode), nanoDiff = diffDayTimeNanos(dayTimeNano, roundedDayTimeNano), expandedBigUnit = Math.sign(roundedDayTimeNano[0] - dayTimeNano[0]) === sign, roundedDayTimeFields = nanoToDurationDayTimeFields(roundedDayTimeNano, Math.min(largestUnit, 6));
    return [ {
      ...durationFields,
      ...roundedDayTimeFields
    }, addDayTimeNanos(endEpochNano, nanoDiff), expandedBigUnit ];
  }
  function nudgeRelativeDurationTime(durationFields, endEpochNano, _largestUnit, smallestUnit, roundingInc, roundingMode, marker, markerToEpochNano, moveMarker) {
    const sign = queryDurationSign(durationFields);
    let [dayDelta, timeNano] = givenFieldsToDayTimeNano(durationFields, 5, durationFieldNamesAsc);
    const nanoInc = computeNanoInc(smallestUnit, roundingInc);
    let roundedTimeNano = roundByInc(timeNano, nanoInc, roundingMode);
    const [dayEpochNano0, dayEpochNano1] = clampRelativeDuration({
      ...durationFields,
      ...durationTimeFieldDefaults
    }, 6, sign, marker, markerToEpochNano, moveMarker), beyondDay = roundedTimeNano - dayTimeNanoToNumber(diffDayTimeNanos(dayEpochNano0, dayEpochNano1));
    beyondDay && Math.sign(beyondDay) !== sign ? endEpochNano = addDayTimeNanoAndNumber(dayEpochNano0, roundedTimeNano) : (dayDelta += sign, 
    roundedTimeNano = roundByInc(beyondDay, nanoInc, roundingMode), endEpochNano = addDayTimeNanoAndNumber(dayEpochNano1, roundedTimeNano));
    const durationTimeFields = nanoToDurationTimeFields(roundedTimeNano);
    return [ {
      ...durationFields,
      ...durationTimeFields,
      days: durationFields.days + dayDelta
    }, endEpochNano, Boolean(dayDelta) ];
  }
  function nudgeRelativeDuration(durationFields, endEpochNano, _largestUnit, smallestUnit, roundingInc, roundingMode, marker, markerToEpochNano, moveMarker) {
    const sign = queryDurationSign(durationFields), smallestUnitFieldName = durationFieldNamesAsc[smallestUnit], baseDurationFields = clearDurationFields(durationFields, smallestUnit - 1), truncedVal = divTrunc(durationFields[smallestUnitFieldName], roundingInc) * roundingInc;
    baseDurationFields[smallestUnitFieldName] = truncedVal;
    const [epochNano0, epochNano1] = clampRelativeDuration(baseDurationFields, smallestUnit, roundingInc * sign, marker, markerToEpochNano, moveMarker), exactVal = truncedVal + computeEpochNanoFrac(epochNano0, epochNano1, endEpochNano) * sign * roundingInc, roundedVal = roundByInc(exactVal, roundingInc, roundingMode), expanded = Math.sign(roundedVal - exactVal) === sign;
    return baseDurationFields[smallestUnitFieldName] = roundedVal, [ baseDurationFields, expanded ? epochNano1 : epochNano0, expanded ];
  }
  function formatInstantIso(refineTimeZoneArg, getTimeZoneOps, instantSlots, options) {
    const [timeZoneArg, roundingMode, nanoInc, subsecDigits] = (options => {
      const timeDisplayTuple = refineTimeDisplayTuple(options = normalizeOptions(options));
      return [ options.timeZone, ...timeDisplayTuple ];
    })(options), providedTimeZone = void 0 !== timeZoneArg;
    return ((providedTimeZone, timeZoneOps, epochNano, roundingMode, nanoInc, subsecDigits) => {
      epochNano = roundDayTimeNanoByInc(epochNano, nanoInc, roundingMode, 1);
      const offsetNano = timeZoneOps.getOffsetNanosecondsFor(epochNano);
      return formatIsoDateTimeFields(epochNanoToIso(epochNano, offsetNano), subsecDigits) + (providedTimeZone ? formatOffsetNano(roundToMinute(offsetNano)) : "Z");
    })(providedTimeZone, getTimeZoneOps(providedTimeZone ? refineTimeZoneArg(timeZoneArg) : utcTimeZoneId), instantSlots.epochNanoseconds, roundingMode, nanoInc, subsecDigits);
  }
  function formatZonedDateTimeIso(getTimeZoneOps, zonedDateTimeSlots0, options) {
    return ((getTimeZoneOps, calendarSlot, timeZoneSlot, epochNano, calendarDisplay, timeZoneDisplay, offsetDisplay, roundingMode, nanoInc, subsecDigits) => {
      epochNano = roundDayTimeNanoByInc(epochNano, nanoInc, roundingMode, 1);
      const offsetNano = getTimeZoneOps(timeZoneSlot).getOffsetNanosecondsFor(epochNano);
      return formatIsoDateTimeFields(epochNanoToIso(epochNano, offsetNano), subsecDigits) + formatOffsetNano(roundToMinute(offsetNano), offsetDisplay) + ((timeZoneNative, timeZoneDisplay) => 1 !== timeZoneDisplay ? "[" + (2 === timeZoneDisplay ? "!" : "") + getId(timeZoneNative) + "]" : "")(timeZoneSlot, timeZoneDisplay) + formatCalendar(calendarSlot, calendarDisplay);
    })(getTimeZoneOps, zonedDateTimeSlots0.calendar, zonedDateTimeSlots0.timeZone, zonedDateTimeSlots0.epochNanoseconds, ...(options => {
      options = normalizeOptions(options);
      const calendarDisplay = refineCalendarDisplay(options), subsecDigits = refineSubsecDigits(options), offsetDisplay = refineOffsetDisplay(options), roundingMode = refineRoundingMode(options, 4), smallestUnit = refineSmallestUnit(options, 4);
      return [ calendarDisplay, refineTimeZoneDisplay(options), offsetDisplay, roundingMode, ...refineSmallestUnitAndSubsecDigits(smallestUnit, subsecDigits) ];
    })(options));
  }
  function formatPlainDateTimeIso(plainDateTimeSlots0, options) {
    return ((calendarIdLike, isoFields, calendarDisplay, roundingMode, nanoInc, subsecDigits) => formatIsoDateTimeFields(roundDateTimeToNano(isoFields, nanoInc, roundingMode), subsecDigits) + formatCalendar(calendarIdLike, calendarDisplay))(plainDateTimeSlots0.calendar, plainDateTimeSlots0, ...(options => (options = normalizeOptions(options), 
    [ refineCalendarDisplay(options), ...refineTimeDisplayTuple(options) ]))(options));
  }
  function formatPlainDateIso(plainDateSlots, options) {
    return calendarIdLike = plainDateSlots.calendar, isoFields = plainDateSlots, calendarDisplay = refineDateDisplayOptions(options), 
    formatIsoDateFields(isoFields) + formatCalendar(calendarIdLike, calendarDisplay);
    var calendarIdLike, isoFields, calendarDisplay;
  }
  function formatPlainYearMonthIso(plainYearMonthSlots, options) {
    return formatDateLikeIso(plainYearMonthSlots.calendar, formatIsoYearMonthFields, plainYearMonthSlots, refineDateDisplayOptions(options));
  }
  function formatPlainMonthDayIso(plainMonthDaySlots, options) {
    return formatDateLikeIso(plainMonthDaySlots.calendar, formatIsoMonthDayFields, plainMonthDaySlots, refineDateDisplayOptions(options));
  }
  function formatPlainTimeIso(slots, options) {
    return ((fields, roundingMode, nanoInc, subsecDigits) => formatIsoTimeFields(roundTimeToNano(fields, nanoInc, roundingMode)[0], subsecDigits))(slots, ...refineTimeDisplayOptions(options));
  }
  function formatDurationIso(slots, options) {
    const [roundingMode, nanoInc, subsecDigits] = refineTimeDisplayOptions(options, 3);
    return nanoInc > 1 && (slots = {
      ...slots,
      ...balanceDayTimeDurationByInc(slots, Math.min(getLargestDurationUnit(slots), 6), nanoInc, roundingMode)
    }), ((durationFields, subsecDigits) => {
      const sign = queryDurationSign(durationFields), abs = -1 === sign ? negateDurationFields(durationFields) : durationFields, {hours: hours, minutes: minutes} = abs, [wholeSeconds, subsecNano] = dayTimeNanoToNumberRemainder(givenFieldsToDayTimeNano(abs, 3, durationFieldNamesAsc), nanoInSec), subsecNanoString = formatSubsecNano(subsecNano, subsecDigits), forceSeconds = subsecDigits >= 0 || !sign || subsecNanoString;
      return (sign < 0 ? "-" : "") + "P" + formatDurationFragments({
        Y: formatNumberUnscientific(abs.years),
        M: formatNumberUnscientific(abs.months),
        W: formatNumberUnscientific(abs.weeks),
        D: formatNumberUnscientific(abs.days)
      }) + (hours || minutes || wholeSeconds || forceSeconds ? "T" + formatDurationFragments({
        H: formatNumberUnscientific(hours),
        M: formatNumberUnscientific(minutes),
        S: formatNumberUnscientific(wholeSeconds, forceSeconds) + subsecNanoString
      }) : "");
    })(slots, subsecDigits);
  }
  function formatDateLikeIso(calendarIdLike, formatSimple, isoFields, calendarDisplay) {
    const calendarId = getId(calendarIdLike), showCalendar = calendarDisplay > 1 || 0 === calendarDisplay && calendarId !== isoCalendarId;
    return 1 === calendarDisplay ? calendarId === isoCalendarId ? formatSimple(isoFields) : formatIsoDateFields(isoFields) : showCalendar ? formatIsoDateFields(isoFields) + formatCalendarId(calendarId, 2 === calendarDisplay) : formatSimple(isoFields);
  }
  function formatDurationFragments(fragObj) {
    const parts = [];
    for (const fragName in fragObj) {
      const fragVal = fragObj[fragName];
      fragVal && parts.push(fragVal, fragName);
    }
    return parts.join("");
  }
  function formatIsoDateTimeFields(isoDateTimeFields, subsecDigits) {
    return formatIsoDateFields(isoDateTimeFields) + "T" + formatIsoTimeFields(isoDateTimeFields, subsecDigits);
  }
  function formatIsoDateFields(isoDateFields) {
    return formatIsoYearMonthFields(isoDateFields) + "-" + padNumber2(isoDateFields.isoDay);
  }
  function formatIsoYearMonthFields(isoDateFields) {
    const {isoYear: isoYear} = isoDateFields;
    return (isoYear < 0 || isoYear > 9999 ? getSignStr(isoYear) + padNumber(6, Math.abs(isoYear)) : padNumber(4, isoYear)) + "-" + padNumber2(isoDateFields.isoMonth);
  }
  function formatIsoMonthDayFields(isoDateFields) {
    return padNumber2(isoDateFields.isoMonth) + "-" + padNumber2(isoDateFields.isoDay);
  }
  function formatIsoTimeFields(isoTimeFields, subsecDigits) {
    const parts = [ padNumber2(isoTimeFields.isoHour), padNumber2(isoTimeFields.isoMinute) ];
    return -1 !== subsecDigits && parts.push(padNumber2(isoTimeFields.isoSecond) + ((isoMillisecond, isoMicrosecond, isoNanosecond, subsecDigits) => formatSubsecNano(isoMillisecond * nanoInMilli + isoMicrosecond * nanoInMicro + isoNanosecond, subsecDigits))(isoTimeFields.isoMillisecond, isoTimeFields.isoMicrosecond, isoTimeFields.isoNanosecond, subsecDigits)), 
    parts.join(":");
  }
  function formatOffsetNano(offsetNano, offsetDisplay = 0) {
    if (1 === offsetDisplay) {
      return "";
    }
    const [hour, nanoRemainder0] = divModFloor(Math.abs(offsetNano), nanoInHour), [minute, nanoRemainder1] = divModFloor(nanoRemainder0, nanoInMinute), [second, nanoRemainder2] = divModFloor(nanoRemainder1, nanoInSec);
    return getSignStr(offsetNano) + padNumber2(hour) + ":" + padNumber2(minute) + (second || nanoRemainder2 ? ":" + padNumber2(second) + formatSubsecNano(nanoRemainder2) : "");
  }
  function formatCalendar(calendarIdLike, calendarDisplay) {
    if (1 !== calendarDisplay) {
      const calendarId = getId(calendarIdLike);
      if (calendarDisplay > 1 || 0 === calendarDisplay && calendarId !== isoCalendarId) {
        return formatCalendarId(calendarId, 2 === calendarDisplay);
      }
    }
    return "";
  }
  function formatCalendarId(calendarId, isCritical) {
    return "[" + (isCritical ? "!" : "") + "u-ca=" + calendarId + "]";
  }
  function formatSubsecNano(totalNano, subsecDigits) {
    let s = padNumber(9, totalNano);
    return s = void 0 === subsecDigits ? s.replace(trailingZerosRE, "") : s.slice(0, subsecDigits), 
    s ? "." + s : "";
  }
  function getSignStr(num) {
    return num < 0 ? "-" : "+";
  }
  function formatNumberUnscientific(n, force) {
    return n || force ? n.toLocaleString("fullwide", {
      useGrouping: 0
    }) : "";
  }
  function zonedEpochNanoToIso(timeZoneOps, epochNano) {
    return epochNanoToIso(epochNano, timeZoneOps.getOffsetNanosecondsFor(epochNano));
  }
  function getMatchingInstantFor(timeZoneOps, isoFields, offsetNano, offsetDisambig = 0, epochDisambig = 0, epochFuzzy, hasZ) {
    if (void 0 !== offsetNano && 1 === offsetDisambig && (1 === offsetDisambig || hasZ)) {
      return isoToEpochNanoWithOffset(isoFields, offsetNano);
    }
    const possibleEpochNanos = timeZoneOps.getPossibleInstantsFor(isoFields);
    if (void 0 !== offsetNano && 3 !== offsetDisambig) {
      const matchingEpochNano = ((possibleEpochNanos, isoDateTimeFields, offsetNano, fuzzy) => {
        const zonedEpochNano = isoToEpochNano(isoDateTimeFields);
        fuzzy && (offsetNano = roundToMinute(offsetNano));
        for (const possibleEpochNano of possibleEpochNanos) {
          let possibleOffsetNano = dayTimeNanoToNumber(diffDayTimeNanos(possibleEpochNano, zonedEpochNano));
          if (fuzzy && (possibleOffsetNano = roundToMinute(possibleOffsetNano)), possibleOffsetNano === offsetNano) {
            return possibleEpochNano;
          }
        }
      })(possibleEpochNanos, isoFields, offsetNano, epochFuzzy);
      if (void 0 !== matchingEpochNano) {
        return matchingEpochNano;
      }
      if (0 === offsetDisambig) {
        throw new RangeError(invalidOffsetForTimeZone);
      }
    }
    return hasZ ? isoToEpochNano(isoFields) : getSingleInstantFor(timeZoneOps, isoFields, epochDisambig, possibleEpochNanos);
  }
  function getSingleInstantFor(timeZoneOps, isoFields, disambig = 0, possibleEpochNanos = timeZoneOps.getPossibleInstantsFor(isoFields)) {
    if (1 === possibleEpochNanos.length) {
      return possibleEpochNanos[0];
    }
    if (1 === disambig) {
      throw new RangeError(ambigOffset);
    }
    if (possibleEpochNanos.length) {
      return possibleEpochNanos[3 === disambig ? 1 : 0];
    }
    const zonedEpochNano = isoToEpochNano(isoFields), gapNano = ((timeZoneOps, zonedEpochNano) => {
      const startOffsetNano = timeZoneOps.getOffsetNanosecondsFor(addDayTimeNanoAndNumber(zonedEpochNano, -nanoInUtcDay));
      return timeZoneOps.getOffsetNanosecondsFor(addDayTimeNanoAndNumber(zonedEpochNano, nanoInUtcDay)) - startOffsetNano;
    })(timeZoneOps, zonedEpochNano), shiftNano = gapNano * (2 === disambig ? -1 : 1);
    return (possibleEpochNanos = timeZoneOps.getPossibleInstantsFor(epochNanoToIso(zonedEpochNano, shiftNano)))[2 === disambig ? 0 : possibleEpochNanos.length - 1];
  }
  function computeNanosecondsInDay(timeZoneOps, isoFields) {
    isoFields = {
      ...isoFields,
      ...isoTimeFieldDefaults
    };
    const nanoInDay = dayTimeNanoToNumber(diffDayTimeNanos(getSingleInstantFor(timeZoneOps, {
      ...isoFields,
      ...isoTimeFieldDefaults
    }), getSingleInstantFor(timeZoneOps, {
      ...moveByIsoDays(isoFields, 1),
      ...isoTimeFieldDefaults
    })));
    if (nanoInDay <= 0) {
      throw new RangeError(invalidProtocolResults);
    }
    return nanoInDay;
  }
  function validateTimeZoneOffset(offsetNano) {
    if (Math.abs(offsetNano) >= nanoInUtcDay) {
      throw new RangeError(outOfBoundsOffset);
    }
    return offsetNano;
  }
  function moveInstant(doSubtract, instantSlots, durationSlots) {
    return createInstantSlots(checkEpochNanoInBounds(addDayTimeNanos(instantSlots.epochNanoseconds, (fields => {
      if (durationHasDateParts(fields)) {
        throw new RangeError(invalidLargeUnits);
      }
      return durationFieldsToDayTimeNano(fields, 5);
    })(doSubtract ? negateDurationFields(durationSlots) : durationSlots))));
  }
  function moveZonedDateTime(getCalendarOps, getTimeZoneOps, doSubtract, zonedDateTimeSlots, durationSlots, options = Object.create(null)) {
    const timeZoneOps = getTimeZoneOps(zonedDateTimeSlots.timeZone), movedEpochNanoseconds = moveZonedEpochNano(getCalendarOps(zonedDateTimeSlots.calendar), timeZoneOps, zonedDateTimeSlots.epochNanoseconds, doSubtract ? negateDurationFields(durationSlots) : durationSlots, options);
    return {
      ...zonedDateTimeSlots,
      epochNanoseconds: movedEpochNanoseconds
    };
  }
  function movePlainDateTime(getCalendarOps, doSubtract, plainDateTimeSlots, durationSlots, options = Object.create(null)) {
    return createPlainDateTimeSlots({
      ...plainDateTimeSlots,
      ...moveDateTime(getCalendarOps(plainDateTimeSlots.calendar), plainDateTimeSlots, doSubtract ? negateDurationFields(durationSlots) : durationSlots, options)
    });
  }
  function movePlainDate(getCalendarOps, doSubtract, plainDateSlots, durationSlots, options) {
    return {
      ...plainDateSlots,
      ...moveDateEfficient(getCalendarOps(plainDateSlots.calendar), plainDateSlots, doSubtract ? negateDurationFields(durationSlots) : durationSlots, options)
    };
  }
  function movePlainYearMonth(getCalendarOps, doSubtract, plainYearMonthSlots, durationFields, options = Object.create(null)) {
    const calendarSlot = plainYearMonthSlots.calendar, calendarOps = getCalendarOps(calendarSlot);
    let isoDateFields = moveToMonthStart(calendarOps, plainYearMonthSlots);
    doSubtract && (durationFields = negateDuration(durationFields)), queryDurationSign(durationFields) < 0 && (isoDateFields = calendarOps.dateAdd(isoDateFields, {
      ...durationFieldDefaults,
      months: 1
    }), isoDateFields = moveByIsoDays(isoDateFields, -1));
    const movedIsoDateFields = calendarOps.dateAdd(isoDateFields, durationFields, options);
    return createPlainYearMonthSlots(moveToMonthStart(calendarOps, movedIsoDateFields), calendarSlot);
  }
  function movePlainTime(doSubtract, slots, durationSlots) {
    return createPlainTimeSlots(moveTime(slots, doSubtract ? negateDurationFields(durationSlots) : durationSlots)[0]);
  }
  function moveZonedEpochNano(calendarOps, timeZoneOps, epochNano, durationFields, options) {
    const dayTimeNano = durationFieldsToDayTimeNano(durationFields, 5);
    if (durationHasDateParts(durationFields)) {
      const isoDateTimeFields = zonedEpochNanoToIso(timeZoneOps, epochNano);
      epochNano = addDayTimeNanos(getSingleInstantFor(timeZoneOps, {
        ...moveDateEfficient(calendarOps, isoDateTimeFields, {
          ...durationFields,
          ...durationTimeFieldDefaults
        }, options),
        ...pluckProps(isoTimeFieldNamesAsc, isoDateTimeFields),
        calendar: isoCalendarId
      }), dayTimeNano);
    } else {
      epochNano = addDayTimeNanos(epochNano, dayTimeNano), refineOverflowOptions(options);
    }
    return checkEpochNanoInBounds(epochNano);
  }
  function moveDateTime(calendarOps, isoDateTimeFields, durationFields, options) {
    const [movedIsoTimeFields, dayDelta] = moveTime(isoDateTimeFields, durationFields);
    return checkIsoDateTimeInBounds({
      ...moveDateEfficient(calendarOps, isoDateTimeFields, {
        ...durationFields,
        ...durationTimeFieldDefaults,
        days: durationFields.days + dayDelta
      }, options),
      ...movedIsoTimeFields
    });
  }
  function moveDateEfficient(calendarOps, isoDateFields, durationFields, options) {
    if (durationFields.years || durationFields.months || durationFields.weeks) {
      return calendarOps.dateAdd(isoDateFields, durationFields, options);
    }
    refineOverflowOptions(options);
    const days = durationFields.days + givenFieldsToDayTimeNano(durationFields, 5, durationFieldNamesAsc)[0];
    return days ? checkIsoDateInBounds(moveByIsoDays(isoDateFields, days)) : isoDateFields;
  }
  function moveToMonthStart(calendarOps, isoFields) {
    return moveByIsoDays(isoFields, 1 - calendarOps.day(isoFields));
  }
  function moveTime(isoFields, durationFields) {
    const [durDays, durTimeNano] = givenFieldsToDayTimeNano(durationFields, 5, durationFieldNamesAsc), [newIsoFields, overflowDays] = nanoToIsoTimeAndDay(isoTimeFieldsToNano(isoFields) + durTimeNano);
    return [ newIsoFields, durDays + overflowDays ];
  }
  function nativeDateAdd(isoDateFields, durationFields, options) {
    const overflow = refineOverflowOptions(options);
    let epochMilli, {years: years, months: months, weeks: weeks, days: days} = durationFields;
    if (days += givenFieldsToDayTimeNano(durationFields, 5, durationFieldNamesAsc)[0], 
    years || months) {
      let [year, month, day] = this.dateParts(isoDateFields);
      if (years) {
        const [monthCodeNumber, isLeapMonth] = this.monthCodeParts(year, month);
        year += years, month = monthCodeNumberToMonth(monthCodeNumber, isLeapMonth, this.leapMonth(year)), 
        month = clampEntity("month", month, 1, this.monthsInYearPart(year), overflow);
      }
      months && ([year, month] = this.monthAdd(year, month, months)), day = clampEntity("day", day, 1, this.daysInMonthParts(year, month), overflow), 
      epochMilli = this.epochMilli(year, month, day);
    } else {
      if (!weeks && !days) {
        return isoDateFields;
      }
      epochMilli = isoToEpochMilli(isoDateFields);
    }
    return epochMilli += (weeks * isoDaysInWeek + days) * milliInDay, checkIsoDateInBounds(epochMilliToIso(epochMilli));
  }
  function moveByIsoDays(isoDateFields, days) {
    return days && (isoDateFields = epochMilliToIso(isoToEpochMilli(isoDateFields) + days * milliInDay)), 
    isoDateFields;
  }
  function createMarkerSystem(getCalendarOps, getTimeZoneOps, markerSlots) {
    const {calendar: calendar, timeZone: timeZone, epochNanoseconds: epochNanoseconds} = markerSlots, calendarOps = getCalendarOps(calendar);
    if (epochNanoseconds) {
      const timeZoneOps = getTimeZoneOps(timeZone);
      return [ epochNanoseconds, identity, bindArgs(moveZonedEpochNano, calendarOps, timeZoneOps), bindArgs(diffZonedEpochNanoExact, calendarOps, timeZoneOps) ];
    }
    return [ {
      ...markerSlots,
      ...isoTimeFieldDefaults
    }, isoToEpochNano, bindArgs(moveDateTime, calendarOps), bindArgs(diffDateTimesExact, calendarOps) ];
  }
  function spanDuration(durationFields0, durationFields1, largestUnit, marker, markerToEpochNano, moveMarker, diffMarkers) {
    let endMarker = moveMarker(marker, durationFields0);
    return durationFields1 && (endMarker = moveMarker(endMarker, durationFields1)), 
    [ diffMarkers(marker, endMarker, largestUnit), markerToEpochNano(endMarker) ];
  }
  function addDurations(refineRelativeTo, getCalendarOps, getTimeZoneOps, doSubtract, slots, otherSlots, options) {
    const markerSlots = refineRelativeTo(normalizeOptions(options).relativeTo), largestUnit = Math.max(getLargestDurationUnit(slots), getLargestDurationUnit(otherSlots));
    if (largestUnit < 6 || 6 === largestUnit && (!markerSlots || !markerSlots.epochNanoseconds)) {
      return createDurationSlots(((a, b, largestUnit, doSubtract) => {
        const combined = addDayTimeNanos(durationFieldsToDayTimeNano(a, 6), durationFieldsToDayTimeNano(b, 6), doSubtract ? -1 : 1);
        if (!Number.isFinite(combined[0])) {
          throw new RangeError(outOfBoundsDate);
        }
        return {
          ...durationFieldDefaults,
          ...nanoToDurationDayTimeFields(combined, largestUnit)
        };
      })(slots, otherSlots, largestUnit, doSubtract));
    }
    if (!markerSlots) {
      throw new RangeError("Missing relativeTo");
    }
    return doSubtract && (otherSlots = negateDurationFields(otherSlots)), createDurationSlots(spanDuration(slots, otherSlots, largestUnit, ...createMarkerSystem(getCalendarOps, getTimeZoneOps, markerSlots))[0]);
  }
  function negateDuration(slots) {
    return createDurationSlots(negateDurationFields(slots));
  }
  function negateDurationFields(fields) {
    const res = {};
    for (const fieldName of durationFieldNamesAsc) {
      res[fieldName] = -1 * fields[fieldName] || 0;
    }
    return res;
  }
  function computeDurationSign(fields, fieldNames = durationFieldNamesAsc) {
    let sign = 0;
    for (const fieldName of fieldNames) {
      const fieldSign = Math.sign(fields[fieldName]);
      if (fieldSign) {
        if (sign && sign !== fieldSign) {
          throw new RangeError(forbiddenDurationSigns);
        }
        sign = fieldSign;
      }
    }
    return sign;
  }
  function checkDurationFields(fields) {
    return queryDurationSign(fields), fields;
  }
  function durationFieldsToDayTimeNano(fields, largestUnit) {
    return givenFieldsToDayTimeNano(fields, largestUnit, durationFieldNamesAsc);
  }
  function nanoToDurationDayTimeFields(dayTimeNano, largestUnit = 6) {
    const [days, timeNano] = dayTimeNano, dayTimeFields = nanoToGivenFields(timeNano, largestUnit, durationFieldNamesAsc);
    if (dayTimeFields[durationFieldNamesAsc[largestUnit]] += days * (nanoInUtcDay / unitNanoMap[largestUnit]), 
    !Number.isFinite(dayTimeFields[durationFieldNamesAsc[largestUnit]])) {
      throw new RangeError(outOfBoundsDate);
    }
    return dayTimeFields;
  }
  function nanoToDurationTimeFields(nano, largestUnit = 5) {
    return nanoToGivenFields(nano, largestUnit, durationFieldNamesAsc);
  }
  function clearDurationFields(durationFields, largestUnitToClear) {
    const copy = {
      ...durationFields
    };
    for (let unit = 0; unit <= largestUnitToClear; unit++) {
      copy[durationFieldNamesAsc[unit]] = 0;
    }
    return copy;
  }
  function durationHasDateParts(fields) {
    return Boolean(computeDurationSign(fields, durationDateFieldNamesAsc));
  }
  function getLargestDurationUnit(fields) {
    let unit = 9;
    for (;unit > 0 && !fields[durationFieldNamesAsc[unit]]; unit--) {}
    return unit;
  }
  function createSplitTuple(startEpochSec, endEpochSec) {
    return [ startEpochSec, endEpochSec ];
  }
  function computePeriod(epochSec) {
    const startEpochSec = Math.floor(epochSec / periodDur) * periodDur;
    return [ startEpochSec, startEpochSec + periodDur ];
  }
  function parseOffsetNano(s) {
    const offsetNano = parseOffsetNanoMaybe(s);
    if (void 0 === offsetNano) {
      throw new RangeError(failedParse(s));
    }
    return offsetNano;
  }
  function parsePlainDate(s) {
    const organized = parseDateTimeLike(requireString(s));
    if (!organized || organized.hasZ) {
      throw new RangeError(failedParse(s));
    }
    return createPlainDateSlots(organized.hasTime ? finalizeDateTime(organized) : finalizeDate(organized));
  }
  function requireIsoCalendar(organized) {
    if (organized.calendar !== isoCalendarId) {
      throw new RangeError(invalidSubstring(organized.calendar));
    }
  }
  function finalizeZonedDateTime(organized, offsetNano, offsetDisambig = 0, epochDisambig = 0) {
    const slotId = resolveTimeZoneId(organized.timeZone), timeZoneImpl = queryNativeTimeZone(slotId);
    return createZonedDateTimeSlots(getMatchingInstantFor(timeZoneImpl, checkIsoDateTimeFields(organized), offsetNano, offsetDisambig, epochDisambig, !timeZoneImpl.offsetNano, organized.hasZ), slotId, resolveCalendarId(organized.calendar));
  }
  function finalizeDateTime(organized) {
    return resolveSlotsCalendar(checkIsoDateTimeInBounds(checkIsoDateTimeFields(organized)));
  }
  function finalizeDate(organized) {
    return resolveSlotsCalendar(checkIsoDateInBounds(checkIsoDateFields(organized)));
  }
  function resolveSlotsCalendar(organized) {
    return {
      ...organized,
      calendar: resolveCalendarId(organized.calendar)
    };
  }
  function parseDateTimeLike(s) {
    const parts = dateTimeRegExp.exec(s);
    return parts ? (parts => {
      const zOrOffset = parts[10], hasZ = "Z" === (zOrOffset || "").toUpperCase();
      return {
        isoYear: organizeIsoYearParts(parts),
        isoMonth: parseInt(parts[4]),
        isoDay: parseInt(parts[5]),
        ...organizeTimeParts(parts.slice(5)),
        ...organizeAnnotationParts(parts[16]),
        hasTime: Boolean(parts[6]),
        hasZ: hasZ,
        offset: hasZ ? void 0 : zOrOffset
      };
    })(parts) : void 0;
  }
  function parseYearMonthOnly(s) {
    const parts = yearMonthRegExp.exec(s);
    return parts ? (parts => ({
      isoYear: organizeIsoYearParts(parts),
      isoMonth: parseInt(parts[4]),
      isoDay: 1,
      ...organizeAnnotationParts(parts[5])
    }))(parts) : void 0;
  }
  function parseMonthDayOnly(s) {
    const parts = monthDayRegExp.exec(s);
    return parts ? (parts => ({
      isoYear: isoEpochFirstLeapYear,
      isoMonth: parseInt(parts[1]),
      isoDay: parseInt(parts[2]),
      ...organizeAnnotationParts(parts[3])
    }))(parts) : void 0;
  }
  function parseOffsetNanoMaybe(s, onlyHourMinute) {
    const parts = offsetRegExp.exec(s);
    return parts ? ((parts, onlyHourMinute) => {
      const firstSubMinutePart = parts[4] || parts[5];
      if (onlyHourMinute && firstSubMinutePart) {
        throw new RangeError(invalidSubstring(firstSubMinutePart));
      }
      return validateTimeZoneOffset((parseInt0(parts[2]) * nanoInHour + parseInt0(parts[3]) * nanoInMinute + parseInt0(parts[4]) * nanoInSec + parseSubsecNano(parts[5] || "")) * parseSign(parts[1]));
    })(parts, onlyHourMinute) : void 0;
  }
  function organizeIsoYearParts(parts) {
    const yearSign = parseSign(parts[1]), year = parseInt(parts[2] || parts[3]);
    if (yearSign < 0 && !year) {
      throw new RangeError(invalidSubstring(-0));
    }
    return yearSign * year;
  }
  function organizeTimeParts(parts) {
    const isoSecond = parseInt0(parts[3]);
    return {
      ...nanoToIsoTimeAndDay(parseSubsecNano(parts[4] || ""))[0],
      isoHour: parseInt0(parts[1]),
      isoMinute: parseInt0(parts[2]),
      isoSecond: 60 === isoSecond ? 59 : isoSecond
    };
  }
  function organizeAnnotationParts(s) {
    let calendarIsCritical, timeZoneId;
    const calendarIds = [];
    if (s.replace(annotationRegExp, ((whole, criticalStr, mainStr) => {
      const isCritical = Boolean(criticalStr), [val, name] = mainStr.split("=").reverse();
      if (name) {
        if ("u-ca" === name) {
          calendarIds.push(val), calendarIsCritical || (calendarIsCritical = isCritical);
        } else if (isCritical) {
          throw new RangeError(invalidSubstring(whole));
        }
      } else {
        if (timeZoneId) {
          throw new RangeError(invalidSubstring(whole));
        }
        timeZoneId = val;
      }
      return "";
    })), calendarIds.length > 1 && calendarIsCritical) {
      throw new RangeError(invalidSubstring(s));
    }
    return {
      timeZone: timeZoneId,
      calendar: calendarIds[0] || isoCalendarId
    };
  }
  function parseSubsecNano(fracStr) {
    return parseInt(fracStr.padEnd(9, "0"));
  }
  function createRegExp(meat) {
    return new RegExp(`^${meat}$`, "i");
  }
  function parseSign(s) {
    return s && "+" !== s ? -1 : 1;
  }
  function parseInt0(s) {
    return void 0 === s ? 0 : parseInt(s);
  }
  function resolveTimeZoneId(id) {
    const essence = getTimeZoneEssence(id);
    return "number" == typeof essence ? formatOffsetNano(essence) : essence ? (id => id.toLowerCase().split("/").map(((part, partI) => (part.length <= 3 || /\d/.test(part)) && !/etc|yap/.test(part) ? part.toUpperCase() : part.replace(/baja|dumont|[a-z]+/g, ((a, i) => a.length <= 2 && !partI || "in" === a || "chat" === a ? a.toUpperCase() : a.length > 2 || !i ? capitalize(a).replace(/island|noronha|murdo|rivadavia|urville/, capitalize) : a)))).join("/"))(id) : utcTimeZoneId;
  }
  function getTimeZoneAtomic(id) {
    const essence = getTimeZoneEssence(id);
    return "number" == typeof essence ? essence : essence ? essence.resolvedOptions().timeZone : utcTimeZoneId;
  }
  function getTimeZoneEssence(id) {
    const offsetNano = parseOffsetNanoMaybe(id = id.toUpperCase(), 1);
    return void 0 !== offsetNano ? offsetNano : id !== utcTimeZoneId ? queryTimeZoneIntlFormat(id) : void 0;
  }
  function compareInstants(instantSlots0, instantSlots1) {
    return compareDayTimeNanos(instantSlots0.epochNanoseconds, instantSlots1.epochNanoseconds);
  }
  function compareZonedDateTimes(zonedDateTimeSlots0, zonedDateTimeSlots1) {
    return compareDayTimeNanos(zonedDateTimeSlots0.epochNanoseconds, zonedDateTimeSlots1.epochNanoseconds);
  }
  function compareIsoDateTimeFields(isoFields0, isoFields1) {
    return compareIsoDateFields(isoFields0, isoFields1) || compareIsoTimeFields(isoFields0, isoFields1);
  }
  function compareIsoDateFields(isoFields0, isoFields1) {
    return compareNumbers(isoToEpochMilli(isoFields0), isoToEpochMilli(isoFields1));
  }
  function compareIsoTimeFields(isoFields0, isoFields1) {
    return compareNumbers(isoTimeFieldsToNano(isoFields0), isoTimeFieldsToNano(isoFields1));
  }
  function isTimeZoneSlotsEqual(a, b) {
    if (a === b) {
      return 1;
    }
    const aId = getId(a), bId = getId(b);
    if (aId === bId) {
      return 1;
    }
    try {
      return getTimeZoneAtomic(aId) === getTimeZoneAtomic(bId);
    } catch (_a) {}
  }
  function diffInstants(invert, instantSlots0, instantSlots1, options) {
    const optionsTuple = refineDiffOptions(invert, copyOptions(options), 3, 5), durationFields = diffEpochNano(instantSlots0.epochNanoseconds, instantSlots1.epochNanoseconds, ...optionsTuple);
    return createDurationSlots(invert ? negateDurationFields(durationFields) : durationFields);
  }
  function diffZonedDateTimes(getCalendarOps, getTimeZoneOps, invert, zonedDateTimeSlots0, zonedDateTimeSlots1, options) {
    const calendarSlot = getCommonCalendarSlot(zonedDateTimeSlots0.calendar, zonedDateTimeSlots1.calendar), optionsCopy = copyOptions(options), [largestUnit, smallestUnit, roundingInc, roundingMode] = refineDiffOptions(invert, optionsCopy, 5), startEpochNano = zonedDateTimeSlots0.epochNanoseconds, endEpochNano = zonedDateTimeSlots1.epochNanoseconds, sign = compareDayTimeNanos(endEpochNano, startEpochNano);
    let durationFields;
    if (sign) {
      if (largestUnit < 6) {
        durationFields = diffEpochNano(startEpochNano, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode);
      } else {
        const timeZoneOps = getTimeZoneOps(((a, b) => {
          if (!isTimeZoneSlotsEqual(a, b)) {
            throw new RangeError(mismatchingTimeZones);
          }
          return a;
        })(zonedDateTimeSlots0.timeZone, zonedDateTimeSlots1.timeZone)), calendarOps = getCalendarOps(calendarSlot);
        durationFields = diffZonedEpochNanoViaCalendar(calendarOps, timeZoneOps, sign, startEpochNano, endEpochNano, largestUnit, optionsCopy), 
        !sign || 0 === smallestUnit && 1 === roundingInc || (durationFields = roundRelativeDuration(durationFields, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode, startEpochNano, identity, bindArgs(moveZonedEpochNano, calendarOps, timeZoneOps)));
      }
    } else {
      durationFields = durationFieldDefaults;
    }
    return createDurationSlots(invert ? negateDurationFields(durationFields) : durationFields);
  }
  function diffPlainDateTimes(getCalendarOps, invert, plainDateTimeSlots0, plainDateTimeSlots1, options) {
    const calendarSlot = getCommonCalendarSlot(plainDateTimeSlots0.calendar, plainDateTimeSlots1.calendar), optionsCopy = copyOptions(options), [largestUnit, smallestUnit, roundingInc, roundingMode] = refineDiffOptions(invert, optionsCopy, 6), startEpochNano = isoToEpochNano(plainDateTimeSlots0), endEpochNano = isoToEpochNano(plainDateTimeSlots1), sign = compareDayTimeNanos(endEpochNano, startEpochNano);
    let durationFields;
    if (sign) {
      if (largestUnit <= 6) {
        durationFields = diffEpochNano(startEpochNano, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode);
      } else {
        const calendarOps = getCalendarOps(calendarSlot);
        durationFields = diffDateTimesViaCalendar(calendarOps, sign, plainDateTimeSlots0, plainDateTimeSlots1, largestUnit, optionsCopy), 
        !sign || 0 === smallestUnit && 1 === roundingInc || (durationFields = roundRelativeDuration(durationFields, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode, plainDateTimeSlots0, isoToEpochNano, bindArgs(moveDateTime, calendarOps)));
      }
    } else {
      durationFields = durationFieldDefaults;
    }
    return createDurationSlots(invert ? negateDurationFields(durationFields) : durationFields);
  }
  function diffPlainDates(getCalendarOps, invert, plainDateSlots0, plainDateSlots1, options) {
    const calendarSlot = getCommonCalendarSlot(plainDateSlots0.calendar, plainDateSlots1.calendar), optionsCopy = copyOptions(options);
    return diffDateLike(invert || 0, (() => getCalendarOps(calendarSlot)), plainDateSlots0, plainDateSlots1, ...refineDiffOptions(invert, optionsCopy, 6, 9, 6), optionsCopy);
  }
  function diffPlainYearMonth(getCalendarOps, invert, plainYearMonthSlots0, plainYearMonthSlots1, options) {
    const calendarSlot = getCommonCalendarSlot(plainYearMonthSlots0.calendar, plainYearMonthSlots1.calendar), optionsCopy = copyOptions(options), optionsTuple = refineDiffOptions(invert, optionsCopy, 9, 9, 8), calendarOps = getCalendarOps(calendarSlot);
    return diffDateLike(invert || 0, (() => calendarOps), moveToMonthStart(calendarOps, plainYearMonthSlots0), moveToMonthStart(calendarOps, plainYearMonthSlots1), ...optionsTuple, optionsCopy);
  }
  function diffDateLike(invert, getCalendarOps, startIsoFields, endIsoFields, largestUnit, smallestUnit, roundingInc, roundingMode, origOptions) {
    const startEpochNano = isoToEpochNano(startIsoFields), endEpochNano = isoToEpochNano(endIsoFields);
    let durationFields;
    if (compareDayTimeNanos(endEpochNano, startEpochNano)) {
      let calendarOps;
      6 === largestUnit ? durationFields = diffByDay(startIsoFields, endIsoFields) : (calendarOps = getCalendarOps(), 
      durationFields = calendarOps.dateUntil(startIsoFields, endIsoFields, largestUnit, origOptions)), 
      6 === smallestUnit && 1 === roundingInc || (calendarOps || (calendarOps = getCalendarOps()), 
      durationFields = roundRelativeDuration(durationFields, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode, startIsoFields, isoToEpochNano, ((m, d) => calendarOps.dateAdd(m, d))));
    } else {
      durationFields = durationFieldDefaults;
    }
    return createDurationSlots(invert ? negateDurationFields(durationFields) : durationFields);
  }
  function diffPlainTimes(invert, plainTimeSlots0, plainTimeSlots1, options) {
    const optionsCopy = copyOptions(options), [largestUnit, smallestUnit, roundingInc, roundingMode] = refineDiffOptions(invert, optionsCopy, 5, 5), startTimeNano = isoTimeFieldsToNano(plainTimeSlots0), timeNano = roundByInc(isoTimeFieldsToNano(plainTimeSlots1) - startTimeNano, computeNanoInc(smallestUnit, roundingInc), roundingMode), durationFields = {
      ...durationFieldDefaults,
      ...nanoToDurationTimeFields(timeNano, largestUnit)
    };
    return createDurationSlots(invert ? negateDurationFields(durationFields) : durationFields);
  }
  function diffZonedEpochNanoExact(calendarOps, timeZoneOps, startEpochNano, endEpochNano, largestUnit, origOptions) {
    const sign = compareDayTimeNanos(endEpochNano, startEpochNano);
    return sign ? largestUnit < 6 ? diffEpochNanoExact(startEpochNano, endEpochNano, largestUnit) : diffZonedEpochNanoViaCalendar(calendarOps, timeZoneOps, sign, startEpochNano, endEpochNano, largestUnit, origOptions) : durationFieldDefaults;
  }
  function diffDateTimesExact(calendarOps, startIsoFields, endIsoFields, largestUnit, origOptions) {
    const startEpochNano = isoToEpochNano(startIsoFields), endEpochNano = isoToEpochNano(endIsoFields), sign = compareDayTimeNanos(endEpochNano, startEpochNano);
    return sign ? largestUnit <= 6 ? diffEpochNanoExact(startEpochNano, endEpochNano, largestUnit) : diffDateTimesViaCalendar(calendarOps, sign, startIsoFields, endIsoFields, largestUnit, origOptions) : durationFieldDefaults;
  }
  function diffZonedEpochNanoViaCalendar(calendarOps, timeZoneOps, sign, startEpochNano, endEpochNano, largestUnit, origOptions) {
    const startIsoFields = zonedEpochNanoToIso(timeZoneOps, startEpochNano), startIsoTimeFields = pluckProps(isoTimeFieldNamesAsc, startIsoFields), endIsoFields = zonedEpochNanoToIso(timeZoneOps, endEpochNano), isoToZonedEpochNano = bindArgs(getSingleInstantFor, timeZoneOps);
    let midIsoFields, midEpochNano, midSign, cnt = 0;
    do {
      if (cnt > 2) {
        throw new RangeError(invalidProtocolResults);
      }
      midIsoFields = {
        ...moveByIsoDays(endIsoFields, cnt++ * -sign),
        ...startIsoTimeFields
      }, midEpochNano = isoToZonedEpochNano(midIsoFields), midSign = compareDayTimeNanos(endEpochNano, midEpochNano);
    } while (midSign === -sign);
    return {
      ...6 === largestUnit ? diffByDay(startIsoFields, midIsoFields) : calendarOps.dateUntil(startIsoFields, midIsoFields, largestUnit, origOptions),
      ...nanoToDurationTimeFields(dayTimeNanoToNumber(diffDayTimeNanos(midEpochNano, endEpochNano)))
    };
  }
  function diffDateTimesViaCalendar(calendarOps, sign, startIsoFields, endIsoFields, largestUnit, origOptions) {
    const startTimeNano = isoTimeFieldsToNano(startIsoFields);
    let timeNano = isoTimeFieldsToNano(endIsoFields) - startTimeNano, midIsoFields = startIsoFields;
    return Math.sign(timeNano) === -sign && (midIsoFields = moveByIsoDays(startIsoFields, sign), 
    timeNano += nanoInUtcDay * sign), {
      ...calendarOps.dateUntil({
        ...midIsoFields,
        ...isoTimeFieldDefaults
      }, {
        ...endIsoFields,
        ...isoTimeFieldDefaults
      }, largestUnit, origOptions),
      ...nanoToDurationTimeFields(timeNano)
    };
  }
  function diffEpochNano(startEpochNano, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode) {
    return {
      ...durationFieldDefaults,
      ...nanoToDurationDayTimeFields(roundDayTimeNano(diffDayTimeNanos(startEpochNano, endEpochNano), smallestUnit, roundingInc, roundingMode), largestUnit)
    };
  }
  function diffEpochNanoExact(startEpochNano, endEpochNano, largestUnit) {
    return {
      ...durationFieldDefaults,
      ...nanoToDurationDayTimeFields(diffDayTimeNanos(startEpochNano, endEpochNano), largestUnit)
    };
  }
  function diffByDay(startIsoFields, endIsoFields) {
    return {
      ...durationFieldDefaults,
      days: diffDays(startIsoFields, endIsoFields)
    };
  }
  function diffDays(startIsoFields, endIsoFields) {
    return diffEpochMilliByDay(isoToEpochMilli(startIsoFields), isoToEpochMilli(endIsoFields));
  }
  function diffEpochMilliByDay(epochMilli0, epochMilli1) {
    return Math.round((epochMilli1 - epochMilli0) / milliInDay);
  }
  function getCommonCalendarSlot(a, b) {
    if (!isIdLikeEqual(a, b)) {
      throw new RangeError(mismatchingCalendars);
    }
    return a;
  }
  function createIntlFieldCache(epochMilliToIntlFields) {
    return createLazyGenerator((isoDateFields => {
      const epochMilli = isoToEpochMilli(isoDateFields);
      return epochMilliToIntlFields(epochMilli);
    }), WeakMap);
  }
  function createIntlYearMonthCache(epochMilliToIntlFields) {
    const yearCorrection = epochMilliToIntlFields(0).year - isoEpochOriginYear;
    return createLazyGenerator((year => {
      let intlFields, epochMilli = isoArgsToEpochMilli(year - yearCorrection);
      const milliReversed = [], monthStrsReversed = [];
      do {
        epochMilli += 400 * milliInDay;
      } while ((intlFields = epochMilliToIntlFields(epochMilli)).year <= year);
      do {
        epochMilli += (1 - intlFields.day) * milliInDay, intlFields.year === year && (milliReversed.push(epochMilli), 
        monthStrsReversed.push(intlFields.month)), epochMilli -= milliInDay;
      } while ((intlFields = epochMilliToIntlFields(epochMilli)).year >= year);
      return {
        monthEpochMilli: milliReversed.reverse(),
        monthStrToIndex: mapPropNamesToIndex(monthStrsReversed.reverse())
      };
    }));
  }
  function parseIntlYear(intlParts, calendarIdBase) {
    let era, eraYear, year = parseIntlPartsYear(intlParts);
    if (intlParts.era) {
      const eraOrigins = eraOriginsByCalendarId[calendarIdBase];
      void 0 !== eraOrigins && (formattedEra = (formattedEra = intlParts.era).normalize("NFD").toLowerCase().replace(/[^a-z0-9]/g, ""), 
      era = eraRemaps[formattedEra] || formattedEra, eraYear = year, year = eraYearToYear(eraYear, eraOrigins[era] || 0));
    }
    var formattedEra;
    return {
      era: era,
      eraYear: eraYear,
      year: year
    };
  }
  function parseIntlPartsYear(intlParts) {
    return parseInt(intlParts.relatedYear || intlParts.year);
  }
  function computeIntlDateParts(isoFields) {
    const {year: year, month: month, day: day} = this.queryFields(isoFields), {monthStrToIndex: monthStrToIndex} = this.queryYearMonths(year);
    return [ year, monthStrToIndex[month] + 1, day ];
  }
  function computeIntlEpochMilli(year, month = 1, day = 1) {
    return this.queryYearMonths(year).monthEpochMilli[month - 1] + (day - 1) * milliInDay;
  }
  function computeIntlLeapMonth(year) {
    const currentMonthStrs = queryMonthStrs(this, year), prevMonthStrs = queryMonthStrs(this, year - 1), currentLength = currentMonthStrs.length;
    if (currentLength > prevMonthStrs.length) {
      const leapMonthMeta = getCalendarLeapMonthMeta(this);
      if (leapMonthMeta < 0) {
        return -leapMonthMeta;
      }
      for (let i = 0; i < currentLength; i++) {
        if (currentMonthStrs[i] !== prevMonthStrs[i]) {
          return i + 1;
        }
      }
    }
  }
  function computeIntlDaysInYear(year) {
    return diffEpochMilliByDay(computeIntlEpochMilli.call(this, year), computeIntlEpochMilli.call(this, year + 1));
  }
  function computeIntlDaysInMonth(year, month) {
    const {monthEpochMilli: monthEpochMilli} = this.queryYearMonths(year);
    let nextMonth = month + 1, nextMonthEpochMilli = monthEpochMilli;
    return nextMonth > monthEpochMilli.length && (nextMonth = 1, nextMonthEpochMilli = this.queryYearMonths(year + 1).monthEpochMilli), 
    diffEpochMilliByDay(monthEpochMilli[month - 1], nextMonthEpochMilli[nextMonth - 1]);
  }
  function computeIntlMonthsInYear(year) {
    return this.queryYearMonths(year).monthEpochMilli.length;
  }
  function queryMonthStrs(intlCalendar, year) {
    return Object.keys(intlCalendar.queryYearMonths(year).monthStrToIndex);
  }
  function resolveCalendarId(id) {
    if ((id = (id => ("islamicc" === (id = id.toLowerCase()) && (id = "islamic-civil"), 
    id))(id)) !== isoCalendarId && id !== gregoryCalendarId && computeCalendarIdBase(id) !== computeCalendarIdBase(queryCalendarIntlFormat(id).resolvedOptions().calendar)) {
      throw new RangeError(invalidCalendar(id));
    }
    return id;
  }
  function computeCalendarIdBase(id) {
    return id.split("-")[0];
  }
  function parseMonthCode(monthCode) {
    const m = monthCodeRegExp.exec(monthCode);
    if (!m) {
      throw new RangeError(invalidMonthCode(monthCode));
    }
    return [ parseInt(m[1]), Boolean(m[2]) ];
  }
  function monthCodeNumberToMonth(monthCodeNumber, isLeapMonth, leapMonth) {
    return monthCodeNumber + (isLeapMonth || leapMonth && monthCodeNumber >= leapMonth ? 1 : 0);
  }
  function monthToMonthCodeNumber(month, leapMonth) {
    return month - (leapMonth && month >= leapMonth ? 1 : 0);
  }
  function eraYearToYear(eraYear, eraOrigin) {
    return (eraOrigin + eraYear) * (Math.sign(eraOrigin) || 1) || 0;
  }
  function getCalendarEraOrigins(native) {
    return eraOriginsByCalendarId[getCalendarIdBase(native)];
  }
  function getCalendarLeapMonthMeta(native) {
    return leapMonthMetas[getCalendarIdBase(native)];
  }
  function getCalendarIdBase(native) {
    return computeCalendarIdBase(native.id || isoCalendarId);
  }
  function refinePlainDateBag(calendarOps, bag, options, requireFields = []) {
    const fields = refineCalendarFields(calendarOps, bag, dateFieldNamesAlpha, requireFields);
    return calendarOps.dateFromFields(fields, options);
  }
  function refinePlainYearMonthBag(calendarOps, bag, options, requireFields) {
    const fields = refineCalendarFields(calendarOps, bag, yearMonthFieldNames, requireFields);
    return calendarOps.yearMonthFromFields(fields, options);
  }
  function refinePlainMonthDayBag(calendarOps, calendarAbsent, bag, options, requireFields = []) {
    const fields = refineCalendarFields(calendarOps, bag, dateFieldNamesAlpha, requireFields);
    return calendarAbsent && void 0 !== fields.month && void 0 === fields.monthCode && void 0 === fields.year && (fields.year = isoEpochFirstLeapYear), 
    calendarOps.monthDayFromFields(fields, options);
  }
  function refineCalendarFields(calendarOps, bag, validFieldNames, requiredFieldNames = [], forcedValidFieldNames = []) {
    return refineFields(bag, [ ...calendarOps.fields(validFieldNames), ...forcedValidFieldNames ].sort(), requiredFieldNames);
  }
  function refineFields(bag, validFieldNames, requiredFieldNames, disallowEmpty = !requiredFieldNames) {
    const res = {};
    let prevFieldName, anyMatching = 0;
    for (const fieldName of validFieldNames) {
      if (fieldName === prevFieldName) {
        throw new RangeError(duplicateFields(fieldName));
      }
      if ("constructor" === fieldName || "__proto__" === fieldName) {
        throw new RangeError(forbiddenField(fieldName));
      }
      let fieldVal = bag[fieldName];
      if (void 0 !== fieldVal) {
        anyMatching = 1, builtinRefiners[fieldName] && (fieldVal = builtinRefiners[fieldName](fieldVal, fieldName)), 
        res[fieldName] = fieldVal;
      } else if (requiredFieldNames) {
        if (requiredFieldNames.includes(fieldName)) {
          throw new TypeError(missingField(fieldName));
        }
        res[fieldName] = timeFieldDefaults[fieldName];
      }
      prevFieldName = fieldName;
    }
    if (disallowEmpty && !anyMatching) {
      throw new TypeError(noValidFields);
    }
    return res;
  }
  function refineTimeBag(fields, overflow) {
    return constrainIsoTimeFields(timeFieldsToIso({
      ...timeFieldDefaults,
      ...fields
    }), overflow);
  }
  function mergeCalendarFields(calendarOps, obj, bag, validFieldNames, forcedValidFieldNames = [], requiredObjFieldNames = []) {
    const fieldNames = [ ...calendarOps.fields(validFieldNames), ...forcedValidFieldNames ].sort();
    let fields = refineFields(obj, fieldNames, requiredObjFieldNames);
    const partialFields = refineFields(bag, fieldNames);
    return fields = calendarOps.mergeFields(fields, partialFields), refineFields(fields, fieldNames, []);
  }
  function convertToPlainMonthDay(calendarOps, input) {
    const fields = refineCalendarFields(calendarOps, input, monthCodeDayFieldNames);
    return calendarOps.monthDayFromFields(fields);
  }
  function convertToPlainYearMonth(calendarOps, input, options) {
    const fields = refineCalendarFields(calendarOps, input, yearMonthCodeFieldNames);
    return calendarOps.yearMonthFromFields(fields, options);
  }
  function convertToIso(calendarOps, input, inputFieldNames, extra, extraFieldNames) {
    input = pluckProps(inputFieldNames = calendarOps.fields(inputFieldNames), input), 
    extra = refineFields(extra, extraFieldNames = calendarOps.fields(extraFieldNames), []);
    let mergedFields = calendarOps.mergeFields(input, extra);
    return mergedFields = refineFields(mergedFields, [ ...inputFieldNames, ...extraFieldNames ].sort(), []), 
    calendarOps.dateFromFields(mergedFields);
  }
  function refineYear(calendarNative, fields) {
    let {era: era, eraYear: eraYear, year: year} = fields;
    const eraOrigins = getCalendarEraOrigins(calendarNative);
    if (void 0 !== era || void 0 !== eraYear) {
      if (void 0 === era || void 0 === eraYear) {
        throw new TypeError(mismatchingEraParts);
      }
      if (!eraOrigins) {
        throw new RangeError(forbiddenEraParts);
      }
      const eraOrigin = eraOrigins[era];
      if (void 0 === eraOrigin) {
        throw new RangeError(invalidEra(era));
      }
      const yearByEra = eraYearToYear(eraYear, eraOrigin);
      if (void 0 !== year && year !== yearByEra) {
        throw new RangeError(mismatchingYearAndEra);
      }
      year = yearByEra;
    } else if (void 0 === year) {
      throw new TypeError(missingYear(eraOrigins));
    }
    return year;
  }
  function refineMonth(calendarNative, fields, year, overflow) {
    let {month: month, monthCode: monthCode} = fields;
    if (void 0 !== monthCode) {
      const monthByCode = ((calendarNative, monthCode, year, overflow) => {
        const leapMonth = calendarNative.leapMonth(year), [monthCodeNumber, wantsLeapMonth] = parseMonthCode(monthCode);
        let month = monthCodeNumberToMonth(monthCodeNumber, wantsLeapMonth, leapMonth);
        if (wantsLeapMonth) {
          const leapMonthMeta = getCalendarLeapMonthMeta(calendarNative);
          if (void 0 === leapMonthMeta) {
            throw new RangeError(invalidLeapMonth);
          }
          if (leapMonthMeta > 0) {
            if (month > leapMonthMeta) {
              throw new RangeError(invalidLeapMonth);
            }
            if (void 0 === leapMonth) {
              if (1 === overflow) {
                throw new RangeError(invalidLeapMonth);
              }
              month--;
            }
          } else {
            if (month !== -leapMonthMeta) {
              throw new RangeError(invalidLeapMonth);
            }
            if (void 0 === leapMonth && 1 === overflow) {
              throw new RangeError(invalidLeapMonth);
            }
          }
        }
        return month;
      })(calendarNative, monthCode, year, overflow);
      if (void 0 !== month && month !== monthByCode) {
        throw new RangeError(mismatchingMonthAndCode);
      }
      month = monthByCode, overflow = 1;
    } else if (void 0 === month) {
      throw new TypeError(missingMonth);
    }
    return clampEntity("month", month, 1, calendarNative.monthsInYearPart(year), overflow);
  }
  function refineDay(calendarNative, fields, month, year, overflow) {
    return clampProp(fields, "day", 1, calendarNative.daysInMonthParts(year, month), overflow);
  }
  function spliceFields(dest, additional, allPropNames, deletablePropNames) {
    let anyMatching = 0;
    const nonMatchingPropNames = [];
    for (const propName of allPropNames) {
      void 0 !== additional[propName] ? anyMatching = 1 : nonMatchingPropNames.push(propName);
    }
    if (Object.assign(dest, additional), anyMatching) {
      for (const deletablePropName of deletablePropNames || nonMatchingPropNames) {
        delete dest[deletablePropName];
      }
    }
  }
  function instantToZonedDateTime(instantSlots, timeZoneSlot, calendarSlot = isoCalendarId) {
    return createZonedDateTimeSlots(instantSlots.epochNanoseconds, timeZoneSlot, calendarSlot);
  }
  function zonedDateTimeToPlainDateTime(getTimeZoneOps, zonedDateTimeSlots0) {
    return createPlainDateTimeSlots(zonedEpochSlotsToIso(zonedDateTimeSlots0, getTimeZoneOps));
  }
  function zonedDateTimeToPlainDate(getTimeZoneOps, zonedDateTimeSlots0) {
    return createPlainDateSlots(zonedEpochSlotsToIso(zonedDateTimeSlots0, getTimeZoneOps));
  }
  function zonedDateTimeToPlainTime(getTimeZoneOps, zonedDateTimeSlots0) {
    return createPlainTimeSlots(zonedEpochSlotsToIso(zonedDateTimeSlots0, getTimeZoneOps));
  }
  function slotsWithCalendar(slots, calendarSlot) {
    return {
      ...slots,
      calendar: calendarSlot
    };
  }
  function getPreferredCalendarSlot(a, b) {
    if (a === b) {
      return a;
    }
    const aId = getId(a), bId = getId(b);
    if (aId === bId || aId === isoCalendarId) {
      return b;
    }
    if (bId === isoCalendarId) {
      return a;
    }
    throw new RangeError(mismatchingCalendars);
  }
  function createOptionsTransformer(validNames, fallbacks, excludedNames = []) {
    const excludedNameSet = new Set(excludedNames);
    return options => (((props, names) => {
      for (const name of names) {
        if (name in props) {
          return 1;
        }
      }
      return 0;
    })(options = excludePropsByName(excludedNameSet, options), validNames) || Object.assign(options, fallbacks), 
    options);
  }
  function isoDateFieldsToEpochNano(isoFields, resolvedOptions) {
    return getSingleInstantFor(queryNativeTimeZone(resolvedOptions.timeZone), {
      ...isoTimeFieldDefaults,
      isoHour: 12,
      ...isoFields
    });
  }
  function extractEpochNano(slots) {
    return slots.epochNanoseconds;
  }
  function createFormatPrepper(config, queryFormat = createFormatForPrep) {
    const [transformOptions, , , getForcedTimeZoneId] = config;
    return (locales, options = emptyOptions, ...slotsList) => {
      const subformat = queryFormat(getForcedTimeZoneId ? getForcedTimeZoneId(...slotsList) : void 0, locales, options, transformOptions), resolvedOptions = subformat.resolvedOptions();
      return [ subformat, ...toEpochMillis(config, resolvedOptions, ...slotsList) ];
    };
  }
  function createFormatForPrep(forcedTimeZoneId, locales, options, transformOptions) {
    if (options = transformOptions(options), forcedTimeZoneId) {
      if (void 0 !== options.timeZone) {
        throw new TypeError(forbiddenFormatTimeZone);
      }
      options.timeZone = forcedTimeZoneId;
    }
    return new RawDateTimeFormat(locales, options);
  }
  function toEpochMillis(config, resolvedOptions, ...slotsList) {
    const [, slotsToEpochNano, strictCalendarCheck] = config;
    return slotsList.map((slots => (slots.calendar && ((internalCalendarId, resolvedCalendarId, strictCalendarCheck) => {
      if ((strictCalendarCheck || internalCalendarId !== isoCalendarId) && internalCalendarId !== resolvedCalendarId) {
        throw new RangeError(mismatchingCalendars);
      }
    })(getId(slots.calendar), resolvedOptions.calendar, strictCalendarCheck), epochNanoToMilli(slotsToEpochNano(slots, resolvedOptions)))));
  }
  function createSlotClass(branding, construct, getters, methods, staticMethods) {
    function Class(...args) {
      if (!(this instanceof Class)) {
        throw new TypeError("Invalid calling context");
      }
      setSlots(this, construct(...args));
    }
    function bindMethod(method, methodName) {
      return Object.defineProperties((function(...args) {
        return method.call(this, getSpecificSlots(this), ...args);
      }), createNameDescriptors(methodName));
    }
    function getSpecificSlots(obj) {
      const slots = getSlots(obj);
      if (!slots || slots.branding !== branding) {
        throw new TypeError("Invalid calling context");
      }
      return slots;
    }
    return Object.defineProperties(Class.prototype, {
      ...createGetterDescriptors(mapProps(bindMethod, getters)),
      ...createPropDescriptors(mapProps(bindMethod, methods)),
      ...createStringTagDescriptors("Temporal." + branding)
    }), Object.defineProperties(Class, {
      ...createPropDescriptors(staticMethods),
      ...createNameDescriptors(branding)
    }), [ Class, slots => {
      const instance = Object.create(Class.prototype);
      return setSlots(instance, slots), instance;
    }, getSpecificSlots ];
  }
  function createProtocolValidator(propNames) {
    return propNames = propNames.concat("id").sort(), obj => {
      if (!((props, names) => {
        for (const name of names) {
          if (!(name in props)) {
            return 0;
          }
        }
        return 1;
      })(obj, propNames)) {
        throw new TypeError("Invalid protocol");
      }
      return obj;
    };
  }
  function rejectInvalidBag(bag) {
    if (getSlots(bag) || void 0 !== bag.calendar || void 0 !== bag.timeZone) {
      throw new TypeError("Invalid bag");
    }
    return bag;
  }
  function createFormatMethod(methodName) {
    return function(...formattables) {
      const prepFormat = internalsMap.get(this), [format, ...rawFormattables] = prepFormat(...formattables);
      return format[methodName](...rawFormattables);
    };
  }
  function createProxiedMethod(methodName) {
    return function(...args) {
      return internalsMap.get(this).rawFormat[methodName](...args);
    };
  }
  function createFormatPrepperForBranding(branding) {
    const config = classFormatConfigs[branding];
    if (!config) {
      throw new TypeError(invalidFormatType(branding));
    }
    return createFormatPrepper(config, createLazyGenerator(createFormatForPrep));
  }
  function createCalendarFieldMethods(methodNameMap, alsoAccept) {
    const methods = {};
    for (const methodName in methodNameMap) {
      methods[methodName] = ({native: native}, dateArg) => {
        const argSlots = getSlots(dateArg) || {}, {branding: branding} = argSlots, refinedSlots = branding === PlainDateBranding || alsoAccept.includes(branding) ? argSlots : toPlainDateSlots(dateArg);
        return native[methodName](refinedSlots);
      };
    }
    return methods;
  }
  function createCalendarGetters(methodNameMap) {
    const methods = {};
    for (const methodName in methodNameMap) {
      methods[methodName] = slots => {
        const {calendar: calendar} = slots;
        return (calendarSlot = calendar, "string" == typeof calendarSlot ? createNativeStandardOps(calendarSlot) : (calendarProtocol = calendarSlot, 
        Object.assign(Object.create(adapterSimpleOps), {
          calendarProtocol: calendarProtocol
        })))[methodName](slots);
        var calendarSlot, calendarProtocol;
      };
    }
    return methods;
  }
  function neverValueOf() {
    throw new TypeError("Cannot use valueOf");
  }
  function createCalendarFromSlots({calendar: calendar}) {
    return "string" == typeof calendar ? new Calendar(calendar) : calendar;
  }
  function toPlainMonthDaySlots(arg, options) {
    if (options = copyOptions(options), isObjectLike(arg)) {
      const slots = getSlots(arg);
      if (slots && slots.branding === PlainMonthDayBranding) {
        return refineOverflowOptions(options), slots;
      }
      const calendarMaybe = extractCalendarSlotFromBag(arg);
      return refinePlainMonthDayBag(createMonthDayRefineOps(calendarMaybe || isoCalendarId), !calendarMaybe, arg, options);
    }
    const res = ((getCalendarOps, s) => {
      const organized = parseMonthDayOnly(requireString(s));
      if (organized) {
        return requireIsoCalendar(organized), createPlainMonthDaySlots(checkIsoDateFields(organized));
      }
      const dateSlots = parsePlainDate(s), {calendar: calendar} = dateSlots, calendarOps = getCalendarOps(calendar), [origYear, origMonth, day] = calendarOps.dateParts(dateSlots), [monthCodeNumber, isLeapMonth] = calendarOps.monthCodeParts(origYear, origMonth), [year, month] = calendarOps.yearMonthForMonthDay(monthCodeNumber, isLeapMonth, day);
      return createPlainMonthDaySlots(calendarOps.isoFields(year, month, day), calendar);
    })(createNativeStandardOps, arg);
    return refineOverflowOptions(options), res;
  }
  function getOffsetNanosecondsForAdapter(timeZoneProtocol, getOffsetNanosecondsFor, epochNano) {
    return validateTimeZoneOffset(requireInteger(getOffsetNanosecondsFor.call(timeZoneProtocol, createInstant(createInstantSlots(epochNano)))));
  }
  function createAdapterOps(timeZoneProtocol, adapterFuncs = timeZoneAdapters) {
    const keys = Object.keys(adapterFuncs).sort(), boundFuncs = {};
    for (const key of keys) {
      boundFuncs[key] = bindArgs(adapterFuncs[key], timeZoneProtocol, requireFunction(timeZoneProtocol[key]));
    }
    return boundFuncs;
  }
  function createTimeZoneOps(timeZoneSlot, adapterFuncs) {
    return "string" == typeof timeZoneSlot ? queryNativeTimeZone(timeZoneSlot) : createAdapterOps(timeZoneSlot, adapterFuncs);
  }
  function createTimeZoneOffsetOps(timeZoneSlot) {
    return createTimeZoneOps(timeZoneSlot, simpleTimeZoneAdapters);
  }
  function toPlainYearMonthSlots(arg, options) {
    if (options = copyOptions(options), isObjectLike(arg)) {
      const slots = getSlots(arg);
      return slots && slots.branding === PlainYearMonthBranding ? (refineOverflowOptions(options), 
      slots) : refinePlainYearMonthBag(createYearMonthRefineOps(getCalendarSlotFromBag(arg)), arg, options);
    }
    const res = ((getCalendarOps, s) => {
      const organized = parseYearMonthOnly(requireString(s));
      if (organized) {
        return requireIsoCalendar(organized), createPlainYearMonthSlots(checkIsoYearMonthInBounds(checkIsoDateFields(organized)));
      }
      const isoFields = parsePlainDate(s), movedIsoFields = moveToMonthStart(getCalendarOps(isoFields.calendar), isoFields);
      return createPlainYearMonthSlots({
        ...isoFields,
        ...movedIsoFields
      });
    })(createNativeStandardOps, arg);
    return refineOverflowOptions(options), res;
  }
  function toZonedDateTimeSlots(arg, options) {
    if (options = copyOptions(options), isObjectLike(arg)) {
      const slots = getSlots(arg);
      if (slots && slots.branding === ZonedDateTimeBranding) {
        return refineZonedFieldOptions(options), slots;
      }
      const calendarSlot = getCalendarSlotFromBag(arg);
      return ((refineTimeZoneArg, getTimeZoneOps, calendarOps, calendarSlot, bag, options) => {
        const fields = refineCalendarFields(calendarOps, bag, dateFieldNamesAlpha, timeZoneFieldNames, timeAndZoneFieldNames), timeZoneSlot = refineTimeZoneArg(fields.timeZone), [overflow, offsetDisambig, epochDisambig] = refineZonedFieldOptions(options), isoDateFields = calendarOps.dateFromFields(fields, overrideOverflowOptions(options, overflow)), isoTimeFields = refineTimeBag(fields, overflow);
        return createZonedDateTimeSlots(getMatchingInstantFor(getTimeZoneOps(timeZoneSlot), {
          ...isoDateFields,
          ...isoTimeFields
        }, void 0 !== fields.offset ? parseOffsetNano(fields.offset) : void 0, offsetDisambig, epochDisambig), timeZoneSlot, calendarSlot);
      })(refineTimeZoneSlot, createTimeZoneOps, createDateRefineOps(calendarSlot), calendarSlot, arg, options);
    }
    return ((s, options) => {
      const organized = parseDateTimeLike(requireString(s));
      if (!organized || !organized.timeZone) {
        throw new RangeError(failedParse(s));
      }
      const {offset: offset} = organized, offsetNano = offset ? parseOffsetNano(offset) : void 0, [, offsetDisambig, epochDisambig] = refineZonedFieldOptions(options);
      return finalizeZonedDateTime(organized, offsetNano, offsetDisambig, epochDisambig);
    })(arg, options);
  }
  function slotsToIso(slots) {
    return zonedEpochSlotsToIso(slots, createTimeZoneOffsetOps);
  }
  function adaptDateMethods(methods) {
    return mapProps((method => slots => method(slotsToIso(slots))), methods);
  }
  function toInstantSlots(arg) {
    if (isObjectLike(arg)) {
      const slots = getSlots(arg);
      if (slots) {
        switch (slots.branding) {
         case InstantBranding:
          return slots;

         case ZonedDateTimeBranding:
          return createInstantSlots(slots.epochNanoseconds);
        }
      }
    }
    return (s => {
      const organized = parseDateTimeLike(s = toStringViaPrimitive(s));
      if (!organized) {
        throw new RangeError(failedParse(s));
      }
      let offsetNano;
      if (organized.hasZ) {
        offsetNano = 0;
      } else {
        if (!organized.offset) {
          throw new RangeError(failedParse(s));
        }
        offsetNano = parseOffsetNano(organized.offset);
      }
      return organized.timeZone && parseOffsetNanoMaybe(organized.timeZone, 1), createInstantSlots(isoToEpochNanoWithOffset(checkIsoDateTimeFields(organized), offsetNano));
    })(arg);
  }
  function getImplTransition(direction, impl, instantArg) {
    const epochNano = impl.getTransition(toInstantSlots(instantArg).epochNanoseconds, direction);
    return epochNano ? createInstant(createInstantSlots(epochNano)) : null;
  }
  function refineTimeZoneSlot(arg) {
    return isObjectLike(arg) ? (getSlots(arg) || {}).timeZone || validateTimeZoneProtocol(arg) : (arg => resolveTimeZoneId((s => {
      const parsed = parseDateTimeLike(s);
      return parsed && (parsed.timeZone || parsed.hasZ && utcTimeZoneId || parsed.offset) || s;
    })(requireString(arg))))(arg);
  }
  function toPlainTimeSlots(arg, options) {
    if (isObjectLike(arg)) {
      const slots = getSlots(arg) || {};
      switch (slots.branding) {
       case PlainTimeBranding:
        return refineOverflowOptions(options), slots;

       case PlainDateTimeBranding:
        return refineOverflowOptions(options), createPlainTimeSlots(slots);

       case ZonedDateTimeBranding:
        return refineOverflowOptions(options), zonedDateTimeToPlainTime(createTimeZoneOffsetOps, slots);
      }
      return ((bag, options) => {
        const overflow = refineOverflowOptions(options);
        return createPlainTimeSlots(refineTimeBag(refineFields(bag, timeFieldNamesAlpha, [], 1), overflow));
      })(arg, options);
    }
    return refineOverflowOptions(options), (s => {
      let altParsed, organized = (s => {
        const parts = timeRegExp.exec(s);
        return parts ? (organizeAnnotationParts(parts[10]), organizeTimeParts(parts)) : void 0;
      })(requireString(s));
      if (!organized) {
        if (organized = parseDateTimeLike(s), !organized) {
          throw new RangeError(failedParse(s));
        }
        if (!organized.hasTime) {
          throw new RangeError(failedParse(s));
        }
        if (organized.hasZ) {
          throw new RangeError(invalidSubstring("Z"));
        }
        requireIsoCalendar(organized);
      }
      if ((altParsed = parseYearMonthOnly(s)) && isIsoDateFieldsValid(altParsed)) {
        throw new RangeError(failedParse(s));
      }
      if ((altParsed = parseMonthDayOnly(s)) && isIsoDateFieldsValid(altParsed)) {
        throw new RangeError(failedParse(s));
      }
      return createPlainTimeSlots(constrainIsoTimeFields(organized, 1));
    })(arg);
  }
  function optionalToPlainTimeFields(timeArg) {
    return void 0 === timeArg ? void 0 : toPlainTimeSlots(timeArg);
  }
  function toPlainDateTimeSlots(arg, options) {
    if (options = copyOptions(options), isObjectLike(arg)) {
      const slots = getSlots(arg) || {};
      switch (slots.branding) {
       case PlainDateTimeBranding:
        return refineOverflowOptions(options), slots;

       case PlainDateBranding:
        return refineOverflowOptions(options), createPlainDateTimeSlots({
          ...slots,
          ...isoTimeFieldDefaults
        });

       case ZonedDateTimeBranding:
        return refineOverflowOptions(options), zonedDateTimeToPlainDateTime(createTimeZoneOffsetOps, slots);
      }
      return ((calendarOps, bag, options) => {
        const fields = refineCalendarFields(calendarOps, bag, dateFieldNamesAlpha, [], timeFieldNamesAsc), overflow = refineOverflowOptions(options);
        return createPlainDateTimeSlots(checkIsoDateTimeInBounds({
          ...calendarOps.dateFromFields(fields, overrideOverflowOptions(options, overflow)),
          ...refineTimeBag(fields, overflow)
        }));
      })(createDateRefineOps(getCalendarSlotFromBag(arg)), arg, options);
    }
    const res = (s => {
      const organized = parseDateTimeLike(requireString(s));
      if (!organized || organized.hasZ) {
        throw new RangeError(failedParse(s));
      }
      return createPlainDateTimeSlots(finalizeDateTime(organized));
    })(arg);
    return refineOverflowOptions(options), res;
  }
  function toPlainDateSlots(arg, options) {
    if (options = copyOptions(options), isObjectLike(arg)) {
      const slots = getSlots(arg) || {};
      switch (slots.branding) {
       case PlainDateBranding:
        return refineOverflowOptions(options), slots;

       case PlainDateTimeBranding:
        return refineOverflowOptions(options), createPlainDateSlots(slots);

       case ZonedDateTimeBranding:
        return refineOverflowOptions(options), zonedDateTimeToPlainDate(createTimeZoneOffsetOps, slots);
      }
      return refinePlainDateBag(createDateRefineOps(getCalendarSlotFromBag(arg)), arg, options);
    }
    const res = parsePlainDate(arg);
    return refineOverflowOptions(options), res;
  }
  function dayAdapter(calendarProtocol, dayMethod, isoFields) {
    return requirePositiveInteger(dayMethod.call(calendarProtocol, createPlainDate(createPlainDateSlots(isoFields, calendarProtocol))));
  }
  function createCompoundOpsCreator(adapterFuncs) {
    return calendarSlot => "string" == typeof calendarSlot ? createNativeStandardOps(calendarSlot) : ((calendarProtocol, adapterFuncs) => {
      const keys = Object.keys(adapterFuncs).sort(), boundFuncs = {};
      for (const key of keys) {
        boundFuncs[key] = bindArgs(adapterFuncs[key], calendarProtocol, calendarProtocol[key]);
      }
      return boundFuncs;
    })(calendarSlot, adapterFuncs);
  }
  function toDurationSlots(arg) {
    if (isObjectLike(arg)) {
      const slots = getSlots(arg);
      return slots && slots.branding === DurationBranding ? slots : (bag => {
        const durationFields = refineFields(bag, durationFieldNamesAlpha);
        return createDurationSlots(checkDurationFields({
          ...durationFieldDefaults,
          ...durationFields
        }));
      })(arg);
    }
    return (s => {
      const parsed = (s => {
        const parts = durationRegExp.exec(s);
        return parts ? (parts => {
          function parseUnit(wholeStr, fracStr, timeUnit) {
            let leftoverUnits = 0, wholeUnits = 0;
            if (timeUnit && ([leftoverUnits, leftoverNano] = divModFloor(leftoverNano, unitNanoMap[timeUnit])), 
            void 0 !== wholeStr) {
              if (hasAnyFrac) {
                throw new RangeError(invalidSubstring(wholeStr));
              }
              wholeUnits = (s => {
                const n = parseInt(s);
                if (!Number.isFinite(n)) {
                  throw new RangeError(invalidSubstring(s));
                }
                return n;
              })(wholeStr), hasAny = 1, fracStr && (leftoverNano = parseSubsecNano(fracStr) * (unitNanoMap[timeUnit] / nanoInSec), 
              hasAnyFrac = 1);
            }
            return leftoverUnits + wholeUnits;
          }
          let hasAny = 0, hasAnyFrac = 0, leftoverNano = 0, durationFields = {
            ...zipProps(durationFieldNamesAsc, [ parseUnit(parts[2]), parseUnit(parts[3]), parseUnit(parts[4]), parseUnit(parts[5]), parseUnit(parts[6], parts[7], 5), parseUnit(parts[8], parts[9], 4), parseUnit(parts[10], parts[11], 3) ]),
            ...nanoToGivenFields(leftoverNano, 2, durationFieldNamesAsc)
          };
          if (!hasAny) {
            throw new RangeError(noValidFields);
          }
          return parseSign(parts[1]) < 0 && (durationFields = negateDurationFields(durationFields)), 
          durationFields;
        })(parts) : void 0;
      })(requireString(s));
      if (!parsed) {
        throw new RangeError(failedParse(s));
      }
      return createDurationSlots(parsed);
    })(arg);
  }
  function refinePublicRelativeTo(relativeTo) {
    if (void 0 !== relativeTo) {
      if (isObjectLike(relativeTo)) {
        const slots = getSlots(relativeTo) || {};
        switch (slots.branding) {
         case ZonedDateTimeBranding:
         case PlainDateBranding:
          return slots;

         case PlainDateTimeBranding:
          return createPlainDateSlots(slots);
        }
        const calendar = getCalendarSlotFromBag(relativeTo);
        return {
          ...((refineTimeZoneArg, getTimeZoneOps, calendarOps, bag) => {
            const fields = refineCalendarFields(calendarOps, bag, dateFieldNamesAlpha, [], timeAndZoneFieldNames);
            if (void 0 !== fields.timeZone) {
              const isoDateFields = calendarOps.dateFromFields(fields), isoTimeFields = refineTimeBag(fields), timeZoneSlot = refineTimeZoneArg(fields.timeZone);
              return {
                epochNanoseconds: getMatchingInstantFor(getTimeZoneOps(timeZoneSlot), {
                  ...isoDateFields,
                  ...isoTimeFields
                }, void 0 !== fields.offset ? parseOffsetNano(fields.offset) : void 0),
                timeZone: timeZoneSlot
              };
            }
            return {
              ...calendarOps.dateFromFields(fields),
              ...isoTimeFieldDefaults
            };
          })(refineTimeZoneSlot, createTimeZoneOps, createDateRefineOps(calendar), relativeTo),
          calendar: calendar
        };
      }
      return (s => {
        const organized = parseDateTimeLike(requireString(s));
        if (!organized) {
          throw new RangeError(failedParse(s));
        }
        if (organized.timeZone) {
          return finalizeZonedDateTime(organized, organized.offset ? parseOffsetNano(organized.offset) : void 0);
        }
        if (organized.hasZ) {
          throw new RangeError(failedParse(s));
        }
        return finalizeDate(organized);
      })(relativeTo);
    }
  }
  function getCalendarSlotFromBag(bag) {
    return extractCalendarSlotFromBag(bag) || isoCalendarId;
  }
  function extractCalendarSlotFromBag(bag) {
    const {calendar: calendar} = bag;
    if (void 0 !== calendar) {
      return refineCalendarSlot(calendar);
    }
  }
  function refineCalendarSlot(arg) {
    return isObjectLike(arg) ? (getSlots(arg) || {}).calendar || validateCalendarProtocol(arg) : (arg => resolveCalendarId((s => {
      const res = parseDateTimeLike(s) || parseYearMonthOnly(s) || parseMonthDayOnly(s);
      return res ? res.calendar : s;
    })(requireString(arg))))(arg);
  }
  function getCurrentIsoDateTime(timeZoneOps) {
    const isoFields = zonedEpochNanoToIso(timeZoneOps, getCurrentEpochNanoseconds());
    return pluckProps(isoDateTimeFieldNamesAsc, isoFields);
  }
  function getCurrentEpochNanoseconds() {
    return numberToDayTimeNano(Date.now(), nanoInMilli);
  }
  function getCurrentTimeZoneId() {
    return currentTimeZoneId || (currentTimeZoneId = (new RawDateTimeFormat).resolvedOptions().timeZone);
  }
  const expectedInteger = (entityName, num) => `Non-integer ${entityName}: ${num}`, expectedPositive = (entityName, num) => `Non-positive ${entityName}: ${num}`, expectedFinite = (entityName, num) => `Non-finite ${entityName}: ${num}`, forbiddenBigIntToNumber = entityName => `Cannot convert bigint to ${entityName}`, invalidBigInt = arg => `Invalid bigint: ${arg}`, forbiddenSymbolToString = "Cannot convert Symbol to string", invalidObject = "Invalid object", numberOutOfRange = (entityName, val, min, max) => `${entityName} ${val} must be between ${min}-${max}`, invalidEntity = (fieldName, val) => `Invalid ${fieldName}: ${val}`, missingField = fieldName => `Missing ${fieldName}`, forbiddenField = fieldName => `Invalid field ${fieldName}`, duplicateFields = fieldName => `Duplicate field ${fieldName}`, noValidFields = "No valid fields", forbiddenEraParts = "Forbidden era/eraYear", mismatchingEraParts = "Mismatching era/eraYear", mismatchingYearAndEra = "Mismatching year/eraYear", invalidEra = era => `Invalid era: ${era}`, missingYear = allowEra => "Missing year" + (allowEra ? "/era/eraYear" : ""), invalidMonthCode = monthCode => `Invalid monthCode: ${monthCode}`, mismatchingMonthAndCode = "Mismatching month/monthCode", missingMonth = "Missing month/monthCode", invalidLeapMonth = "Invalid leap month", invalidProtocolResults = "Invalid protocol results", invalidCalendar = calendarId => `Invalid Calendar: ${calendarId}`, mismatchingCalendars = "Mismatching Calendars", mismatchingTimeZones = "Mismatching TimeZones", outOfBoundsOffset = "Out-of-bounds offset", invalidOffsetForTimeZone = "Invalid offset for TimeZone", ambigOffset = "Ambiguous offset", outOfBoundsDate = "Out-of-bounds date", forbiddenDurationSigns = "Cannot mix duration signs", invalidLargeUnits = "Cannot use large units", flippedSmallestLargestUnit = "smallestUnit > largestUnit", failedParse = s => `Cannot parse: ${s}`, invalidSubstring = substring => `Invalid substring: ${substring}`, invalidFormatType = branding => `Cannot format ${branding}`, forbiddenFormatTimeZone = "Forbidden timeZone", mapPropNamesToIndex = bindArgs(mapPropNames, ((_propVal, i) => i)), mapPropNamesToConstant = bindArgs(mapPropNames, ((_propVal, _i, constant) => constant)), padNumber2 = bindArgs(padNumber, 2), unitNameMap = {
    nanosecond: 0,
    microsecond: 1,
    millisecond: 2,
    second: 3,
    minute: 4,
    hour: 5,
    day: 6,
    week: 7,
    month: 8,
    year: 9
  }, unitNamesAsc = Object.keys(unitNameMap), milliInDay = 864e5, milliInSec = 1e3, nanoInMicro = 1e3, nanoInMilli = 1e6, nanoInSec = 1e9, nanoInMinute = 6e10, nanoInHour = 36e11, nanoInUtcDay = 864e11, unitNanoMap = [ 1, nanoInMicro, nanoInMilli, nanoInSec, nanoInMinute, nanoInHour, nanoInUtcDay ], timeFieldNamesAsc = unitNamesAsc.slice(0, 6), timeFieldNamesAlpha = sortStrings(timeFieldNamesAsc), offsetFieldNames = [ "offset" ], timeZoneFieldNames = [ "timeZone" ], timeAndOffsetFieldNames = [ ...timeFieldNamesAsc, ...offsetFieldNames ], timeAndZoneFieldNames = [ ...timeAndOffsetFieldNames, ...timeZoneFieldNames ], eraYearFieldNames = [ "era", "eraYear" ], allYearFieldNames = [ ...eraYearFieldNames, "year" ], yearFieldNames = [ "year" ], monthCodeFieldNames = [ "monthCode" ], monthFieldNames = [ "month", ...monthCodeFieldNames ], dayFieldNames = [ "day" ], yearMonthFieldNames = [ ...monthFieldNames, ...yearFieldNames ], yearMonthCodeFieldNames = [ ...monthCodeFieldNames, ...yearFieldNames ], dateFieldNamesAlpha = [ ...dayFieldNames, ...yearMonthFieldNames ], monthDayFieldNames = [ ...dayFieldNames, ...monthFieldNames ], monthCodeDayFieldNames = [ ...dayFieldNames, ...monthCodeFieldNames ], timeFieldDefaults = mapPropNamesToConstant(timeFieldNamesAsc, 0), isoCalendarId = "iso8601", gregoryCalendarId = "gregory", eraOriginsByCalendarId = {
    [gregoryCalendarId]: {
      bce: -1,
      ce: 0
    },
    japanese: {
      bce: -1,
      ce: 0,
      meiji: 1867,
      taisho: 1911,
      showa: 1925,
      heisei: 1988,
      reiwa: 2018
    },
    ethioaa: {
      era0: 0
    },
    ethiopic: {
      era0: 0,
      era1: 5500
    },
    coptic: {
      era0: -1,
      era1: 0
    },
    roc: {
      beforeroc: -1,
      minguo: 0
    },
    buddhist: {
      be: 0
    },
    islamic: {
      ah: 0
    },
    indian: {
      saka: 0
    },
    persian: {
      ap: 0
    }
  }, eraRemaps = {
    bc: "bce",
    ad: "ce"
  }, leapMonthMetas = {
    chinese: 13,
    dangi: 13,
    hebrew: -6
  }, durationFieldNamesAsc = unitNamesAsc.map((unitName => unitName + "s")), durationFieldNamesAlpha = sortStrings(durationFieldNamesAsc), durationTimeFieldNamesAsc = durationFieldNamesAsc.slice(0, 6), durationDateFieldNamesAsc = durationFieldNamesAsc.slice(6), durationFieldIndexes = mapPropNamesToIndex(durationFieldNamesAsc), durationFieldDefaults = mapPropNamesToConstant(durationFieldNamesAsc, 0), durationTimeFieldDefaults = mapPropNamesToConstant(durationTimeFieldNamesAsc, 0), isoTimeFieldNamesAsc = [ "isoNanosecond", "isoMicrosecond", "isoMillisecond", "isoSecond", "isoMinute", "isoHour" ], isoDateFieldNamesAsc = [ "isoDay", "isoMonth", "isoYear" ], isoDateTimeFieldNamesAsc = [ ...isoTimeFieldNamesAsc, ...isoDateFieldNamesAsc ], isoDateFieldNamesAlpha = sortStrings(isoDateFieldNamesAsc), isoTimeFieldNamesAlpha = sortStrings(isoTimeFieldNamesAsc), isoDateTimeFieldNamesAlpha = sortStrings(isoDateTimeFieldNamesAsc), isoTimeFieldDefaults = mapPropNamesToConstant(isoTimeFieldNamesAlpha, 0), RawDateTimeFormat = Intl.DateTimeFormat, maxDays = 1e8, epochNanoMax = [ maxDays, 0 ], epochNanoMin = [ -maxDays, 0 ], isoYearMax = 275760, isoYearMin = -271821, isoEpochOriginYear = 1970, isoEpochFirstLeapYear = 1972, isoMonthsInYear = 12, isoDaysInWeek = 7, primaryJapaneseEraMilli = isoArgsToEpochMilli(1868, 9, 8), queryJapaneseEraParts = createLazyGenerator((isoFields => {
    const epochMilli = isoToEpochMilli(isoFields);
    if (epochMilli < primaryJapaneseEraMilli) {
      return computeGregoryEraParts(isoFields);
    }
    const intlParts = hashIntlFormatParts(queryCalendarIntlFormat("japanese"), epochMilli), {era: era, eraYear: eraYear} = parseIntlYear(intlParts, "japanese");
    return [ era, eraYear ];
  }), WeakMap), requireString = bindArgs(requireType, "string"), requireBoolean = bindArgs(requireType, "boolean"), requireNumber = bindArgs(requireType, "number"), requireFunction = bindArgs(requireType, "function"), smallestUnitStr = "smallestUnit", roundingIncName = "roundingIncrement", subsecDigitsName = "fractionalSecondDigits", overflowMap = {
    constrain: 0,
    reject: 1
  }, overflowMapNames = Object.keys(overflowMap), refineSmallestUnit = bindArgs(refineUnitOption, smallestUnitStr), refineLargestUnit = bindArgs(refineUnitOption, "largestUnit"), refineTotalUnit = bindArgs(refineUnitOption, "unit"), refineOverflow = bindArgs(refineChoiceOption, "overflow", overflowMap), refineEpochDisambig = bindArgs(refineChoiceOption, "disambiguation", {
    compatible: 0,
    reject: 1,
    earlier: 2,
    later: 3
  }), refineOffsetDisambig = bindArgs(refineChoiceOption, "offset", {
    reject: 0,
    use: 1,
    prefer: 2,
    ignore: 3
  }), refineCalendarDisplay = bindArgs(refineChoiceOption, "calendarName", {
    auto: 0,
    never: 1,
    critical: 2,
    always: 3
  }), refineTimeZoneDisplay = bindArgs(refineChoiceOption, "timeZoneName", {
    auto: 0,
    never: 1,
    critical: 2
  }), refineOffsetDisplay = bindArgs(refineChoiceOption, "offset", {
    auto: 0,
    never: 1
  }), refineRoundingMode = bindArgs(refineChoiceOption, "roundingMode", {
    floor: 0,
    halfFloor: 1,
    ceil: 2,
    halfCeil: 3,
    trunc: 4,
    halfTrunc: 5,
    expand: 6,
    halfExpand: 7,
    halfEven: 8
  }), PlainYearMonthBranding = "PlainYearMonth", PlainMonthDayBranding = "PlainMonthDay", PlainDateBranding = "PlainDate", PlainDateTimeBranding = "PlainDateTime", PlainTimeBranding = "PlainTime", ZonedDateTimeBranding = "ZonedDateTime", InstantBranding = "Instant", DurationBranding = "Duration", roundingModeFuncs = [ Math.floor, num => hasHalf(num) ? Math.floor(num) : Math.round(num), Math.ceil, num => hasHalf(num) ? Math.ceil(num) : Math.round(num), Math.trunc, num => hasHalf(num) ? Math.trunc(num) || 0 : Math.round(num), num => num < 0 ? Math.floor(num) : Math.ceil(num), num => Math.sign(num) * Math.round(Math.abs(num)) || 0, num => hasHalf(num) ? (num = Math.trunc(num) || 0) + num % 2 : Math.round(num) ], utcTimeZoneId = "UTC", periodDur = 5184e3, minPossibleTransition = isoArgsToEpochSec(1847), maxPossibleTransition = isoArgsToEpochSec((new Date).getUTCFullYear() + 10), trailingZerosRE = /0+$/, zonedEpochSlotsToIso = createLazyGenerator(((slots, getTimeZoneOps) => {
    const {epochNanoseconds: epochNanoseconds} = slots, offsetNanoseconds = (getTimeZoneOps.getOffsetNanosecondsFor ? getTimeZoneOps : getTimeZoneOps(slots.timeZone)).getOffsetNanosecondsFor(epochNanoseconds), isoDateTimeFields = epochNanoToIso(epochNanoseconds, offsetNanoseconds);
    return {
      calendar: slots.calendar,
      ...isoDateTimeFields,
      offsetNanoseconds: offsetNanoseconds
    };
  }), WeakMap), queryDurationSign = createLazyGenerator(computeDurationSign, WeakMap), queryNativeTimeZone = createLazyGenerator((slotId => {
    const essence = getTimeZoneEssence(slotId);
    return "object" == typeof essence ? new IntlTimeZone(essence) : new FixedTimeZone(essence || 0);
  }));
  class FixedTimeZone {
    constructor(offsetNano) {
      this.offsetNano = offsetNano;
    }
    getOffsetNanosecondsFor() {
      return this.offsetNano;
    }
    getPossibleInstantsFor(isoDateTimeFields) {
      return [ isoToEpochNanoWithOffset(isoDateTimeFields, this.offsetNano) ];
    }
    getTransition() {}
  }
  class IntlTimeZone {
    constructor(format) {
      this.tzStore = (computeOffsetSec => {
        function getOffsetSec(epochSec) {
          const clampedEpochSec = clampNumber(epochSec, minTransition, maxTransition), [startEpochSec, endEpochSec] = computePeriod(clampedEpochSec), startOffsetSec = getSample(startEpochSec), endOffsetSec = getSample(endEpochSec);
          return startOffsetSec === endOffsetSec ? startOffsetSec : pinch(getSplit(startEpochSec, endEpochSec), startOffsetSec, endOffsetSec, epochSec);
        }
        function pinch(split, startOffsetSec, endOffsetSec, forEpochSec) {
          let offsetSec, splitDurSec;
          for (;(void 0 === forEpochSec || void 0 === (offsetSec = forEpochSec < split[0] ? startOffsetSec : forEpochSec >= split[1] ? endOffsetSec : void 0)) && (splitDurSec = split[1] - split[0]); ) {
            const middleEpochSec = split[0] + Math.floor(splitDurSec / 2);
            computeOffsetSec(middleEpochSec) === endOffsetSec ? split[1] = middleEpochSec : split[0] = middleEpochSec + 1;
          }
          return offsetSec;
        }
        const getSample = createLazyGenerator(computeOffsetSec), getSplit = createLazyGenerator(createSplitTuple);
        let minTransition = minPossibleTransition, maxTransition = maxPossibleTransition;
        return {
          getPossibleEpochSec(zonedEpochSec) {
            const wideOffsetSec0 = getOffsetSec(zonedEpochSec - 86400), wideOffsetSec1 = getOffsetSec(zonedEpochSec + 86400), wideUtcEpochSec0 = zonedEpochSec - wideOffsetSec0, wideUtcEpochSec1 = zonedEpochSec - wideOffsetSec1;
            if (wideOffsetSec0 === wideOffsetSec1) {
              return [ wideUtcEpochSec0 ];
            }
            const narrowOffsetSec0 = getOffsetSec(wideUtcEpochSec0);
            return narrowOffsetSec0 === getOffsetSec(wideUtcEpochSec1) ? [ zonedEpochSec - narrowOffsetSec0 ] : wideOffsetSec0 > wideOffsetSec1 ? [ wideUtcEpochSec0, wideUtcEpochSec1 ] : [];
          },
          getOffsetSec: getOffsetSec,
          getTransition(epochSec, direction) {
            const clampedEpochSec = clampNumber(epochSec, minTransition, maxTransition);
            let [startEpochSec, endEpochSec] = computePeriod(clampedEpochSec);
            const inc = periodDur * direction, inBounds = direction < 0 ? () => endEpochSec > minTransition || (minTransition = clampedEpochSec, 
            0) : () => startEpochSec < maxTransition || (maxTransition = clampedEpochSec, 0);
            for (;inBounds(); ) {
              const startOffsetSec = getSample(startEpochSec), endOffsetSec = getSample(endEpochSec);
              if (startOffsetSec !== endOffsetSec) {
                const split = getSplit(startEpochSec, endEpochSec);
                pinch(split, startOffsetSec, endOffsetSec);
                const transitionEpochSec = split[0];
                if ((compareNumbers(transitionEpochSec, epochSec) || 1) === direction) {
                  return transitionEpochSec;
                }
              }
              startEpochSec += inc, endEpochSec += inc;
            }
          }
        };
      })((format => epochSec => {
        const intlParts = hashIntlFormatParts(format, epochSec * milliInSec);
        return isoArgsToEpochSec(parseIntlPartsYear(intlParts), parseInt(intlParts.month), parseInt(intlParts.day), parseInt(intlParts.hour), parseInt(intlParts.minute), parseInt(intlParts.second)) - epochSec;
      })(format));
    }
    getOffsetNanosecondsFor(epochNano) {
      return this.tzStore.getOffsetSec(epochNanoToSec(epochNano)) * nanoInSec;
    }
    getPossibleInstantsFor(isoFields) {
      const [zonedEpochSec, subsecNano] = [ isoArgsToEpochSec((isoDateTimeFields = isoFields).isoYear, isoDateTimeFields.isoMonth, isoDateTimeFields.isoDay, isoDateTimeFields.isoHour, isoDateTimeFields.isoMinute, isoDateTimeFields.isoSecond), isoDateTimeFields.isoMillisecond * nanoInMilli + isoDateTimeFields.isoMicrosecond * nanoInMicro + isoDateTimeFields.isoNanosecond ];
      var isoDateTimeFields;
      return this.tzStore.getPossibleEpochSec(zonedEpochSec).map((epochSec => checkEpochNanoInBounds(addDayTimeNanoAndNumber(numberToDayTimeNano(epochSec, nanoInSec), subsecNano))));
    }
    getTransition(epochNano, direction) {
      const [epochSec, subsecNano] = (epochNano => dayTimeNanoToNumberRemainder(epochNano, nanoInSec))(epochNano), resEpochSec = this.tzStore.getTransition(epochSec + (direction > 0 || subsecNano ? 1 : 0), direction);
      if (void 0 !== resEpochSec) {
        return numberToDayTimeNano(resEpochSec, nanoInSec);
      }
    }
  }
  const timeRegExpStr = "(\\d{2})(?::?(\\d{2})(?::?(\\d{2})(?:[.,](\\d{1,9}))?)?)?", offsetRegExpStr = "([+−-])" + timeRegExpStr, dateTimeRegExpStr = "(?:(?:([+−-])(\\d{6}))|(\\d{4}))-?(\\d{2})-?(\\d{2})(?:[T ]" + timeRegExpStr + "(Z|" + offsetRegExpStr + ")?)?", yearMonthRegExp = createRegExp("(?:(?:([+−-])(\\d{6}))|(\\d{4}))-?(\\d{2})((?:\\[(!?)([^\\]]*)\\])*)"), monthDayRegExp = createRegExp("(?:--)?(\\d{2})-?(\\d{2})((?:\\[(!?)([^\\]]*)\\])*)"), dateTimeRegExp = createRegExp(dateTimeRegExpStr + "((?:\\[(!?)([^\\]]*)\\])*)"), timeRegExp = createRegExp("T?" + timeRegExpStr + "(?:" + offsetRegExpStr + ")?((?:\\[(!?)([^\\]]*)\\])*)"), offsetRegExp = createRegExp(offsetRegExpStr), annotationRegExp = new RegExp("\\[(!?)([^\\]]*)\\]", "g"), durationRegExp = createRegExp("([+−-])?P(\\d+Y)?(\\d+M)?(\\d+W)?(\\d+D)?(?:T(?:(\\d+)(?:[.,](\\d{1,9}))?H)?(?:(\\d+)(?:[.,](\\d{1,9}))?M)?(?:(\\d+)(?:[.,](\\d{1,9}))?S)?)?"), queryTimeZoneIntlFormat = createLazyGenerator((id => new RawDateTimeFormat("en-GB", {
    timeZone: id,
    era: "short",
    year: "numeric",
    month: "numeric",
    day: "numeric",
    hour: "numeric",
    minute: "numeric",
    second: "numeric"
  }))), queryIntlCalendar = createLazyGenerator((calendarId => {
    function epochMilliToIntlFields(epochMilli) {
      return ((intlParts, calendarIdBase) => ({
        ...parseIntlYear(intlParts, calendarIdBase),
        month: intlParts.month,
        day: parseInt(intlParts.day)
      }))(hashIntlFormatParts(intlFormat, epochMilli), calendarIdBase);
    }
    const intlFormat = queryCalendarIntlFormat(calendarId), calendarIdBase = computeCalendarIdBase(calendarId);
    return {
      id: calendarId,
      queryFields: createIntlFieldCache(epochMilliToIntlFields),
      queryYearMonths: createIntlYearMonthCache(epochMilliToIntlFields)
    };
  })), queryCalendarIntlFormat = createLazyGenerator((id => new RawDateTimeFormat("en-GB", {
    calendar: id,
    timeZone: utcTimeZoneId,
    era: "short",
    year: "numeric",
    month: "short",
    day: "numeric"
  }))), nativeStandardBase = {
    dateAdd: nativeDateAdd,
    dateUntil(startIsoFields, endIsoFields, largestUnit) {
      if (largestUnit <= 7) {
        let weeks = 0, days = diffDays(startIsoFields, endIsoFields);
        return 7 === largestUnit && ([weeks, days] = divModTrunc(days, isoDaysInWeek)), 
        {
          ...durationFieldDefaults,
          weeks: weeks,
          days: days
        };
      }
      const yearMonthDayStart = this.dateParts(startIsoFields), yearMonthDayEnd = this.dateParts(endIsoFields);
      let [years, months, days] = ((calendarNative, year0, month0, day0, year1, month1, day1) => {
        function updateYearMonth() {
          const [monthCodeNumber0, isLeapYear0] = calendarNative.monthCodeParts(year0, month0), [monthCodeNumber1, isLeapYear1] = calendarNative.monthCodeParts(year1, month1);
          yearDiff = year1 - year0, monthsInYear1 = calendarNative.monthsInYearPart(year1), 
          monthDiff = yearDiff ? monthCodeNumber1 - monthCodeNumber0 || Number(isLeapYear1) - Number(isLeapYear0) : month1 - Math.min(month0, monthsInYear1);
        }
        function updateYearMonthDay() {
          updateYearMonth(), daysInMonth1 = calendarNative.daysInMonthParts(year1, month1), 
          dayDiff = day1 - Math.min(day0, daysInMonth1);
        }
        let yearDiff, monthsInYear1, monthDiff, daysInMonth1, dayDiff;
        updateYearMonthDay();
        const daySign = Math.sign(dayDiff), sign = Math.sign(yearDiff) || Math.sign(monthDiff) || daySign;
        if (sign) {
          if (daySign === -sign) {
            const oldDaysInMonth1 = daysInMonth1;
            [year1, month1] = calendarNative.monthAdd(year1, month1, -sign), updateYearMonthDay(), 
            dayDiff += sign < 0 ? -oldDaysInMonth1 : daysInMonth1;
          }
          if (Math.sign(monthDiff) === -sign) {
            const oldMonthsInYear1 = monthsInYear1;
            year1 -= sign, updateYearMonth(), monthDiff += sign < 0 ? -oldMonthsInYear1 : monthsInYear1;
          }
        }
        return [ yearDiff, monthDiff, dayDiff ];
      })(this, ...yearMonthDayStart, ...yearMonthDayEnd);
      return 8 === largestUnit && (months += this.monthsInYearSpan(years, yearMonthDayStart[0]), 
      years = 0), {
        ...durationFieldDefaults,
        years: years,
        months: months,
        days: days
      };
    },
    dateFromFields(fields, options) {
      const overflow = refineOverflowOptions(options), year = refineYear(this, fields), month = refineMonth(this, fields, year, overflow), day = refineDay(this, fields, month, year, overflow);
      return createPlainDateSlots(checkIsoDateInBounds(this.isoFields(year, month, day)), this.id || isoCalendarId);
    },
    yearMonthFromFields(fields, options) {
      const overflow = refineOverflowOptions(options), year = refineYear(this, fields), month = refineMonth(this, fields, year, overflow);
      return createPlainYearMonthSlots(checkIsoYearMonthInBounds(this.isoFields(year, month, 1)), this.id || isoCalendarId);
    },
    monthDayFromFields(fields, options) {
      const overflow = refineOverflowOptions(options), isIso = !this.id, {monthCode: monthCode, year: year, month: month} = fields;
      let monthCodeNumber, isLeapMonth, normalYear, normalMonth, normalDay;
      if (void 0 !== monthCode) {
        [monthCodeNumber, isLeapMonth] = parseMonthCode(monthCode), normalDay = getDefinedProp(fields, "day");
        const res = this.yearMonthForMonthDay(monthCodeNumber, isLeapMonth, normalDay);
        if (!res) {
          throw new RangeError("Cannot guess year");
        }
        if ([normalYear, normalMonth] = res, void 0 !== month && month !== normalMonth) {
          throw new RangeError(mismatchingMonthAndCode);
        }
        isIso && (normalMonth = clampEntity("month", normalMonth, 1, isoMonthsInYear, 1), 
        normalDay = clampEntity("day", normalDay, 1, computeIsoDaysInMonth(void 0 !== year ? year : normalYear, normalMonth), overflow));
      } else {
        normalYear = void 0 === year && isIso ? isoEpochFirstLeapYear : refineYear(this, fields), 
        normalMonth = refineMonth(this, fields, normalYear, overflow), normalDay = refineDay(this, fields, normalMonth, normalYear, overflow);
        const leapMonth = this.leapMonth(normalYear);
        isLeapMonth = normalMonth === leapMonth, monthCodeNumber = monthToMonthCodeNumber(normalMonth, leapMonth);
        const res = this.yearMonthForMonthDay(monthCodeNumber, isLeapMonth, normalDay);
        if (!res) {
          throw new RangeError("Cannot guess year");
        }
        [normalYear, normalMonth] = res;
      }
      return createPlainMonthDaySlots(this.isoFields(normalYear, normalMonth, normalDay), this.id || isoCalendarId);
    },
    fields(fieldNames) {
      return getCalendarEraOrigins(this) && fieldNames.includes("year") ? [ ...fieldNames, ...eraYearFieldNames ] : fieldNames;
    },
    mergeFields(baseFields, additionalFields) {
      const merged = Object.assign(Object.create(null), baseFields);
      return spliceFields(merged, additionalFields, monthFieldNames), getCalendarEraOrigins(this) && (spliceFields(merged, additionalFields, allYearFieldNames), 
      "japanese" === this.id && spliceFields(merged, additionalFields, monthDayFieldNames, eraYearFieldNames)), 
      merged;
    },
    inLeapYear(isoFields) {
      const [year] = this.dateParts(isoFields);
      return this.inLeapYearPart(year);
    },
    monthsInYear(isoFields) {
      const [year] = this.dateParts(isoFields);
      return this.monthsInYearPart(year);
    },
    daysInMonth(isoFields) {
      const [year, month] = this.dateParts(isoFields);
      return this.daysInMonthParts(year, month);
    },
    daysInYear(isoFields) {
      const [year] = this.dateParts(isoFields);
      return this.daysInYearPart(year);
    },
    era(isoFields) {
      return this.eraParts(isoFields)[0];
    },
    eraYear(isoFields) {
      return this.eraParts(isoFields)[1];
    },
    monthCode(isoFields) {
      const [year, month] = this.dateParts(isoFields), [monthCodeNumber, isLeapMonth] = this.monthCodeParts(year, month);
      return ((monthCodeNumber, isLeapMonth) => "M" + padNumber2(monthCodeNumber) + (isLeapMonth ? "L" : ""))(monthCodeNumber, isLeapMonth);
    },
    dayOfWeek: computeIsoDayOfWeek,
    weekOfYear(isoDateFields) {
      return computeIsoWeekParts(isoDateFields)[1];
    },
    yearOfWeek(isoDateFields) {
      return computeIsoWeekParts(isoDateFields)[0];
    },
    daysInWeek() {
      return isoDaysInWeek;
    }
  }, monthCodeRegExp = /^M(\d{2})(L?)$/, builtinRefiners = {
    era: toStringViaPrimitive,
    eraYear: toInteger,
    year: toInteger,
    month: toPositiveInteger,
    monthCode: toStringViaPrimitive,
    day: toPositiveInteger,
    ...mapPropNamesToConstant(timeFieldNamesAsc, toInteger),
    ...mapPropNamesToConstant(durationFieldNamesAsc, toStrictInteger),
    offset: toStringViaPrimitive
  }, timeFieldsToIso = bindArgs(((oldNames, newNames, oldProps) => {
    const newProps = {};
    for (let i = 0; i < oldNames.length; i++) {
      newProps[newNames[i]] = oldProps[oldNames[i]];
    }
    return newProps;
  }), timeFieldNamesAsc, isoTimeFieldNamesAsc), isoStandardOps = {
    ...nativeStandardBase,
    dateParts(isoFields) {
      return [ isoFields.isoYear, isoFields.isoMonth, isoFields.isoDay ];
    },
    eraParts(isoFields) {
      return this.id === gregoryCalendarId ? computeGregoryEraParts(isoFields) : "japanese" === this.id ? queryJapaneseEraParts(isoFields) : [ void 0, void 0 ];
    },
    monthCodeParts(_isoYear, isoMonth) {
      return [ isoMonth, 0 ];
    },
    yearMonthForMonthDay(monthCodeNumber, isLeapMonth) {
      if (!isLeapMonth) {
        return [ isoEpochFirstLeapYear, monthCodeNumber ];
      }
    },
    inLeapYearPart: computeIsoInLeapYear,
    leapMonth() {},
    monthsInYearPart: computeIsoMonthsInYear,
    monthsInYearSpan: yearDelta => yearDelta * isoMonthsInYear,
    daysInMonthParts: computeIsoDaysInMonth,
    daysInYearPart: computeIsoDaysInYear,
    dayOfYear: computeIsoDayOfYear,
    isoFields(year, month, day) {
      return {
        isoYear: year,
        isoMonth: month,
        isoDay: day
      };
    },
    epochMilli: isoArgsToEpochMilli,
    monthAdd(year, month, monthDelta) {
      return year += divTrunc(monthDelta, isoMonthsInYear), (month += modTrunc(monthDelta, isoMonthsInYear)) < 1 ? (year--, 
      month += isoMonthsInYear) : month > isoMonthsInYear && (year++, month -= isoMonthsInYear), 
      [ year, month ];
    },
    year(isoFields) {
      return isoFields.isoYear;
    },
    month(isoFields) {
      return isoFields.isoMonth;
    },
    day: isoFields => isoFields.isoDay
  }, intlStandardOps = {
    ...nativeStandardBase,
    dateParts: computeIntlDateParts,
    eraParts(isoFields) {
      const intlFields = this.queryFields(isoFields);
      return [ intlFields.era, intlFields.eraYear ];
    },
    monthCodeParts(year, month) {
      const leapMonth = computeIntlLeapMonth.call(this, year);
      return [ monthToMonthCodeNumber(month, leapMonth), leapMonth === month ];
    },
    yearMonthForMonthDay(monthCodeNumber, isLeapMonth, day) {
      let [startYear, startMonth, startDay] = computeIntlDateParts.call(this, {
        isoYear: isoEpochFirstLeapYear,
        isoMonth: isoMonthsInYear,
        isoDay: 31
      });
      const startYearLeapMonth = computeIntlLeapMonth.call(this, startYear), startMonthIsLeap = startMonth === startYearLeapMonth;
      1 === (compareNumbers(monthCodeNumber, monthToMonthCodeNumber(startMonth, startYearLeapMonth)) || compareNumbers(Number(isLeapMonth), Number(startMonthIsLeap)) || compareNumbers(day, startDay)) && startYear--;
      for (let yearMove = 0; yearMove < 100; yearMove++) {
        const tryYear = startYear - yearMove, tryLeapMonth = computeIntlLeapMonth.call(this, tryYear), tryMonth = monthCodeNumberToMonth(monthCodeNumber, isLeapMonth, tryLeapMonth);
        if (isLeapMonth === (tryMonth === tryLeapMonth) && day <= computeIntlDaysInMonth.call(this, tryYear, tryMonth)) {
          return [ tryYear, tryMonth ];
        }
      }
    },
    inLeapYearPart(year) {
      const days = computeIntlDaysInYear.call(this, year);
      return days > computeIntlDaysInYear.call(this, year - 1) && days > computeIntlDaysInYear.call(this, year + 1);
    },
    leapMonth: computeIntlLeapMonth,
    monthsInYearPart: computeIntlMonthsInYear,
    monthsInYearSpan(yearDelta, yearStart) {
      const yearEnd = yearStart + yearDelta, yearSign = Math.sign(yearDelta), yearCorrection = yearSign < 0 ? -1 : 0;
      let months = 0;
      for (let year = yearStart; year !== yearEnd; year += yearSign) {
        months += computeIntlMonthsInYear.call(this, year + yearCorrection);
      }
      return months;
    },
    daysInMonthParts: computeIntlDaysInMonth,
    daysInYearPart: computeIntlDaysInYear,
    dayOfYear(isoFields) {
      const dayEpochMilli = isoToEpochMilli({
        ...isoFields,
        ...isoTimeFieldDefaults
      }), {year: year} = this.queryFields(isoFields);
      return diffEpochMilliByDay(computeIntlEpochMilli.call(this, year), dayEpochMilli);
    },
    isoFields(year, month, day) {
      return checkIsoDateInBounds({
        ...epochMilliToIso(computeIntlEpochMilli.call(this, year, month, day))
      });
    },
    epochMilli: computeIntlEpochMilli,
    monthAdd(year, month, monthDelta) {
      if (monthDelta) {
        if (month += monthDelta, monthDelta < 0) {
          if (month < Number.MIN_SAFE_INTEGER) {
            throw new RangeError(outOfBoundsDate);
          }
          for (;month < 1; ) {
            month += computeIntlMonthsInYear.call(this, --year);
          }
        } else {
          if (month > Number.MAX_SAFE_INTEGER) {
            throw new RangeError(outOfBoundsDate);
          }
          let monthsInYear;
          for (;month > (monthsInYear = computeIntlMonthsInYear.call(this, year)); ) {
            month -= monthsInYear, year++;
          }
        }
      }
      return [ year, month ];
    },
    year(isoFields) {
      return this.queryFields(isoFields).year;
    },
    month(isoFields) {
      const {year: year, month: month} = this.queryFields(isoFields), {monthStrToIndex: monthStrToIndex} = this.queryYearMonths(year);
      return monthStrToIndex[month] + 1;
    },
    day(isoFields) {
      return this.queryFields(isoFields).day;
    }
  }, createNativeStandardOps = (isoOps = isoStandardOps, intlOps = intlStandardOps, 
  calendarId => calendarId === isoCalendarId ? isoOps : calendarId === gregoryCalendarId || "japanese" === calendarId ? Object.assign(Object.create(isoOps), {
    id: calendarId
  }) : Object.assign(Object.create(intlOps), queryIntlCalendar(calendarId)));
  var isoOps, intlOps;
  const timeZoneNameStrs = [ "timeZoneName" ], monthDayFallbacks = {
    month: "numeric",
    day: "numeric"
  }, yearMonthFallbacks = {
    year: "numeric",
    month: "numeric"
  }, dateFallbacks = {
    ...yearMonthFallbacks,
    day: "numeric"
  }, timeFallbacks = {
    hour: "numeric",
    minute: "numeric",
    second: "numeric"
  }, dateTimeFallbacks = {
    ...dateFallbacks,
    ...timeFallbacks
  }, zonedFallbacks = {
    ...dateTimeFallbacks,
    timeZoneName: "short"
  }, monthDayValidNames = Object.keys(monthDayFallbacks), yearMonthValidNames = Object.keys(yearMonthFallbacks), dateValidNames = [ ...Object.keys(dateFallbacks), "weekday", "dateStyle" ], timeValidNames = [ ...Object.keys(timeFallbacks), "dayPeriod", "timeStyle" ], dateTimeValidNames = [ ...dateValidNames, ...timeValidNames ], zonedValidNames = [ ...dateTimeValidNames, ...timeZoneNameStrs ], dateExclusions = [ ...timeZoneNameStrs, ...timeValidNames ], timeExclusions = [ ...timeZoneNameStrs, ...dateValidNames ], yearMonthExclusions = [ ...timeZoneNameStrs, "day", "weekday", "dateStyle", ...timeValidNames ], transformMonthDayOptions = createOptionsTransformer(monthDayValidNames, monthDayFallbacks, [ ...timeZoneNameStrs, "year", "weekday", "dateStyle", ...timeValidNames ]), plainYearMonthConfig = [ createOptionsTransformer(yearMonthValidNames, yearMonthFallbacks, yearMonthExclusions), isoDateFieldsToEpochNano, 1 ], plainMonthDayConfig = [ transformMonthDayOptions, isoDateFieldsToEpochNano, 1 ], plainDateConfig = [ createOptionsTransformer(dateValidNames, dateFallbacks, dateExclusions), isoDateFieldsToEpochNano ], plainDateTimeConfig = [ createOptionsTransformer(dateTimeValidNames, dateTimeFallbacks, timeZoneNameStrs), isoDateFieldsToEpochNano ], plainTimeConfig = [ createOptionsTransformer(timeValidNames, timeFallbacks, timeExclusions), (internals, resolvedOptions) => getSingleInstantFor(queryNativeTimeZone(resolvedOptions.timeZone), {
    isoYear: isoEpochOriginYear,
    isoMonth: 1,
    isoDay: 1,
    ...internals
  }) ], instantConfig = [ createOptionsTransformer(dateTimeValidNames, dateTimeFallbacks), extractEpochNano ], zonedDateTimeConfig = [ createOptionsTransformer(zonedValidNames, zonedFallbacks), extractEpochNano, 0, (slots0, slots1) => {
    const timeZoneId = getId(slots0.timeZone);
    if (slots1 && getId(slots1.timeZone) !== timeZoneId) {
      throw new RangeError(mismatchingTimeZones);
    }
    return timeZoneId;
  } ], emptyOptions = {}, slotsMap = new WeakMap, getSlots = slotsMap.get.bind(slotsMap), setSlots = slotsMap.set.bind(slotsMap), DateTimeFormat = function() {
    const members = RawDateTimeFormat.prototype, memberDescriptors = Object.getOwnPropertyDescriptors(members), classDescriptors = Object.getOwnPropertyDescriptors(RawDateTimeFormat), DateTimeFormat = function(locales, options = {}) {
      if (!(this instanceof DateTimeFormat)) {
        return new DateTimeFormat(locales, options);
      }
      internalsMap.set(this, ((locales, options = {}) => {
        const rawFormat = new RawDateTimeFormat(locales, options), resolveOptions = rawFormat.resolvedOptions(), resolvedLocale = resolveOptions.locale, copiedOptions = pluckProps(Object.keys(options), resolveOptions), queryFormatPrepperForBranding = createLazyGenerator(createFormatPrepperForBranding), prepFormat = (...formattables) => {
          let branding;
          const slotsList = formattables.map(((formattable, i) => {
            const slots = getSlots(formattable), slotsBranding = (slots || {}).branding;
            if (i && branding && branding !== slotsBranding) {
              throw new TypeError("Mismatching types for formatting");
            }
            return branding = slotsBranding, slots;
          }));
          return branding ? queryFormatPrepperForBranding(branding)(resolvedLocale, copiedOptions, ...slotsList) : [ rawFormat, ...formattables ];
        };
        return prepFormat.rawFormat = rawFormat, prepFormat;
      })(locales, options));
    };
    for (const memberName in memberDescriptors) {
      const memberDescriptor = memberDescriptors[memberName], formatLikeMethod = memberName.startsWith("format") && createFormatMethod(memberName);
      "function" == typeof memberDescriptor.value ? memberDescriptor.value = "constructor" === memberName ? DateTimeFormat : formatLikeMethod || createProxiedMethod(memberName) : formatLikeMethod && (memberDescriptor.get = function() {
        return formatLikeMethod.bind(this);
      });
    }
    return classDescriptors.prototype.value = Object.create(members, memberDescriptors), 
    Object.defineProperties(DateTimeFormat, classDescriptors), DateTimeFormat;
  }(), internalsMap = new WeakMap, classFormatConfigs = {
    PlainYearMonth: plainYearMonthConfig,
    PlainMonthDay: plainMonthDayConfig,
    PlainDate: plainDateConfig,
    PlainDateTime: plainDateTimeConfig,
    PlainTime: plainTimeConfig,
    Instant: instantConfig
  }, prepPlainYearMonthFormat = createFormatPrepper(plainYearMonthConfig), prepPlainMonthDayFormat = createFormatPrepper(plainMonthDayConfig), prepPlainDateFormat = createFormatPrepper(plainDateConfig), prepPlainDateTimeFormat = createFormatPrepper(plainDateTimeConfig), prepPlainTimeFormat = createFormatPrepper(plainTimeConfig), prepInstantFormat = createFormatPrepper(instantConfig), prepZonedDateTimeFormat = createFormatPrepper(zonedDateTimeConfig), yearMonthOnlyRefiners = {
    era(input) {
      if (void 0 !== input && "string" != typeof input) {
        throw new TypeError("Expected string or undefined");
      }
      return input;
    },
    eraYear(input) {
      if ("number" == typeof input) {
        requireNumberIsInteger(input);
      } else if (void 0 !== input) {
        throw new TypeError("Expected integer or undefined");
      }
      return input;
    },
    year: requireInteger,
    month: requirePositiveInteger,
    daysInMonth: requirePositiveInteger,
    daysInYear: requirePositiveInteger,
    inLeapYear: requireBoolean,
    monthsInYear: requirePositiveInteger
  }, monthOnlyRefiners = {
    monthCode: requireString
  }, dayOnlyRefiners = {
    day: requirePositiveInteger
  }, dateOnlyRefiners = {
    dayOfWeek: requirePositiveInteger,
    dayOfYear: requirePositiveInteger,
    weekOfYear: requirePositiveInteger,
    yearOfWeek: requireInteger,
    daysInWeek: requirePositiveInteger
  }, dateRefiners = {
    ...yearMonthOnlyRefiners,
    ...monthOnlyRefiners,
    ...dayOnlyRefiners,
    ...dateOnlyRefiners
  }, calendarFieldMethods = {
    ...createCalendarFieldMethods(yearMonthOnlyRefiners, [ PlainYearMonthBranding ]),
    ...createCalendarFieldMethods(dateOnlyRefiners, []),
    ...createCalendarFieldMethods(monthOnlyRefiners, [ PlainYearMonthBranding, PlainMonthDayBranding ]),
    ...createCalendarFieldMethods(dayOnlyRefiners, [ PlainMonthDayBranding ])
  }, dateGetters = createCalendarGetters(dateRefiners), yearMonthGetters = createCalendarGetters({
    ...yearMonthOnlyRefiners,
    ...monthOnlyRefiners
  }), monthDayGetters = createCalendarGetters({
    ...monthOnlyRefiners,
    ...dayOnlyRefiners
  }), calendarIdGetters = {
    calendarId: slots => getId(slots.calendar)
  }, adapterSimpleOps = mapProps(((refiner, methodName) => function(isoFields) {
    const {calendarProtocol: calendarProtocol} = this;
    return refiner(calendarProtocol[methodName](createPlainDate(createPlainDateSlots(isoFields, calendarProtocol))));
  }), dateRefiners), durationGetters = mapPropNames((propName => slots => slots[propName]), durationFieldNamesAsc), timeGetters = mapPropNames(((_name, i) => slots => slots[isoTimeFieldNamesAsc[i]]), timeFieldNamesAsc), epochGetters = {
    epochSeconds(slots) {
      return epochNanoToSec(slots.epochNanoseconds);
    },
    epochMilliseconds(slots) {
      return epochNanoToMilli(slots.epochNanoseconds);
    },
    epochMicroseconds(slots) {
      return dayTimeNanoToBigInt(slots.epochNanoseconds, nanoInMicro);
    },
    epochNanoseconds(slots) {
      return dayTimeNanoToBigInt(slots.epochNanoseconds);
    }
  }, removeBranding = bindArgs(excludePropsByName, new Set([ "branding" ])), [PlainMonthDay, createPlainMonthDay, getPlainMonthDaySlots] = createSlotClass(PlainMonthDayBranding, bindArgs(((refineCalendarArg, isoMonth, isoDay, calendar = isoCalendarId, referenceIsoYear = isoEpochFirstLeapYear) => {
    const isoMonthInt = toInteger(isoMonth), isoDayInt = toInteger(isoDay), calendarSlot = refineCalendarArg(calendar);
    return createPlainMonthDaySlots(checkIsoDateInBounds(checkIsoDateFields({
      isoYear: toInteger(referenceIsoYear),
      isoMonth: isoMonthInt,
      isoDay: isoDayInt
    })), calendarSlot);
  }), refineCalendarSlot), {
    ...calendarIdGetters,
    ...monthDayGetters
  }, {
    with(slots, mod, options) {
      return createPlainMonthDay(((getCalendarOps, plainMonthDaySlots, initialFields, modFields, options) => {
        const optionsCopy = copyOptions(options);
        return ((calendarOps, plainMonthDay, bag, options) => {
          const fields = mergeCalendarFields(calendarOps, plainMonthDay, bag, dateFieldNamesAlpha);
          return calendarOps.monthDayFromFields(fields, options);
        })(getCalendarOps(plainMonthDaySlots.calendar), initialFields, modFields, optionsCopy);
      })(createMonthDayModOps, slots, this, rejectInvalidBag(mod), options));
    },
    equals(slots, otherArg) {
      return !compareIsoDateFields(plainMonthDaySlots0 = slots, plainMonthDaySlots1 = toPlainMonthDaySlots(otherArg)) && isIdLikeEqual(plainMonthDaySlots0.calendar, plainMonthDaySlots1.calendar);
      var plainMonthDaySlots0, plainMonthDaySlots1;
    },
    toString: formatPlainMonthDayIso,
    toJSON: slots => formatPlainMonthDayIso(slots),
    toLocaleString(slots, locales, options) {
      const [format, epochMilli] = prepPlainMonthDayFormat(locales, options, slots);
      return format.format(epochMilli);
    },
    toPlainDate(slots, bag) {
      return createPlainDate(((getCalendarOps, plainMonthDaySlots, plainMonthDayFields, bag) => ((calendarOps, plainMonthDay, bag) => convertToIso(calendarOps, plainMonthDay, monthCodeDayFieldNames, requireObjectLike(bag), yearFieldNames))(getCalendarOps(plainMonthDaySlots.calendar), plainMonthDayFields, bag))(createDateModOps, slots, this, bag));
    },
    getISOFields: removeBranding,
    getCalendar: createCalendarFromSlots,
    valueOf: neverValueOf
  }, {
    from: (arg, options) => createPlainMonthDay(toPlainMonthDaySlots(arg, options))
  }), timeZoneAdapters = {
    getOffsetNanosecondsFor: getOffsetNanosecondsForAdapter,
    getPossibleInstantsFor(timeZoneProtocol, getPossibleInstantsFor, isoFields) {
      return [ ...getPossibleInstantsFor.call(timeZoneProtocol, createPlainDateTime(createPlainDateTimeSlots(isoFields, isoCalendarId))) ].map((instant => getInstantSlots(instant).epochNanoseconds));
    }
  }, simpleTimeZoneAdapters = {
    getOffsetNanosecondsFor: getOffsetNanosecondsForAdapter
  }, [PlainYearMonth, createPlainYearMonth, getPlainYearMonthSlots] = createSlotClass(PlainYearMonthBranding, bindArgs(((refineCalendarArg, isoYear, isoMonth, calendar = isoCalendarId, referenceIsoDay = 1) => {
    const isoYearInt = toInteger(isoYear), isoMonthInt = toInteger(isoMonth), calendarSlot = refineCalendarArg(calendar);
    return createPlainYearMonthSlots(checkIsoYearMonthInBounds(checkIsoDateFields({
      isoYear: isoYearInt,
      isoMonth: isoMonthInt,
      isoDay: toInteger(referenceIsoDay)
    })), calendarSlot);
  }), refineCalendarSlot), {
    ...calendarIdGetters,
    ...yearMonthGetters
  }, {
    with(slots, mod, options) {
      return createPlainYearMonth(((getCalendarOps, plainYearMonthSlots, initialFields, modFields, options) => {
        const optionsCopy = copyOptions(options);
        return createPlainYearMonthSlots(((calendarOps, plainYearMonth, bag, options) => {
          const fields = mergeCalendarFields(calendarOps, plainYearMonth, bag, yearMonthFieldNames);
          return calendarOps.yearMonthFromFields(fields, options);
        })(getCalendarOps(plainYearMonthSlots.calendar), initialFields, modFields, optionsCopy));
      })(createYearMonthModOps, slots, this, rejectInvalidBag(mod), options));
    },
    add: (slots, durationArg, options) => createPlainYearMonth(movePlainYearMonth(createYearMonthMoveOps, 0, slots, toDurationSlots(durationArg), options)),
    subtract: (slots, durationArg, options) => createPlainYearMonth(movePlainYearMonth(createYearMonthMoveOps, 1, slots, toDurationSlots(durationArg), options)),
    until: (slots, otherArg, options) => createDuration(diffPlainYearMonth(createYearMonthDiffOps, 0, slots, toPlainYearMonthSlots(otherArg), options)),
    since: (slots, otherArg, options) => createDuration(diffPlainYearMonth(createYearMonthDiffOps, 1, slots, toPlainYearMonthSlots(otherArg), options)),
    equals(slots, otherArg) {
      return !compareIsoDateFields(plainYearMonthSlots0 = slots, plainYearMonthSlots1 = toPlainYearMonthSlots(otherArg)) && isIdLikeEqual(plainYearMonthSlots0.calendar, plainYearMonthSlots1.calendar);
      var plainYearMonthSlots0, plainYearMonthSlots1;
    },
    toString: formatPlainYearMonthIso,
    toJSON: slots => formatPlainYearMonthIso(slots),
    toLocaleString(slots, locales, options) {
      const [format, epochMilli] = prepPlainYearMonthFormat(locales, options, slots);
      return format.format(epochMilli);
    },
    toPlainDate(slots, bag) {
      return createPlainDate(((getCalendarOps, plainYearMonthSlots, plainYearMonthFields, bag) => ((calendarOps, plainYearMonth, bag) => convertToIso(calendarOps, plainYearMonth, yearMonthCodeFieldNames, requireObjectLike(bag), dayFieldNames))(getCalendarOps(plainYearMonthSlots.calendar), plainYearMonthFields, bag))(createDateModOps, slots, this, bag));
    },
    getISOFields: removeBranding,
    getCalendar: createCalendarFromSlots,
    valueOf: neverValueOf
  }, {
    from: (arg, options) => createPlainYearMonth(toPlainYearMonthSlots(arg, options)),
    compare: (arg0, arg1) => compareIsoDateFields(toPlainYearMonthSlots(arg0), toPlainYearMonthSlots(arg1))
  }), [ZonedDateTime, createZonedDateTime] = createSlotClass(ZonedDateTimeBranding, bindArgs(((refineCalendarArg, refineTimeZoneArg, epochNano, timeZoneArg, calendarArg = isoCalendarId) => createZonedDateTimeSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(epochNano))), refineTimeZoneArg(timeZoneArg), refineCalendarArg(calendarArg))), refineCalendarSlot, refineTimeZoneSlot), {
    ...epochGetters,
    ...calendarIdGetters,
    ...adaptDateMethods(dateGetters),
    ...adaptDateMethods(timeGetters),
    hoursInDay: slots => ((getTimeZoneOps, zonedDateTimeSlots) => {
      const timeZoneOps = getTimeZoneOps(zonedDateTimeSlots.timeZone);
      return computeNanosecondsInDay(timeZoneOps, zonedEpochSlotsToIso(zonedDateTimeSlots, timeZoneOps)) / nanoInHour;
    })(createTimeZoneOps, slots),
    offsetNanoseconds: slots => slotsToIso(slots).offsetNanoseconds,
    offset: slots => formatOffsetNano(slotsToIso(slots).offsetNanoseconds),
    timeZoneId: slots => getId(slots.timeZone)
  }, {
    with(slots, mod, options) {
      return createZonedDateTime(((getCalendarOps, getTimeZoneOps, zonedDateTimeSlots, initialFields, modFields, options) => {
        const optionsCopy = copyOptions(options), {calendar: calendar, timeZone: timeZone} = zonedDateTimeSlots;
        return createZonedDateTimeSlots(((calendarOps, timeZoneOps, zonedDateTime, mod, options) => {
          const fields = mergeCalendarFields(calendarOps, zonedDateTime, mod, dateFieldNamesAlpha, timeAndOffsetFieldNames, offsetFieldNames), [overflow, offsetDisambig, epochDisambig] = refineZonedFieldOptions(options, 2);
          return getMatchingInstantFor(timeZoneOps, {
            ...calendarOps.dateFromFields(fields, overrideOverflowOptions(options, overflow)),
            ...refineTimeBag(fields, overflow)
          }, parseOffsetNano(fields.offset), offsetDisambig, epochDisambig);
        })(getCalendarOps(calendar), getTimeZoneOps(timeZone), initialFields, modFields, optionsCopy), timeZone, calendar);
      })(createDateModOps, createTimeZoneOps, slots, this, rejectInvalidBag(mod), options));
    },
    withPlainTime: (slots, plainTimeArg) => createZonedDateTime(((getTimeZoneOps, zonedDateTimeSlots, plainTimeSlots = isoTimeFieldDefaults) => {
      const timeZoneSlot = zonedDateTimeSlots.timeZone, timeZoneOps = getTimeZoneOps(timeZoneSlot), isoFields = {
        ...zonedEpochSlotsToIso(zonedDateTimeSlots, timeZoneOps),
        ...plainTimeSlots
      };
      return createZonedDateTimeSlots(getMatchingInstantFor(timeZoneOps, isoFields, isoFields.offsetNanoseconds, 2), timeZoneSlot, zonedDateTimeSlots.calendar);
    })(createTimeZoneOps, slots, optionalToPlainTimeFields(plainTimeArg))),
    withPlainDate: (slots, plainDateArg) => createZonedDateTime(((getTimeZoneOps, zonedDateTimeSlots, plainDateSlots) => {
      const timeZoneSlot = zonedDateTimeSlots.timeZone, timeZoneOps = getTimeZoneOps(timeZoneSlot), isoFields = {
        ...zonedEpochSlotsToIso(zonedDateTimeSlots, timeZoneOps),
        ...plainDateSlots
      }, calendar = getPreferredCalendarSlot(zonedDateTimeSlots.calendar, plainDateSlots.calendar);
      return createZonedDateTimeSlots(getMatchingInstantFor(timeZoneOps, isoFields, isoFields.offsetNanoseconds, 2), timeZoneSlot, calendar);
    })(createTimeZoneOps, slots, toPlainDateSlots(plainDateArg))),
    withTimeZone: (slots, timeZoneArg) => createZonedDateTime(((slots, timeZoneSlot) => ({
      ...slots,
      timeZone: timeZoneSlot
    }))(slots, refineTimeZoneSlot(timeZoneArg))),
    withCalendar: (slots, calendarArg) => createZonedDateTime(slotsWithCalendar(slots, refineCalendarSlot(calendarArg))),
    add: (slots, durationArg, options) => createZonedDateTime(moveZonedDateTime(createMoveOps, createTimeZoneOps, 0, slots, toDurationSlots(durationArg), options)),
    subtract: (slots, durationArg, options) => createZonedDateTime(moveZonedDateTime(createMoveOps, createTimeZoneOps, 1, slots, toDurationSlots(durationArg), options)),
    until: (slots, otherArg, options) => createDuration(createDurationSlots(diffZonedDateTimes(createDiffOps, createTimeZoneOps, 0, slots, toZonedDateTimeSlots(otherArg), options))),
    since: (slots, otherArg, options) => createDuration(createDurationSlots(diffZonedDateTimes(createDiffOps, createTimeZoneOps, 1, slots, toZonedDateTimeSlots(otherArg), options))),
    round: (slots, options) => createZonedDateTime(((getTimeZoneOps, zonedDateTimeSlots, options) => {
      let {epochNanoseconds: epochNanoseconds, timeZone: timeZone, calendar: calendar} = zonedDateTimeSlots;
      const [smallestUnit, roundingInc, roundingMode] = refineRoundOptions(options);
      if (0 === smallestUnit && 1 === roundingInc) {
        return zonedDateTimeSlots;
      }
      const timeZoneOps = getTimeZoneOps(timeZone), offsetNano = timeZoneOps.getOffsetNanosecondsFor(epochNanoseconds);
      let isoDateTimeFields = {
        ...epochNanoToIso(epochNanoseconds, offsetNano),
        calendar: calendar
      };
      return isoDateTimeFields = {
        calendar: calendar,
        ...roundDateTime(isoDateTimeFields, smallestUnit, roundingInc, roundingMode, timeZoneOps)
      }, epochNanoseconds = getMatchingInstantFor(timeZoneOps, isoDateTimeFields, offsetNano, 2, 0, 1), 
      createZonedDateTimeSlots(epochNanoseconds, timeZone, calendar);
    })(createTimeZoneOps, slots, options)),
    startOfDay: slots => createZonedDateTime(((getTimeZoneOps, zonedDateTimeSlots) => {
      let {epochNanoseconds: epochNanoseconds, timeZone: timeZone, calendar: calendar} = zonedDateTimeSlots;
      const timeZoneOps = getTimeZoneOps(timeZone);
      return epochNanoseconds = getMatchingInstantFor(timeZoneOps, {
        ...zonedEpochSlotsToIso(zonedDateTimeSlots, timeZoneOps),
        ...isoTimeFieldDefaults
      }, void 0, 0, 0, 1), createZonedDateTimeSlots(epochNanoseconds, timeZone, calendar);
    })(createTimeZoneOps, slots)),
    equals(slots, otherArg) {
      return !compareZonedDateTimes(zonedDateTimeSlots0 = slots, zonedDateTimeSlots1 = toZonedDateTimeSlots(otherArg)) && !!isTimeZoneSlotsEqual(zonedDateTimeSlots0.timeZone, zonedDateTimeSlots1.timeZone) && isIdLikeEqual(zonedDateTimeSlots0.calendar, zonedDateTimeSlots1.calendar);
      var zonedDateTimeSlots0, zonedDateTimeSlots1;
    },
    toString: (slots, options) => formatZonedDateTimeIso(createTimeZoneOffsetOps, slots, options),
    toJSON: slots => formatZonedDateTimeIso(createTimeZoneOffsetOps, slots),
    toLocaleString(slots, locales, options = {}) {
      const [format, epochMilli] = prepZonedDateTimeFormat(locales, options, slots);
      return format.format(epochMilli);
    },
    toInstant: slots => createInstant(createInstantSlots(slots.epochNanoseconds)),
    toPlainDate: slots => createPlainDate(zonedDateTimeToPlainDate(createTimeZoneOffsetOps, slots)),
    toPlainTime: slots => createPlainTime(zonedDateTimeToPlainTime(createTimeZoneOffsetOps, slots)),
    toPlainDateTime: slots => createPlainDateTime(zonedDateTimeToPlainDateTime(createTimeZoneOffsetOps, slots)),
    toPlainYearMonth(slots) {
      return createPlainYearMonth(convertToPlainYearMonth(createYearMonthRefineOps(slots.calendar), this));
    },
    toPlainMonthDay(slots) {
      return createPlainMonthDay(convertToPlainMonthDay(createMonthDayRefineOps(slots.calendar), this));
    },
    getISOFields: slots => ((getTimeZoneOps, zonedDateTimeSlots) => {
      const isoFields = zonedEpochSlotsToIso(zonedDateTimeSlots, getTimeZoneOps);
      return {
        calendar: zonedDateTimeSlots.calendar,
        ...pluckProps(isoDateTimeFieldNamesAlpha, isoFields),
        offset: formatOffsetNano(isoFields.offsetNanoseconds),
        timeZone: zonedDateTimeSlots.timeZone
      };
    })(createTimeZoneOffsetOps, slots),
    getCalendar: createCalendarFromSlots,
    getTimeZone: ({timeZone: timeZone}) => "string" == typeof timeZone ? new TimeZone(timeZone) : timeZone,
    valueOf: neverValueOf
  }, {
    from: (arg, options) => createZonedDateTime(toZonedDateTimeSlots(arg, options)),
    compare: (arg0, arg1) => compareZonedDateTimes(toZonedDateTimeSlots(arg0), toZonedDateTimeSlots(arg1))
  }), [Instant, createInstant, getInstantSlots] = createSlotClass(InstantBranding, (epochNano => createInstantSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(epochNano))))), epochGetters, {
    add: (slots, durationArg) => createInstant(moveInstant(0, slots, toDurationSlots(durationArg))),
    subtract: (slots, durationArg) => createInstant(moveInstant(1, slots, toDurationSlots(durationArg))),
    until: (slots, otherArg, options) => createDuration(diffInstants(0, slots, toInstantSlots(otherArg), options)),
    since: (slots, otherArg, options) => createDuration(diffInstants(1, slots, toInstantSlots(otherArg), options)),
    round: (slots, options) => createInstant(((instantSlots, options) => {
      const [smallestUnit, roundingInc, roundingMode] = refineRoundOptions(options, 5, 1);
      return createInstantSlots(roundDayTimeNano(instantSlots.epochNanoseconds, smallestUnit, roundingInc, roundingMode, 1));
    })(slots, options)),
    equals(slots, otherArg) {
      return !compareInstants(slots, toInstantSlots(otherArg));
    },
    toString: (slots, options) => formatInstantIso(refineTimeZoneSlot, createTimeZoneOffsetOps, slots, options),
    toJSON: slots => formatInstantIso(refineTimeZoneSlot, createTimeZoneOffsetOps, slots),
    toLocaleString(slots, locales, options) {
      const [format, epochMilli] = prepInstantFormat(locales, options, slots);
      return format.format(epochMilli);
    },
    toZonedDateTimeISO: (slots, timeZoneArg) => createZonedDateTime(instantToZonedDateTime(slots, refineTimeZoneSlot(timeZoneArg))),
    toZonedDateTime(slots, options) {
      const refinedObj = requireObjectLike(options);
      return createZonedDateTime(instantToZonedDateTime(slots, refineTimeZoneSlot(refinedObj.timeZone), refineCalendarSlot(refinedObj.calendar)));
    },
    valueOf: neverValueOf
  }, {
    from: arg => createInstant(toInstantSlots(arg)),
    fromEpochSeconds: epochSec => createInstant((epochSec => createInstantSlots(checkEpochNanoInBounds(numberToDayTimeNano(epochSec, nanoInSec))))(epochSec)),
    fromEpochMilliseconds: epochMilli => createInstant((epochMilli => createInstantSlots(checkEpochNanoInBounds(numberToDayTimeNano(epochMilli, nanoInMilli))))(epochMilli)),
    fromEpochMicroseconds: epochMicro => createInstant((epochMicro => createInstantSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(epochMicro), nanoInMicro))))(epochMicro)),
    fromEpochNanoseconds: epochNano => createInstant((epochNano => createInstantSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(epochNano)))))(epochNano)),
    compare: (a, b) => compareInstants(toInstantSlots(a), toInstantSlots(b))
  }), [TimeZone, createTimeZone] = createSlotClass("TimeZone", (id => {
    const slotId = resolveTimeZoneId(id);
    return {
      branding: "TimeZone",
      id: slotId,
      native: queryNativeTimeZone(slotId)
    };
  }), {
    id: slots => slots.id
  }, {
    toString: slots => slots.id,
    toJSON: slots => slots.id,
    getPossibleInstantsFor: ({native: native}, plainDateTimeArg) => native.getPossibleInstantsFor(toPlainDateTimeSlots(plainDateTimeArg)).map((epochNano => createInstant(createInstantSlots(epochNano)))),
    getOffsetNanosecondsFor: ({native: native}, instantArg) => native.getOffsetNanosecondsFor(toInstantSlots(instantArg).epochNanoseconds),
    getOffsetStringFor(_slots, instantArg) {
      const epochNano = toInstantSlots(instantArg).epochNanoseconds;
      return formatOffsetNano(createAdapterOps(this, simpleTimeZoneAdapters).getOffsetNanosecondsFor(epochNano));
    },
    getPlainDateTimeFor(_slots, instantArg, calendarArg = isoCalendarId) {
      const epochNano = toInstantSlots(instantArg).epochNanoseconds, offsetNano = createAdapterOps(this, simpleTimeZoneAdapters).getOffsetNanosecondsFor(epochNano);
      return createPlainDateTime(createPlainDateTimeSlots(epochNanoToIso(epochNano, offsetNano), refineCalendarSlot(calendarArg)));
    },
    getInstantFor(_slots, plainDateTimeArg, options) {
      const isoFields = toPlainDateTimeSlots(plainDateTimeArg), epochDisambig = refineEpochDisambigOptions(options), calendarOps = createAdapterOps(this);
      return createInstant(createInstantSlots(getSingleInstantFor(calendarOps, isoFields, epochDisambig)));
    },
    getNextTransition: ({native: native}, instantArg) => getImplTransition(1, native, instantArg),
    getPreviousTransition: ({native: native}, instantArg) => getImplTransition(-1, native, instantArg),
    equals(_slots, otherArg) {
      return !!isTimeZoneSlotsEqual(this, refineTimeZoneSlot(otherArg));
    }
  }, {
    from(arg) {
      const timeZoneSlot = refineTimeZoneSlot(arg);
      return "string" == typeof timeZoneSlot ? new TimeZone(timeZoneSlot) : timeZoneSlot;
    }
  }), validateTimeZoneProtocol = createProtocolValidator(Object.keys(timeZoneAdapters)), [PlainTime, createPlainTime] = createSlotClass(PlainTimeBranding, ((isoHour = 0, isoMinute = 0, isoSecond = 0, isoMillisecond = 0, isoMicrosecond = 0, isoNanosecond = 0) => createPlainTimeSlots(constrainIsoTimeFields(mapProps(toInteger, zipProps(isoTimeFieldNamesAsc, [ isoHour, isoMinute, isoSecond, isoMillisecond, isoMicrosecond, isoNanosecond ])), 1))), timeGetters, {
    with(_slots, mod, options) {
      return createPlainTime(((initialFields, mod, options) => createPlainTimeSlots(((plainTime, bag, options) => {
        const overflow = refineOverflowOptions(options);
        return refineTimeBag({
          ...pluckProps(timeFieldNamesAlpha, plainTime),
          ...refineFields(bag, timeFieldNamesAlpha)
        }, overflow);
      })(initialFields, mod, options)))(this, rejectInvalidBag(mod), options));
    },
    add: (slots, durationArg) => createPlainTime(movePlainTime(0, slots, toDurationSlots(durationArg))),
    subtract: (slots, durationArg) => createPlainTime(movePlainTime(1, slots, toDurationSlots(durationArg))),
    until: (slots, otherArg, options) => createDuration(diffPlainTimes(0, slots, toPlainTimeSlots(otherArg), options)),
    since: (slots, otherArg, options) => createDuration(diffPlainTimes(1, slots, toPlainTimeSlots(otherArg), options)),
    round: (slots, options) => createPlainTime(((slots, options) => createPlainTimeSlots(((isoFields, smallestUnit, roundingInc, roundingMode) => roundTimeToNano(isoFields, computeNanoInc(smallestUnit, roundingInc), roundingMode)[0])(slots, ...refineRoundOptions(options, 5))))(slots, options)),
    equals(slots, other) {
      return !compareIsoTimeFields(slots, toPlainTimeSlots(other));
    },
    toString: formatPlainTimeIso,
    toJSON: slots => formatPlainTimeIso(slots),
    toLocaleString(slots, locales, options) {
      const [format, epochMilli] = prepPlainTimeFormat(locales, options, slots);
      return format.format(epochMilli);
    },
    toZonedDateTime: (slots, options) => createZonedDateTime(((refineTimeZoneArg, refinePlainDateArg, getTimeZoneOps, slots, options) => {
      const refinedOptions = requireObjectLike(options), plainDateSlots = refinePlainDateArg(refinedOptions.plainDate), timeZoneSlot = refineTimeZoneArg(refinedOptions.timeZone);
      return createZonedDateTimeSlots(getSingleInstantFor(getTimeZoneOps(timeZoneSlot), {
        ...plainDateSlots,
        ...slots
      }), timeZoneSlot, plainDateSlots.calendar);
    })(refineTimeZoneSlot, toPlainDateSlots, createTimeZoneOps, slots, options)),
    toPlainDateTime(slots, plainDateArg) {
      return createPlainDateTime((plainTimeSlots0 = slots, plainDateSlots1 = toPlainDateSlots(plainDateArg), 
      createPlainDateTimeSlots(checkIsoDateTimeInBounds({
        ...plainTimeSlots0,
        ...plainDateSlots1
      }))));
      var plainTimeSlots0, plainDateSlots1;
    },
    getISOFields: removeBranding,
    valueOf: neverValueOf
  }, {
    from: (arg, options) => createPlainTime(toPlainTimeSlots(arg, options)),
    compare: (arg0, arg1) => compareIsoTimeFields(toPlainTimeSlots(arg0), toPlainTimeSlots(arg1))
  }), [PlainDateTime, createPlainDateTime] = createSlotClass(PlainDateTimeBranding, bindArgs(((refineCalendarArg, isoYear, isoMonth, isoDay, isoHour = 0, isoMinute = 0, isoSecond = 0, isoMillisecond = 0, isoMicrosecond = 0, isoNanosecond = 0, calendarArg = isoCalendarId) => createPlainDateTimeSlots(checkIsoDateTimeInBounds(checkIsoDateTimeFields(mapProps(toInteger, zipProps(isoDateTimeFieldNamesAsc, [ isoYear, isoMonth, isoDay, isoHour, isoMinute, isoSecond, isoMillisecond, isoMicrosecond, isoNanosecond ])))), refineCalendarArg(calendarArg))), refineCalendarSlot), {
    ...calendarIdGetters,
    ...dateGetters,
    ...timeGetters
  }, {
    with(slots, mod, options) {
      return createPlainDateTime(((getCalendarOps, plainDateTimeSlots, initialFields, modFields, options) => {
        const optionsCopy = copyOptions(options);
        return createPlainDateTimeSlots(((calendarOps, plainDateTime, mod, options) => {
          const fields = mergeCalendarFields(calendarOps, plainDateTime, mod, dateFieldNamesAlpha, timeFieldNamesAsc), overflow = refineOverflowOptions(options);
          return checkIsoDateTimeInBounds({
            ...calendarOps.dateFromFields(fields, overrideOverflowOptions(options, overflow)),
            ...refineTimeBag(fields, overflow)
          });
        })(getCalendarOps(plainDateTimeSlots.calendar), initialFields, modFields, optionsCopy));
      })(createDateModOps, slots, this, rejectInvalidBag(mod), options));
    },
    withPlainTime: (slots, plainTimeArg) => createPlainDateTime(((plainDateTimeSlots, plainTimeSlots = isoTimeFieldDefaults) => createPlainDateTimeSlots({
      ...plainDateTimeSlots,
      ...plainTimeSlots
    }))(slots, optionalToPlainTimeFields(plainTimeArg))),
    withPlainDate(slots, plainDateArg) {
      return createPlainDateTime((plainDateTimeSlots = slots, plainDateSlots = toPlainDateSlots(plainDateArg), 
      createPlainDateTimeSlots({
        ...plainDateTimeSlots,
        ...plainDateSlots
      }, getPreferredCalendarSlot(plainDateTimeSlots.calendar, plainDateSlots.calendar))));
      var plainDateTimeSlots, plainDateSlots;
    },
    withCalendar: (slots, calendarArg) => createPlainDateTime(slotsWithCalendar(slots, refineCalendarSlot(calendarArg))),
    add: (slots, durationArg, options) => createPlainDateTime(movePlainDateTime(createMoveOps, 0, slots, toDurationSlots(durationArg), options)),
    subtract: (slots, durationArg, options) => createPlainDateTime(movePlainDateTime(createMoveOps, 1, slots, toDurationSlots(durationArg), options)),
    until: (slots, otherArg, options) => createDuration(diffPlainDateTimes(createDiffOps, 0, slots, toPlainDateTimeSlots(otherArg), options)),
    since: (slots, otherArg, options) => createDuration(diffPlainDateTimes(createDiffOps, 1, slots, toPlainDateTimeSlots(otherArg), options)),
    round: (slots, options) => createPlainDateTime(((plainDateTimeSlots, options) => createPlainDateTimeSlots(roundDateTime(plainDateTimeSlots, ...refineRoundOptions(options)), plainDateTimeSlots.calendar))(slots, options)),
    equals(slots, otherArg) {
      return !compareIsoDateTimeFields(plainDateTimeSlots0 = slots, plainDateTimeSlots1 = toPlainDateTimeSlots(otherArg)) && isIdLikeEqual(plainDateTimeSlots0.calendar, plainDateTimeSlots1.calendar);
      var plainDateTimeSlots0, plainDateTimeSlots1;
    },
    toString: (slots, options) => formatPlainDateTimeIso(slots, options),
    toJSON: slots => formatPlainDateTimeIso(slots),
    toLocaleString(slots, locales, options) {
      const [format, epochMilli] = prepPlainDateTimeFormat(locales, options, slots);
      return format.format(epochMilli);
    },
    toZonedDateTime: (slots, timeZoneArg, options) => createZonedDateTime(((getTimeZoneOps, plainDateTimeSlots, timeZoneSlot, options) => createZonedDateTimeSlots(((getTimeZoneOps, timeZoneSlot, isoFields, options) => {
      const epochDisambig = refineEpochDisambigOptions(options);
      return checkEpochNanoInBounds(getSingleInstantFor(getTimeZoneOps(timeZoneSlot), isoFields, epochDisambig));
    })(getTimeZoneOps, timeZoneSlot, plainDateTimeSlots, options), timeZoneSlot, plainDateTimeSlots.calendar))(createTimeZoneOps, slots, refineTimeZoneSlot(timeZoneArg), options)),
    toPlainDate: slots => createPlainDate(createPlainDateSlots(slots)),
    toPlainYearMonth(slots) {
      return createPlainYearMonth(((getCalendarOps, plainDateTimeSlots, plainDateFields) => {
        const calendarOps = getCalendarOps(plainDateTimeSlots.calendar);
        return createPlainYearMonthSlots({
          ...plainDateTimeSlots,
          ...convertToPlainYearMonth(calendarOps, plainDateFields)
        });
      })(createYearMonthRefineOps, slots, this));
    },
    toPlainMonthDay(slots) {
      return createPlainMonthDay(convertToPlainMonthDay(createMonthDayRefineOps(slots.calendar), this));
    },
    toPlainTime: slots => createPlainTime(createPlainTimeSlots(slots)),
    getISOFields: removeBranding,
    getCalendar: createCalendarFromSlots,
    valueOf: neverValueOf
  }, {
    from: (arg, options) => createPlainDateTime(toPlainDateTimeSlots(arg, options)),
    compare: (arg0, arg1) => compareIsoDateTimeFields(toPlainDateTimeSlots(arg0), toPlainDateTimeSlots(arg1))
  }), [PlainDate, createPlainDate, getPlainDateSlots] = createSlotClass(PlainDateBranding, bindArgs(((refineCalendarArg, isoYear, isoMonth, isoDay, calendarArg = isoCalendarId) => createPlainDateSlots(checkIsoDateInBounds(checkIsoDateFields(mapProps(toInteger, {
    isoYear: isoYear,
    isoMonth: isoMonth,
    isoDay: isoDay
  }))), refineCalendarArg(calendarArg))), refineCalendarSlot), {
    ...calendarIdGetters,
    ...dateGetters
  }, {
    with(slots, mod, options) {
      return createPlainDate(((getCalendarOps, plainDateSlots, initialFields, modFields, options) => {
        const optionsCopy = copyOptions(options);
        return ((calendarOps, plainDate, mod, options) => {
          const fields = mergeCalendarFields(calendarOps, plainDate, mod, dateFieldNamesAlpha);
          return calendarOps.dateFromFields(fields, options);
        })(getCalendarOps(plainDateSlots.calendar), initialFields, modFields, optionsCopy);
      })(createDateModOps, slots, this, rejectInvalidBag(mod), options));
    },
    withCalendar: (slots, calendarArg) => createPlainDate(slotsWithCalendar(slots, refineCalendarSlot(calendarArg))),
    add: (slots, durationArg, options) => createPlainDate(movePlainDate(createMoveOps, 0, slots, toDurationSlots(durationArg), options)),
    subtract: (slots, durationArg, options) => createPlainDate(movePlainDate(createMoveOps, 1, slots, toDurationSlots(durationArg), options)),
    until: (slots, otherArg, options) => createDuration(diffPlainDates(createDiffOps, 0, slots, toPlainDateSlots(otherArg), options)),
    since: (slots, otherArg, options) => createDuration(diffPlainDates(createDiffOps, 1, slots, toPlainDateSlots(otherArg), options)),
    equals(slots, otherArg) {
      return !compareIsoDateFields(plainDateSlots0 = slots, plainDateSlots1 = toPlainDateSlots(otherArg)) && isIdLikeEqual(plainDateSlots0.calendar, plainDateSlots1.calendar);
      var plainDateSlots0, plainDateSlots1;
    },
    toString: formatPlainDateIso,
    toJSON: slots => formatPlainDateIso(slots),
    toLocaleString(slots, locales, options) {
      const [format, epochMilli] = prepPlainDateFormat(locales, options, slots);
      return format.format(epochMilli);
    },
    toZonedDateTime(slots, options) {
      const optionsObj = !isObjectLike(options) || options instanceof TimeZone ? {
        timeZone: options
      } : options;
      return createZonedDateTime(((refineTimeZoneArg, refinePlainTimeArg, getTimeZoneOps, plainDateSlots, options) => {
        const timeZoneSlot = refineTimeZoneArg(options.timeZone), plainTimeArg = options.plainTime, isoTimeFields = void 0 !== plainTimeArg ? refinePlainTimeArg(plainTimeArg) : isoTimeFieldDefaults;
        return createZonedDateTimeSlots(getSingleInstantFor(getTimeZoneOps(timeZoneSlot), {
          ...plainDateSlots,
          ...isoTimeFields
        }), timeZoneSlot, plainDateSlots.calendar);
      })(refineTimeZoneSlot, toPlainTimeSlots, createTimeZoneOps, slots, optionsObj));
    },
    toPlainDateTime: (slots, plainTimeArg) => createPlainDateTime(((plainDateSlots, plainTimeFields = isoTimeFieldDefaults) => createPlainDateTimeSlots(checkIsoDateTimeInBounds({
      ...plainDateSlots,
      ...plainTimeFields
    })))(slots, optionalToPlainTimeFields(plainTimeArg))),
    toPlainYearMonth(slots) {
      return createPlainYearMonth(convertToPlainYearMonth(createYearMonthRefineOps(slots.calendar), this));
    },
    toPlainMonthDay(slots) {
      return createPlainMonthDay(convertToPlainMonthDay(createMonthDayRefineOps(slots.calendar), this));
    },
    getISOFields: removeBranding,
    getCalendar: createCalendarFromSlots,
    valueOf: neverValueOf
  }, {
    from: (arg, options) => createPlainDate(toPlainDateSlots(arg, options)),
    compare: (arg0, arg1) => compareIsoDateFields(toPlainDateSlots(arg0), toPlainDateSlots(arg1))
  }), refineAdapters = {
    fields(calendarProtocol, fieldsMethod, fieldNames) {
      return [ ...fieldsMethod.call(calendarProtocol, fieldNames) ];
    }
  }, dateRefineAdapters = {
    dateFromFields(calendarProtocol, dateFromFields, fields, options) {
      return getPlainDateSlots(dateFromFields.call(calendarProtocol, Object.assign(Object.create(null), fields), options));
    },
    ...refineAdapters
  }, yearMonthRefineAdapters = {
    yearMonthFromFields(calendarProtocol, yearMonthFromFields, fields, options) {
      return getPlainYearMonthSlots(yearMonthFromFields.call(calendarProtocol, Object.assign(Object.create(null), fields), options));
    },
    ...refineAdapters
  }, monthDayRefineAdapters = {
    monthDayFromFields(calendarProtocol, monthDayFromFields, fields, options) {
      return getPlainMonthDaySlots(monthDayFromFields.call(calendarProtocol, Object.assign(Object.create(null), fields), options));
    },
    ...refineAdapters
  }, modAdapters = {
    mergeFields(calendarProtocol, mergeFields, fields, additionalFields) {
      return requireObjectLike(mergeFields.call(calendarProtocol, Object.assign(Object.create(null), fields), Object.assign(Object.create(null), additionalFields)));
    }
  }, dateModAdapters = {
    ...dateRefineAdapters,
    ...modAdapters
  }, yearMonthModAdapters = {
    ...yearMonthRefineAdapters,
    ...modAdapters
  }, monthDayModAdapters = {
    ...monthDayRefineAdapters,
    ...modAdapters
  }, moveAdapters = {
    dateAdd(calendarProtocol, dateAdd, isoFields, durationFields, options) {
      return getPlainDateSlots(dateAdd.call(calendarProtocol, createPlainDate(createPlainDateSlots(isoFields, calendarProtocol)), createDuration(createDurationSlots(durationFields)), options));
    }
  }, diffAdapters = {
    ...moveAdapters,
    dateUntil(calendarProtocol, dateUntil, isoFields0, isoFields1, largestUnit, origOptions) {
      return getDurationSlots(dateUntil.call(calendarProtocol, createPlainDate(createPlainDateSlots(isoFields0, calendarProtocol)), createPlainDate(createPlainDateSlots(isoFields1, calendarProtocol)), Object.assign(Object.create(null), origOptions, {
        largestUnit: unitNamesAsc[largestUnit]
      })));
    }
  }, yearMonthMoveAdapters = {
    ...moveAdapters,
    day: dayAdapter
  }, yearMonthDiffAdapters = {
    ...diffAdapters,
    day: dayAdapter
  }, createYearMonthRefineOps = createCompoundOpsCreator(yearMonthRefineAdapters), createDateRefineOps = createCompoundOpsCreator(dateRefineAdapters), createMonthDayRefineOps = createCompoundOpsCreator(monthDayRefineAdapters), createYearMonthModOps = createCompoundOpsCreator(yearMonthModAdapters), createDateModOps = createCompoundOpsCreator(dateModAdapters), createMonthDayModOps = createCompoundOpsCreator(monthDayModAdapters), createMoveOps = createCompoundOpsCreator(moveAdapters), createDiffOps = createCompoundOpsCreator(diffAdapters), createYearMonthMoveOps = createCompoundOpsCreator(yearMonthMoveAdapters), createYearMonthDiffOps = createCompoundOpsCreator(yearMonthDiffAdapters), [Duration, createDuration, getDurationSlots] = createSlotClass(DurationBranding, ((years = 0, months = 0, weeks = 0, days = 0, hours = 0, minutes = 0, seconds = 0, milliseconds = 0, microseconds = 0, nanoseconds = 0) => createDurationSlots(checkDurationFields(mapProps(toStrictInteger, zipProps(durationFieldNamesAsc, [ years, months, weeks, days, hours, minutes, seconds, milliseconds, microseconds, nanoseconds ]))))), {
    ...durationGetters,
    blank: slots => !queryDurationSign(slots),
    sign: slots => queryDurationSign(slots)
  }, {
    with: (slots, mod) => createDuration(((slots, fields) => {
      return createDurationSlots((durationFields = slots, bag = fields, checkDurationFields({
        ...durationFields,
        ...refineFields(bag, durationFieldNamesAlpha)
      })));
      var durationFields, bag;
    })(slots, mod)),
    add: (slots, otherArg, options) => createDuration(addDurations(refinePublicRelativeTo, createDiffOps, createTimeZoneOps, 0, slots, toDurationSlots(otherArg), options)),
    subtract: (slots, otherArg, options) => createDuration(addDurations(refinePublicRelativeTo, createDiffOps, createTimeZoneOps, 1, slots, toDurationSlots(otherArg), options)),
    negated: slots => createDuration(negateDuration(slots)),
    abs: slots => createDuration((slots => {
      return createDurationSlots(-1 === queryDurationSign(fields = slots) ? negateDurationFields(fields) : fields);
      var fields;
    })(slots)),
    round: (slots, options) => createDuration(((refineRelativeTo, getCalendarOps, getTimeZoneOps, slots, options) => {
      const durationLargestUnit = getLargestDurationUnit(slots), [largestUnit, smallestUnit, roundingInc, roundingMode, markerSlots] = ((options, defaultLargestUnit, refineRelativeTo) => {
        options = normalizeUnitNameOptions(options, smallestUnitStr);
        let largestUnit = refineLargestUnit(options);
        const relativeToInternals = refineRelativeTo(options.relativeTo);
        let roundingInc = parseRoundingIncInteger(options);
        const roundingMode = refineRoundingMode(options, 7);
        let smallestUnit = refineSmallestUnit(options);
        if (void 0 === largestUnit && void 0 === smallestUnit) {
          throw new RangeError("Required smallestUnit or largestUnit");
        }
        return null == smallestUnit && (smallestUnit = 0), null == largestUnit && (largestUnit = Math.max(smallestUnit, defaultLargestUnit)), 
        checkLargestSmallestUnit(largestUnit, smallestUnit), roundingInc = refineRoundingInc(roundingInc, smallestUnit, 1), 
        [ largestUnit, smallestUnit, roundingInc, roundingMode, relativeToInternals ];
      })(options, durationLargestUnit, refineRelativeTo), maxLargestUnit = Math.max(durationLargestUnit, largestUnit);
      if (maxLargestUnit < 6 || 6 === maxLargestUnit && (!markerSlots || !markerSlots.epochNanoseconds)) {
        return createDurationSlots(((durationFields, largestUnit, smallestUnit, roundingInc, roundingMode) => ({
          ...durationFieldDefaults,
          ...balanceDayTimeDuration(durationFields, largestUnit, smallestUnit, roundingInc, roundingMode)
        }))(slots, largestUnit, smallestUnit, roundingInc, roundingMode));
      }
      if (!markerSlots) {
        throw new RangeError("Missing relativeTo");
      }
      const markerSystem = createMarkerSystem(getCalendarOps, getTimeZoneOps, markerSlots);
      let transplantedWeeks = 0;
      slots.weeks && 7 === smallestUnit && (transplantedWeeks = slots.weeks, slots = {
        ...slots,
        weeks: 0
      });
      let [balancedDuration, endEpochNano] = spanDuration(slots, void 0, largestUnit, ...markerSystem);
      const origSign = queryDurationSign(slots), balancedSign = queryDurationSign(balancedDuration);
      if (origSign && balancedSign && origSign !== balancedSign) {
        throw new RangeError(invalidProtocolResults);
      }
      return !balancedSign || 0 === smallestUnit && 1 === roundingInc || (balancedDuration = roundRelativeDuration(balancedDuration, endEpochNano, largestUnit, smallestUnit, roundingInc, roundingMode, ...markerSystem)), 
      balancedDuration.weeks += transplantedWeeks, createDurationSlots(balancedDuration);
    })(refinePublicRelativeTo, createDiffOps, createTimeZoneOps, slots, options)),
    total: (slots, options) => ((refineRelativeTo, getCalendarOps, getTimeZoneOps, slots, options) => {
      const durationLargestUnit = getLargestDurationUnit(slots), [totalUnit, markerSlots] = ((options, refineRelativeTo) => {
        const relativeToInternals = refineRelativeTo((options = normalizeUnitNameOptions(options, "unit")).relativeTo);
        let totalUnit = refineTotalUnit(options);
        return totalUnit = requirePropDefined("unit", totalUnit), [ totalUnit, relativeToInternals ];
      })(options, refineRelativeTo), maxLargestUnit = Math.max(totalUnit, durationLargestUnit);
      if (maxLargestUnit < 6 || 6 === maxLargestUnit && (!markerSlots || !markerSlots.epochNanoseconds)) {
        return ((durationFields, totalUnit) => totalDayTimeNano(durationFieldsToDayTimeNano(durationFields, 6), totalUnit))(slots, totalUnit);
      }
      if (!markerSlots) {
        throw new RangeError("Missing relativeTo");
      }
      const markerSystem = createMarkerSystem(getCalendarOps, getTimeZoneOps, markerSlots);
      return ((durationFields, endEpochNano, totalUnit, marker, markerToEpochNano, moveMarker) => {
        const sign = queryDurationSign(durationFields), [epochNano0, epochNano1] = clampRelativeDuration(clearDurationFields(durationFields, totalUnit - 1), totalUnit, sign, marker, markerToEpochNano, moveMarker), frac = computeEpochNanoFrac(epochNano0, epochNano1, endEpochNano);
        return durationFields[durationFieldNamesAsc[totalUnit]] + frac * sign;
      })(...spanDuration(slots, void 0, totalUnit, ...markerSystem), totalUnit, ...markerSystem);
    })(refinePublicRelativeTo, createDiffOps, createTimeZoneOps, slots, options),
    toString: formatDurationIso,
    toLocaleString(slots, locales, options) {
      return Intl.DurationFormat ? new Intl.DurationFormat(locales, options).format(this) : formatDurationIso(slots);
    },
    toJSON: slots => formatDurationIso(slots),
    valueOf: neverValueOf
  }, {
    from: arg => createDuration(toDurationSlots(arg)),
    compare: (durationArg0, durationArg1, options) => ((refineRelativeTo, getCalendarOps, getTimeZoneOps, durationSlots0, durationSlots1, options) => {
      const markerSlots = refineRelativeTo(normalizeOptions(options).relativeTo), largestUnit = Math.max(getLargestDurationUnit(durationSlots0), getLargestDurationUnit(durationSlots1));
      if (allPropsEqual(durationFieldNamesAsc, durationSlots0, durationSlots1)) {
        return 0;
      }
      if (largestUnit < 6 || 6 === largestUnit && (!markerSlots || !markerSlots.epochNanoseconds)) {
        return compareDayTimeNanos(givenFieldsToDayTimeNano(durationSlots0, 6, durationFieldNamesAsc), givenFieldsToDayTimeNano(durationSlots1, 6, durationFieldNamesAsc));
      }
      if (!markerSlots) {
        throw new RangeError("Missing relativeTo");
      }
      const [marker, markerToEpochNano, moveMarker] = createMarkerSystem(getCalendarOps, getTimeZoneOps, markerSlots);
      return compareDayTimeNanos(markerToEpochNano(moveMarker(marker, durationSlots0)), markerToEpochNano(moveMarker(marker, durationSlots1)));
    })(refinePublicRelativeTo, createDiffOps, createTimeZoneOps, toDurationSlots(durationArg0), toDurationSlots(durationArg1), options)
  }), calendarMethods = {
    toString: slots => slots.id,
    toJSON: slots => slots.id,
    ...calendarFieldMethods,
    dateAdd: ({id: id, native: native}, plainDateArg, durationArg, options) => createPlainDate(createPlainDateSlots(native.dateAdd(toPlainDateSlots(plainDateArg), toDurationSlots(durationArg), options), id)),
    dateUntil: ({native: native}, plainDateArg0, plainDateArg1, options) => createDuration(createDurationSlots(native.dateUntil(toPlainDateSlots(plainDateArg0), toPlainDateSlots(plainDateArg1), (options => (options = normalizeOptions(options), 
    refineLargestUnit(options, 9, 6, 1)))(options)))),
    dateFromFields: ({id: id, native: native}, fields, options) => createPlainDate(refinePlainDateBag(native, fields, options, id === isoCalendarId ? [ "year", "day" ] : [])),
    yearMonthFromFields: ({id: id, native: native}, fields, options) => createPlainYearMonth(refinePlainYearMonthBag(native, fields, options, id === isoCalendarId ? yearFieldNames : [])),
    monthDayFromFields: ({id: id, native: native}, fields, options) => createPlainMonthDay(refinePlainMonthDayBag(native, 0, fields, options, id === isoCalendarId ? dayFieldNames : [])),
    fields({native: native}, fieldNames) {
      const allowed = new Set(dateFieldNamesAlpha), fieldNamesArray = [];
      for (const fieldName of fieldNames) {
        if (requireString(fieldName), !allowed.has(fieldName)) {
          throw new RangeError(forbiddenField(fieldName));
        }
        allowed.delete(fieldName), fieldNamesArray.push(fieldName);
      }
      return native.fields(fieldNamesArray);
    },
    mergeFields: ({native: native}, fields0, fields1) => native.mergeFields(excludeUndefinedProps(requireNonNullish(fields0)), excludeUndefinedProps(requireNonNullish(fields1)))
  }, [Calendar] = createSlotClass("Calendar", (id => {
    const slotId = resolveCalendarId(requireString(id));
    return {
      branding: "Calendar",
      id: slotId,
      native: createNativeStandardOps(slotId)
    };
  }), {
    id: slots => slots.id
  }, calendarMethods, {
    from(arg) {
      const calendarSlot = refineCalendarSlot(arg);
      return "string" == typeof calendarSlot ? new Calendar(calendarSlot) : calendarSlot;
    }
  }), validateCalendarProtocol = createProtocolValidator(Object.keys(calendarMethods).slice(4));
  let currentTimeZoneId;
  const Now = Object.defineProperties({}, {
    ...createStringTagDescriptors("Temporal.Now"),
    ...createPropDescriptors({
      timeZoneId: () => getCurrentTimeZoneId(),
      instant: () => createInstant(createInstantSlots(getCurrentEpochNanoseconds())),
      zonedDateTime: (calendar, timeZone = getCurrentTimeZoneId()) => createZonedDateTime(createZonedDateTimeSlots(getCurrentEpochNanoseconds(), refineTimeZoneSlot(timeZone), refineCalendarSlot(calendar))),
      zonedDateTimeISO: (timeZone = getCurrentTimeZoneId()) => createZonedDateTime(createZonedDateTimeSlots(getCurrentEpochNanoseconds(), refineTimeZoneSlot(timeZone), isoCalendarId)),
      plainDateTime: (calendar, timeZone = getCurrentTimeZoneId()) => createPlainDateTime(createPlainDateTimeSlots(getCurrentIsoDateTime(createTimeZoneOffsetOps(refineTimeZoneSlot(timeZone))), refineCalendarSlot(calendar))),
      plainDateTimeISO: (timeZone = getCurrentTimeZoneId()) => createPlainDateTime(createPlainDateTimeSlots(getCurrentIsoDateTime(createTimeZoneOffsetOps(refineTimeZoneSlot(timeZone))), isoCalendarId)),
      plainDate: (calendar, timeZone = getCurrentTimeZoneId()) => createPlainDate(createPlainDateSlots(getCurrentIsoDateTime(createTimeZoneOffsetOps(refineTimeZoneSlot(timeZone))), refineCalendarSlot(calendar))),
      plainDateISO: (timeZone = getCurrentTimeZoneId()) => createPlainDate(createPlainDateSlots(getCurrentIsoDateTime(createTimeZoneOffsetOps(refineTimeZoneSlot(timeZone))), isoCalendarId)),
      plainTimeISO: (timeZone = getCurrentTimeZoneId()) => createPlainTime(createPlainTimeSlots(getCurrentIsoDateTime(createTimeZoneOffsetOps(refineTimeZoneSlot(timeZone)))))
    })
  }), Temporal = Object.defineProperties({}, {
    ...createStringTagDescriptors("Temporal"),
    ...createPropDescriptors({
      PlainYearMonth: PlainYearMonth,
      PlainMonthDay: PlainMonthDay,
      PlainDate: PlainDate,
      PlainTime: PlainTime,
      PlainDateTime: PlainDateTime,
      ZonedDateTime: ZonedDateTime,
      Instant: Instant,
      Calendar: Calendar,
      TimeZone: TimeZone,
      Duration: Duration,
      Now: Now
    })
  });
  Object.defineProperties(globalThis, createPropDescriptors({
    Temporal: Temporal
  })), Object.defineProperties(Intl, createPropDescriptors({
    DateTimeFormat: DateTimeFormat
  })), Object.defineProperties(Date.prototype, createPropDescriptors({
    toTemporalInstant() {
      return createInstant(createInstantSlots(numberToDayTimeNano(this.valueOf(), nanoInMilli)));
    }
  }));
}();
